# 1 "src/Text/Pandoc/Data.hsb"
{-# LANGUAGE OverloadedStrings #-}
-- to be processed using hsb2hs
module Text.Pandoc.Data (dataFiles) where
import qualified Data.ByteString as B

dataFiles :: [(FilePath, B.ByteString)]
dataFiles = ("README", "% Pandoc User's Guide\n% John MacFarlane\n% May 27, 2015\n\nSynopsis\n========\n\n`pandoc` [*options*] [*input-file*]...\n\nDescription\n===========\n\nPandoc is a [Haskell] library for converting from one markup format to\nanother, and a command-line tool that uses this library. It can read\n[Markdown], [CommonMark], and (subsets of) [Textile],\n[reStructuredText], [HTML], [LaTeX], [MediaWiki markup], [TWiki\nmarkup], [Haddock markup], [OPML], [Emacs Org-mode], [DocBook],\n[txt2tags], [EPUB] and [Word docx]; and it can write plain text,\n[Markdown], [reStructuredText], [XHTML], [HTML 5], [LaTeX] (including\n[beamer] slide shows), [ConTeXt], [RTF], [OPML], [DocBook],\n[OpenDocument], [ODT], [Word docx], [GNU Texinfo], [MediaWiki markup],\n[DokuWiki markup], [Haddock markup], [EPUB] (v2 or v3),\n[FictionBook2], [Textile], [groff man] pages, [Emacs Org-Mode],\n[AsciiDoc], [InDesign ICML], and [Slidy], [Slideous], [DZSlides],\n[reveal.js] or [S5] HTML slide shows. It can also produce [PDF] output\non systems where LaTeX is installed.\n\nPandoc's enhanced version of markdown includes syntax for footnotes,\ntables, flexible ordered lists, definition lists, fenced code blocks,\nsuperscript, subscript, strikeout, title blocks, automatic tables of\ncontents, embedded LaTeX math, citations, and markdown inside HTML block\nelements. (These enhancements, described below under\n[Pandoc's markdown](#pandocs-markdown), can be disabled using the\n`markdown_strict` input or output format.)\n\nIn contrast to most existing tools for converting markdown to HTML, which\nuse regex substitutions, Pandoc has a modular design: it consists of a\nset of readers, which parse text in a given format and produce a native\nrepresentation of the document, and a set of writers, which convert\nthis native representation into a target format. Thus, adding an input\nor output format requires only adding a reader or writer.\n\nUsing `pandoc`\n--------------\n\nIf no *input-file* is specified, input is read from *stdin*.\nOtherwise, the *input-files* are concatenated (with a blank\nline between each) and used as input.  Output goes to *stdout* by\ndefault (though output to *stdout* is disabled for the `odt`, `docx`,\n`epub`, and `epub3` output formats).  For output to a file, use the\n`-o` option:\n\n    pandoc -o output.html input.txt\n\nBy default, pandoc produces a document fragment, not a standalone\ndocument with a proper header and footer.  To produce a standalone\ndocument, use the `-s` or `--standalone` flag:\n\n    pandoc -s -o output.html input.txt\n\nFor more information on how standalone documents are produced, see\n[Templates](#templates), below.\n\nInstead of a file, an absolute URI may be given.  In this case\npandoc will fetch the content using HTTP:\n\n    pandoc -f html -t markdown http://www.fsf.org\n\nIf multiple input files are given, `pandoc` will concatenate them all (with\nblank lines between them) before parsing. This feature is disabled for\n binary input formats such as `EPUB` and `docx`.\n\nThe format of the input and output can be specified explicitly using\ncommand-line options.  The input format can be specified using the\n`-r/--read` or `-f/--from` options, the output format using the\n`-w/--write` or `-t/--to` options.  Thus, to convert `hello.txt` from\nmarkdown to LaTeX, you could type:\n\n    pandoc -f markdown -t latex hello.txt\n\nTo convert `hello.html` from html to markdown:\n\n    pandoc -f html -t markdown hello.html\n\nSupported output formats are listed below under the `-t/--to` option.\nSupported input formats are listed below under the `-f/--from` option. Note\nthat the `rst`, `textile`, `latex`, and `html` readers are not complete;\nthere are some constructs that they do not parse.\n\nIf the input or output format is not specified explicitly, `pandoc`\nwill attempt to guess it from the extensions of\nthe input and output filenames.  Thus, for example,\n\n    pandoc -o hello.tex hello.txt\n\nwill convert `hello.txt` from markdown to LaTeX.  If no output file\nis specified (so that output goes to *stdout*), or if the output file's\nextension is unknown, the output format will default to HTML.\nIf no input file is specified (so that input comes from *stdin*), or\nif the input files' extensions are unknown, the input format will\nbe assumed to be markdown unless explicitly specified.\n\nPandoc uses the UTF-8 character encoding for both input and output.\nIf your local character encoding is not UTF-8, you\nshould pipe input and output through `iconv`:\n\n    iconv -t utf-8 input.txt | pandoc | iconv -f utf-8\n\nNote that in some output formats (such as HTML, LaTeX, ConTeXt,\nRTF, OPML, DocBook, and Texinfo), information about\nthe character encoding is included in the document header, which\nwill only be included if you use the `-s/--standalone` option.\n\nCreating a PDF\n--------------\n\nEarlier versions of pandoc came with a program, `markdown2pdf`, that\nused pandoc and pdflatex to produce a PDF.  This is no longer needed,\nsince `pandoc` can now produce `pdf` output itself. To produce a PDF, simply\nspecify an output file with a `.pdf` extension. Pandoc will create a latex\nfile and use pdflatex (or another engine, see `--latex-engine`) to convert it\nto PDF:\n\n    pandoc test.txt -o test.pdf\n\nProduction of a PDF requires that a LaTeX engine be installed (see\n`--latex-engine`, below), and assumes that the following LaTeX packages are\navailable: `amssymb`, `amsmath`, `ifxetex`, `ifluatex`, `listings` (if the\n`--listings` option is used), `fancyvrb`, `longtable`, `booktabs`, `url`,\n`graphicx` and `grffile` (if the document contains images),\n `hyperref`, `ulem`, `babel` (if the `lang` variable is set),\n`fontspec` (if `xelatex` or `lualatex` is used as the LaTeX engine), `xltxtra`\nand `xunicode` (if `xelatex` is used).\n\n`hsmarkdown`\n------------\n\nA user who wants a drop-in replacement for `Markdown.pl` may create\na symbolic link to the `pandoc` executable called `hsmarkdown`. When\ninvoked under the name `hsmarkdown`, `pandoc` will behave as if\ninvoked with `-f markdown_strict --email-obfuscation=references`,\nand all command-line options will be treated as regular arguments.\nHowever, this approach does not work under Cygwin, due to problems with\nits simulation of symbolic links.\n\n[Cygwin]:  http://www.cygwin.com/\n[`iconv`]: http://www.gnu.org/software/libiconv/\n[CTAN]: http://www.ctan.org \"Comprehensive TeX Archive Network\"\n[TeX Live]: http://www.tug.org/texlive/\n[MacTeX]:   http://www.tug.org/mactex/\n\nOptions\n=======\n\nGeneral options\n---------------\n\n`-f` *FORMAT*, `-r` *FORMAT*, `--from=`*FORMAT*, `--read=`*FORMAT*\n\n:   Specify input format.  *FORMAT* can be `native` (native Haskell),\n    `json` (JSON version of native AST), `markdown` (pandoc's\n    extended markdown), `markdown_strict` (original unextended\n    markdown), `markdown_phpextra` (PHP Markdown Extra extended\n    markdown), `markdown_github` (github extended markdown),\n    `commonmark` (CommonMark markdown), `textile` (Textile), `rst`\n    (reStructuredText), `html` (HTML), `docbook` (DocBook), `t2t`\n    (txt2tags), `docx` (docx), `epub` (EPUB), `opml` (OPML), `org`\n    (Emacs Org-mode), `mediawiki` (MediaWiki markup), `twiki` (TWiki\n    markup), `haddock` (Haddock markup), or `latex` (LaTeX).  If\n    `+lhs` is appended to `markdown`, `rst`, `latex`, or `html`, the\n    input will be treated as literate Haskell source: see [Literate\n    Haskell support](#literate-haskell-support), below. Markdown\n    syntax extensions can be individually enabled or disabled by\n    appending `+EXTENSION` or `-EXTENSION` to the format name. So, for\n    example, `markdown_strict+footnotes+definition_lists` is strict\n    markdown with footnotes and definition lists enabled, and\n    `markdown-pipe_tables+hard_line_breaks` is pandoc's markdown\n    without pipe tables and with hard line breaks. See [Pandoc's\n    markdown](#pandocs-markdown), below, for a list of extensions and\n    their names.\n\n`-t` *FORMAT*, `-w` *FORMAT*, `--to=`*FORMAT*, `--write=`*FORMAT*\n\n:   Specify output format.  *FORMAT* can be `native` (native Haskell),\n    `json` (JSON version of native AST), `plain` (plain text),\n    `markdown` (pandoc's extended markdown), `markdown_strict`\n    (original unextended markdown), `markdown_phpextra` (PHP Markdown\n    extra extended markdown), `markdown_github` (github extended\n    markdown), `commonmark` (CommonMark markdown), `rst`\n    (reStructuredText), `html` (XHTML 1), `html5` (HTML 5), `latex`\n    (LaTeX), `beamer` (LaTeX beamer slide show), `context` (ConTeXt),\n    `man` (groff man), `mediawiki` (MediaWiki markup), `dokuwiki`\n    (DokuWiki markup), `textile` (Textile), `org` (Emacs Org-Mode),\n    `texinfo` (GNU Texinfo), `opml` (OPML), `docbook` (DocBook),\n    `opendocument` (OpenDocument), `odt` (OpenOffice text document),\n    `docx` (Word docx), `haddock` (Haddock markup), `rtf` (rich text\n    format), `epub` (EPUB v2 book), `epub3` (EPUB v3), `fb2`\n    (FictionBook2 e-book), `asciidoc` (AsciiDoc), `icml` (InDesign\n    ICML), `slidy` (Slidy HTML and javascript slide show), `slideous`\n    (Slideous HTML and javascript slide show), `dzslides` (DZSlides\n    HTML5 + javascript slide show), `revealjs` (reveal.js HTML5 +\n    javascript slide show), `s5` (S5 HTML and javascript slide show),\n    or the path of a custom lua writer (see [Custom\n    writers](#custom-writers), below). Note that `odt`, `epub`, and\n    `epub3` output will not be directed to *stdout*; an output\n    filename must be specified using the `-o/--output` option. If\n    `+lhs` is appended to `markdown`, `rst`, `latex`, `beamer`,\n    `html`, or `html5`, the output will be rendered as literate\n    Haskell source: see [Literate Haskell\n    support](#literate-haskell-support), below.  Markdown syntax\n    extensions can be individually enabled or disabled by appending\n    `+EXTENSION` or `-EXTENSION` to the format name, as described\n    above under `-f`.\n\n`-o` *FILE*, `--output=`*FILE*\n\n:   Write output to *FILE* instead of *stdout*.  If *FILE* is\n    `-`, output will go to *stdout*.  (Exception: if the output\n    format is `odt`, `docx`, `epub`, or `epub3`, output to stdout is disabled.)\n\n`--data-dir=`*DIRECTORY*\n\n:   Specify the user data directory to search for pandoc data files.\n    If this option is not specified, the default user data directory\n    will be used.  This is\n\n        $HOME/.pandoc\n\n    in unix,\n\n        C:\\Documents And Settings\\USERNAME\\Application Data\\pandoc\n\n    in Windows XP, and\n\n        C:\\Users\\USERNAME\\AppData\\Roaming\\pandoc\n\n    in Windows 7. (You can find the default user data directory\n    on your system by looking at the output of `pandoc --version`.)\n    A `reference.odt`, `reference.docx`, `default.csl`,\n    `epub.css`, `templates`, `slidy`, `slideous`, or `s5` directory\n    placed in this directory will override pandoc's normal defaults.\n\n`--verbose`\n\n:   Give verbose debugging output.  Currently this only has an effect\n    with PDF output.\n\n`-v`, `--version`\n\n:   Print version.\n\n`-h`, `--help`\n\n:   Show usage message.\n\nReader options\n--------------\n\n`-R`, `--parse-raw`\n\n:   Parse untranslatable HTML codes and LaTeX environments as raw HTML\n    or LaTeX, instead of ignoring them.  Affects only HTML and LaTeX\n    input. Raw HTML can be printed in markdown, reStructuredText, HTML,\n    Slidy, Slideous, DZSlides, reveal.js, and S5 output; raw LaTeX\n    can be printed in markdown, reStructuredText, LaTeX, and ConTeXt output.\n    The default is for the readers to omit untranslatable HTML codes and\n    LaTeX environments.  (The LaTeX reader does pass through untranslatable\n    LaTeX *commands*, even if `-R` is not specified.)\n\n`-S`, `--smart`\n\n:   Produce typographically correct output, converting straight quotes\n    to curly quotes, `---` to em-dashes, `--` to en-dashes, and\n    `...` to ellipses. Nonbreaking spaces are inserted after certain\n    abbreviations, such as \"Mr.\" (Note: This option is significant only when\n    the input format is `markdown`, `markdown_strict`, `textile` or `twiki`.\n    It is selected automatically when the input format is `textile` or the\n    output format is `latex` or `context`, unless `--no-tex-ligatures`\n    is used.)\n\n`--old-dashes`\n\n:   Selects the pandoc <= 1.8.2.1 behavior for parsing smart dashes: `-` before\n    a numeral is an en-dash, and `--` is an em-dash.  This option is selected\n    automatically for `textile` input.\n\n`--base-header-level=`*NUMBER*\n\n:   Specify the base level for headers (defaults to 1).\n\n`--indented-code-classes=`*CLASSES*\n\n:   Specify classes to use for indented code blocks--for example,\n    `perl,numberLines` or `haskell`. Multiple classes may be separated\n    by spaces or commas.\n\n`--default-image-extension=`*EXTENSION*\n\n:   Specify a default extension to use when image paths/URLs have no\n    extension.  This allows you to use the same source for formats that\n    require different kinds of images.  Currently this option only affects\n    the markdown and LaTeX readers.\n\n`--filter=`*EXECUTABLE*\n\n:   Specify an executable to be used as a filter transforming the\n    Pandoc AST after the input is parsed and before the output is\n    written.  The executable should read JSON from stdin and write\n    JSON to stdout.  The JSON must be formatted like  pandoc's own\n    JSON input and output.  The name of the output format will be\n    passed to the filter as the first argument.  Hence,\n\n        pandoc --filter ./caps.py -t latex\n\n    is equivalent to\n\n        pandoc -t json | ./caps.py latex | pandoc -f json -t latex\n\n    The latter form may be useful for debugging filters.\n\n    Filters may be written in any language.  `Text.Pandoc.JSON`\n    exports `toJSONFilter` to facilitate writing filters in Haskell.\n    Those who would prefer to write filters in python can use the\n    module `pandocfilters`, installable from PyPI. See\n    <http://github.com/jgm/pandocfilters> for the module and several\n    examples. There are also pandoc filter libraries in\n    [PHP](https://github.com/vinai/pandocfilters-php),\n    [perl](https://metacpan.org/pod/Pandoc::Filter), and\n    [javascript/node.js](https://github.com/mvhenderson/pandoc-filter-node).\n\n    Note that the *EXECUTABLE* will be sought in the user's\n    `PATH`, and not in the working directory, if no directory is\n    provided.  If you want to run a script in the working directory,\n    preface the filename with `./`.\n\n`-M` *KEY*[`=`*VAL*], `--metadata=`*KEY*[`:`*VAL*]\n\n:   Set the metadata field *KEY* to the value *VAL*.  A value specified\n    on the command line overrides a value specified in the document.\n    Values will be parsed as YAML boolean or string values. If no value is\n    specified, the value will be treated as Boolean true.  Like\n    `--variable`, `--metadata` causes template variables to be set.\n    But unlike `--variable`, `--metadata` affects the metadata of the\n    underlying document (which is accessible from filters and may be\n    printed in some output formats).\n\n`--normalize`\n\n:   Normalize the document after reading:  merge adjacent\n    `Str` or `Emph` elements, for example, and remove repeated `Space`s.\n\n`-p`, `--preserve-tabs`\n\n:   Preserve tabs instead of converting them to spaces (the default).\n    Note that this will only affect tabs in literal code spans and code\n    blocks; tabs in regular text will be treated as spaces.\n\n`--tab-stop=`*NUMBER*\n\n:   Specify the number of spaces per tab (default is 4).\n\n`--track-changes=accept`|`reject`|`all`\n\n:   Specifies what to do with insertions and deletions produced by the MS\n    Word \"track-changes\" feature.  `accept` (the default), inserts all\n    insertions, and ignores all deletions. `reject` inserts all\n    deletions and ignores insertions. `all` puts in both insertions\n    and deletions, wrapped in spans with `insertion` and `deletion`\n    classes, respectively. The author and time of change is\n    included. `all` is useful for scripting: only accepting changes\n    from a certain reviewer, say, or before a certain date. This\n    option only affects the docx reader.\n\n`--extract-media=`*DIR*\n\n:   Extract images and other media contained in a docx or epub container\n    to the path *DIR*, creating it if necessary, and adjust the images\n    references in the document so they point to the extracted files.\n    This option only affects the docx and epub readers.\n\nGeneral writer options\n----------------------\n\n`-s`, `--standalone`\n\n:   Produce output with an appropriate header and footer (e.g. a\n    standalone HTML, LaTeX, or RTF file, not a fragment).  This option\n    is set automatically for `pdf`, `epub`, `epub3`, `fb2`, `docx`, and `odt`\n    output.\n\n`--template=`*FILE*\n\n:   Use *FILE* as a custom template for the generated document. Implies\n    `--standalone`. See [Templates](#templates) below for a description\n    of template syntax. If no extension is specified, an extension\n    corresponding to the writer will be added, so that `--template=special`\n    looks for `special.html` for HTML output.  If the template is not\n    found, pandoc will search for it in the user data directory\n    (see `--data-dir`). If this option is not used, a default\n    template appropriate for the output format will be used (see\n    `-D/--print-default-template`).\n\n`-V` *KEY*[`=`*VAL*], `--variable=`*KEY*[`:`*VAL*]\n\n:   Set the template variable *KEY* to the value *VAL* when rendering the\n    document in standalone mode. This is generally only useful when the\n    `--template` option is used to specify a custom template, since\n    pandoc automatically sets the variables used in the default\n    templates.  If no *VAL* is specified, the key will be given the\n    value `true`.\n\n`-D` *FORMAT*, `--print-default-template=`*FORMAT*\n\n:   Print the default template for an output *FORMAT*. (See `-t`\n    for a list of possible *FORMAT*s.)\n\n`--print-default-data-file=`*FILE*\n\n:   Print a default data file.\n\n`--no-wrap`\n\n:   Disable text wrapping in output. By default, text is wrapped\n    appropriately for the output format.\n\n`--columns=`*NUMBER*\n\n:   Specify length of lines in characters (for text wrapping).\n\n`--toc`, `--table-of-contents`\n\n:   Include an automatically generated table of contents (or, in\n    the case of `latex`, `context`, and `rst`, an instruction to create\n    one) in the output document. This option has no effect on `man`,\n    `docbook`, `slidy`, `slideous`, `s5`, `docx`, or `odt` output.\n\n`--toc-depth=`*NUMBER*\n\n:   Specify the number of section levels to include in the table\n    of contents.  The default is 3 (which means that level 1, 2, and 3\n    headers will be listed in the contents).\n\n`--no-highlight`\n\n:   Disables syntax highlighting for code blocks and inlines, even when\n    a language attribute is given.\n\n`--highlight-style=`*STYLE*\n\n:   Specifies the coloring style to be used in highlighted source code.\n    Options are `pygments` (the default), `kate`, `monochrome`,\n    `espresso`, `zenburn`, `haddock`, and `tango`.  For more information\n    on syntax highlighting in pandoc, see [Syntax highlighting], below.\n\n`-H` *FILE*, `--include-in-header=`*FILE*\n\n:   Include contents of *FILE*, verbatim, at the end of the header.\n    This can be used, for example, to include special\n    CSS or javascript in HTML documents.  This option can be used\n    repeatedly to include multiple files in the header.  They will be\n    included in the order specified.  Implies `--standalone`.\n\n`-B` *FILE*, `--include-before-body=`*FILE*\n\n:   Include contents of *FILE*, verbatim, at the beginning of the\n    document body (e.g. after the `<body>` tag in HTML, or the\n    `\\begin{document}` command in LaTeX). This can be used to include\n    navigation bars or banners in HTML documents. This option can be\n    used repeatedly to include multiple files. They will be included in\n    the order specified.  Implies `--standalone`.\n\n`-A` *FILE*, `--include-after-body=`*FILE*\n\n:   Include contents of *FILE*, verbatim, at the end of the document\n    body (before the `</body>` tag in HTML, or the\n    `\\end{document}` command in LaTeX). This option can be be used\n    repeatedly to include multiple files. They will be included in the\n    order specified.  Implies `--standalone`.\n\nOptions affecting specific writers\n----------------------------------\n\n`--self-contained`\n\n:   Produce a standalone HTML file with no external dependencies, using\n    `data:` URIs to incorporate the contents of linked scripts, stylesheets,\n    images, and videos. The resulting file should be \"self-contained,\"\n    in the sense that it needs no external files and no net access to be\n    displayed properly by a browser. This option works only with HTML output\n    formats, including `html`, `html5`, `html+lhs`, `html5+lhs`, `s5`,\n    `slidy`, `slideous`, `dzslides`, and `revealjs`. Scripts, images, and\n    stylesheets at absolute URLs will be downloaded; those at relative URLs\n    will be sought relative to the working directory (if the first source\n    file is local) or relative to the base URL (if the first source\n    file is remote).  `--self-contained` does not work with `--mathjax`.\n\n`--offline`\n\n:   Deprecated synonym for `--self-contained`.\n\n`-5`, `--html5`\n\n:   Produce HTML5 instead of HTML4.  This option has no effect for writers\n    other than `html`. (*Deprecated:*  Use the `html5` output format instead.)\n\n`--html-q-tags`\n\n:   Use `<q>` tags for quotes in HTML.\n\n`--ascii`\n\n:   Use only ascii characters in output.  Currently supported only\n    for HTML output (which uses numerical entities instead of\n    UTF-8 when this option is selected).\n\n`--reference-links`\n\n:   Use reference-style links, rather than inline links, in writing markdown\n    or reStructuredText.  By default inline links are used.\n\n`--atx-headers`\n\n:   Use ATX style headers in markdown and asciidoc output. The default is\n    to use setext-style headers for levels 1-2, and then ATX headers.\n\n`--chapters`\n\n:   Treat top-level headers as chapters in LaTeX, ConTeXt, and DocBook\n    output.  When the LaTeX template uses the report, book, or\n    memoir class, this option is implied.  If `beamer` is the output\n    format, top-level headers will become `\\part{..}`.\n\n`-N`, `--number-sections`\n\n:   Number section headings in LaTeX, ConTeXt, HTML, or EPUB output.\n    By default, sections are not numbered.  Sections with class\n    `unnumbered` will never be numbered, even if `--number-sections`\n    is specified.\n\n`--number-offset=`*NUMBER*[`,`*NUMBER*`,`*...*]\n\n:   Offset for section headings in HTML output (ignored in other\n    output formats).  The first number is added to the section number for\n    top-level headers, the second for second-level headers, and so on.\n    So, for example, if you want the first top-level header in your\n    document to be numbered \"6\", specify `--number-offset=5`.\n    If your document starts with a level-2 header which you want to\n    be numbered \"1.5\", specify `--number-offset=1,4`.\n    Offsets are 0 by default.  Implies `--number-sections`.\n\n`--no-tex-ligatures`\n\n:   Do not convert quotation marks, apostrophes, and dashes to\n    the TeX ligatures when writing LaTeX or ConTeXt. Instead, just\n    use literal unicode characters. This is needed for using advanced\n    OpenType features with XeLaTeX and LuaLaTeX. Note: normally\n    `--smart` is selected automatically for LaTeX and ConTeXt\n    output, but it must be specified explicitly if `--no-tex-ligatures`\n    is selected. If you use literal curly quotes, dashes, and ellipses\n    in your source, then you may want to use `--no-tex-ligatures`\n    without `--smart`.\n\n`--listings`\n\n:   Use listings package for LaTeX code blocks\n\n`-i`, `--incremental`\n\n:   Make list items in slide shows display incrementally (one by one).\n    The default is for lists to be displayed all at once.\n\n`--slide-level=`*NUMBER*\n\n:   Specifies that headers with the specified level create\n    slides (for `beamer`, `s5`, `slidy`, `slideous`, `dzslides`).  Headers\n    above this level in the hierarchy are used to divide the\n    slide show into sections; headers below this level create\n    subheads within a slide.  The default is to set the slide level\n    based on the contents of the document; see\n    [Structuring the slide show](#structuring-the-slide-show), below.\n\n`--section-divs`\n\n:   Wrap sections in `<div>` tags (or `<section>` tags in HTML5),\n    and attach identifiers to the enclosing `<div>` (or `<section>`)\n    rather than the header itself.\n    See [Section identifiers](#header-identifiers-in-html-latex-and-context), below.\n\n`--email-obfuscation=none`|`javascript`|`references`\n\n:   Specify a method for obfuscating `mailto:` links in HTML documents.\n    `none` leaves `mailto:` links as they are.  `javascript` obfuscates\n    them using javascript. `references` obfuscates them by printing their\n    letters as decimal or hexadecimal character references.\n\n`--id-prefix=`*STRING*\n\n:   Specify a prefix to be added to all automatically generated identifiers\n    in HTML and DocBook output, and to footnote numbers in markdown output.\n    This is useful for preventing duplicate identifiers when generating\n    fragments to be included in other pages.\n\n`-T` *STRING*, `--title-prefix=`*STRING*\n\n:   Specify *STRING* as a prefix at the beginning of the title\n    that appears in the HTML header (but not in the title as it\n    appears at the beginning of the HTML body).  Implies\n    `--standalone`.\n\n`-c` *URL*, `--css=`*URL*\n\n:   Link to a CSS style sheet. This option can be be used repeatedly to\n    include multiple files. They will be included in the order specified.\n\n`--reference-odt=`*FILE*\n\n:   Use the specified file as a style reference in producing an ODT.\n    For best results, the reference ODT should be a modified version\n    of an ODT produced using pandoc.  The contents of the reference ODT\n    are ignored, but its stylesheets are used in the new ODT. If no\n    reference ODT is specified on the command line, pandoc will look\n    for a file `reference.odt` in the user data directory (see\n    `--data-dir`). If this is not found either, sensible defaults will be\n    used.\n\n`--reference-docx=`*FILE*\n\n:   Use the specified file as a style reference in producing a docx file.\n    For best results, the reference docx should be a modified version\n    of a docx file produced using pandoc.  The contents of the reference docx\n    are ignored, but its stylesheets and document properties (including\n    margins, page size, header, and footer) are used in the new docx. If no\n    reference docx is specified on the command line, pandoc will look\n    for a file `reference.docx` in the user data directory (see\n    `--data-dir`). If this is not found either, sensible defaults will be\n    used. The following styles are used by pandoc: [paragraph]\n    Normal, Compact, Title, Subtitle, Authors, Date, Abstract, Heading 1,\n    Heading 2, Heading 3, Heading 4, Heading 5, Block Text, Definition Term,\n    Definition, Bibliography, Body Text, Table Caption, Image Caption,\n    Figure, FigureWithCaption;\n    [character] Default Paragraph Font, Body Text Char, Verbatim Char,\n    Footnote Reference, Hyperlink.\n\n`--epub-stylesheet=`*FILE*\n\n:   Use the specified CSS file to style the EPUB.  If no stylesheet\n    is specified, pandoc will look for a file `epub.css` in the\n    user data directory (see `--data-dir`).  If it is not\n    found there, sensible defaults will be used.\n\n`--epub-cover-image=`*FILE*\n\n:   Use the specified image as the EPUB cover.  It is recommended\n    that the image be less than 1000px in width and height. Note that\n    in a markdown source document you can also specify `cover-image`\n    in a YAML metadata block (see [EPUB Metadata], below).\n\n`--epub-metadata=`*FILE*\n\n:   Look in the specified XML file for metadata for the EPUB.\n    The file should contain a series of Dublin Core elements,\n    as documented at <http://dublincore.org/documents/dces/>.\n    For example:\n\n         <dc:rights>Creative Commons</dc:rights>\n         <dc:language>es-AR</dc:language>\n\n    By default, pandoc will include the following metadata elements:\n    `<dc:title>` (from the document title), `<dc:creator>` (from the\n    document authors), `<dc:date>` (from the document date, which should\n    be in [ISO 8601 format]), `<dc:language>` (from the `lang`\n    variable, or, if is not set, the locale), and `<dc:identifier\n    id=\"BookId\">` (a randomly generated UUID). Any of these may be\n    overridden by elements in the metadata file.\n\n    Note: if the source document is markdown, a YAML metadata block\n    in the document can be used instead.  See below under\n    [EPUB Metadata].\n\n`--epub-embed-font=`*FILE*\n\n:   Embed the specified font in the EPUB. This option can be repeated\n    to embed multiple fonts.  Wildcards can also be used: for example,\n    `DejaVuSans-*.ttf`.  However, if you use wildcards on the command\n    line, be sure to escape them or put the whole filename in single quotes,\n    to prevent them from being interpreted by the shell. To use the\n    embedded fonts, you will need to add declarations like the following\n    to your CSS (see `--epub-stylesheet`):\n\n        @font-face {\n        font-family: DejaVuSans;\n        font-style: normal;\n        font-weight: normal;\n        src:url(\"DejaVuSans-Regular.ttf\");\n        }\n        @font-face {\n        font-family: DejaVuSans;\n        font-style: normal;\n        font-weight: bold;\n        src:url(\"DejaVuSans-Bold.ttf\");\n        }\n        @font-face {\n        font-family: DejaVuSans;\n        font-style: italic;\n        font-weight: normal;\n        src:url(\"DejaVuSans-Oblique.ttf\");\n        }\n        @font-face {\n        font-family: DejaVuSans;\n        font-style: italic;\n        font-weight: bold;\n        src:url(\"DejaVuSans-BoldOblique.ttf\");\n        }\n        body { font-family: \"DejaVuSans\"; }\n\n`--epub-chapter-level=`*NUMBER*\n\n:   Specify the header level at which to split the EPUB into separate\n    \"chapter\" files. The default is to split into chapters at level 1\n    headers. This option only affects the internal composition of the\n    EPUB, not the way chapters and sections are displayed to users. Some\n    readers may be slow if the chapter files are too large, so for large\n    documents with few level 1 headers, one might want to use a chapter\n    level of 2 or 3.\n\n`--latex-engine=pdflatex`|`lualatex`|`xelatex`\n\n:   Use the specified LaTeX engine when producing PDF output.\n    The default is `pdflatex`.  If the engine is not in your PATH,\n    the full path of the engine may be specified here.\n\n`--latex-engine-opt=`*STRING*\n\n:   Use the given string as a command-line argument to the `latex-engine`.\n    If used multiple times, the arguments are provided with spaces between\n    them. Note that no check for duplicate options is done.\n\nCitation rendering\n------------------\n\n`--bibliography=`*FILE*\n\n:   Set the `bibliography` field in the document's metadata to *FILE*,\n    overriding any value set in the metadata, and process citations\n    using `pandoc-citeproc`. (This is equivalent to\n    `--metadata bibliography=FILE --filter pandoc-citeproc`.)\n    If `--natbib` or `--biblatex` is also supplied, `pandoc-citeproc` is not\n    used, making this equivalent to `--metadata bibliography=FILE`.\n    If you supply this argument multiple times, each *FILE* will be added\n    to bibliography.\n\n`--csl=`*FILE*\n\n:   Set the `csl` field in the document's metadata to *FILE*,\n    overriding any value set in the metadata.  (This is equivalent to\n    `--metadata csl=FILE`.)\n    This option is only relevant with `pandoc-citeproc`.\n\n`--citation-abbreviations=`*FILE*\n\n:   Set the `citation-abbreviations` field in the document's metadata to\n    *FILE*, overriding any value set in the metadata.  (This is equivalent to\n    `--metadata citation-abbreviations=FILE`.)\n    This option is only relevant with `pandoc-citeproc`.\n\n`--natbib`\n\n:   Use natbib for citations in LaTeX output.  This option is not for use\n    with the `pandoc-citeproc` filter or with PDF output.  It is intended for\n    use in producing a LaTeX file that can be processed with pdflatex and\n    bibtex.\n\n`--biblatex`\n\n:   Use biblatex for citations in LaTeX output.  This option is not for use\n    with the `pandoc-citeproc` filter or with PDF output. It is intended for\n    use in producing a LaTeX file that can be processed with pdflatex and\n    bibtex or biber.\n\nMath rendering in HTML\n----------------------\n\n`-m` [*URL*], `--latexmathml`[`=`*URL*]\n\n:   Use the [LaTeXMathML] script to display embedded TeX math in HTML output.\n    To insert a link to a local copy of the `LaTeXMathML.js` script,\n    provide a *URL*. If no *URL* is provided, the contents of the\n    script will be inserted directly into the HTML header, preserving\n    portability at the price of efficiency. If you plan to use math on\n    several pages, it is much better to link to a copy of the script,\n    so it can be cached.\n\n`--mathml`[`=`*URL*]\n\n:   Convert TeX math to MathML (in `docbook` as well as `html` and `html5`).\n    In standalone `html` output, a small javascript (or a link to such a\n    script if a *URL* is supplied) will be inserted that allows the MathML to\n    be viewed on some browsers.\n\n`--jsmath`[`=`*URL*]\n\n:   Use [jsMath] to display embedded TeX math in HTML output.\n    The *URL* should point to the jsMath load script (e.g.\n    `jsMath/easy/load.js`); if provided, it will be linked to in\n    the header of standalone HTML documents. If a *URL* is not provided,\n    no link to the jsMath load script will be inserted; it is then\n    up to the author to provide such a link in the HTML template.\n\n`--mathjax`[`=`*URL*]\n\n:   Use [MathJax] to display embedded TeX math in HTML output.\n    The *URL* should point to the `MathJax.js` load script.\n    If a *URL* is not provided, a link to the MathJax CDN will\n    be inserted.\n\n`--gladtex`\n\n:   Enclose TeX math in `<eq>` tags in HTML output.  These can then\n    be processed by [gladTeX] to produce links to images of the typeset\n    formulas.\n\n`--mimetex`[`=`*URL*]\n\n:   Render TeX math using the [mimeTeX] CGI script.  If *URL* is not\n    specified, it is assumed that the script is at `/cgi-bin/mimetex.cgi`.\n\n`--webtex`[`=`*URL*]\n\n:   Render TeX formulas using an external script that converts TeX\n    formulas to images. The formula will be concatenated with the URL\n    provided. If *URL* is not specified, the Google Chart API will be used.\n\n`--katex`[`=`*URL*]\n\n:   Use [KaTeX] to display embedded TeX math in HTML output.\n    The *URL* should point to the `katex.js` load script. If a *URL* is\n    not provided, a link to the KaTeX CDN will be inserted.\n\n`--katex-stylesheet=`*URL*\n\n:   The *URL* should point to the `katex.css` stylesheet. If this option is\n    not specified, a link to the KaTeX CDN will be inserted. Note that this\n    option does not imply `--katex`.\n\nOptions for wrapper scripts\n---------------------------\n\n`--dump-args`\n\n:   Print information about command-line arguments to *stdout*, then exit.\n    This option is intended primarily for use in wrapper scripts.\n    The first line of output contains the name of the output file specified\n    with the `-o` option, or `-` (for *stdout*) if no output file was\n    specified.  The remaining lines contain the command-line arguments,\n    one per line, in the order they appear.  These do not include regular\n    Pandoc options and their arguments, but do include any options appearing\n    after a `--` separator at the end of the line.\n\n`--ignore-args`\n\n:   Ignore command-line arguments (for use in wrapper scripts).\n    Regular Pandoc options are not ignored.  Thus, for example,\n\n        pandoc --ignore-args -o foo.html -s foo.txt -- -e latin1\n\n    is equivalent to\n\n        pandoc -o foo.html -s\n\n[LaTeXMathML]: http://math.etsu.edu/LaTeXMathML/\n[jsMath]:  http://www.math.union.edu/~dpvc/jsmath/\n[MathJax]: http://www.mathjax.org/\n[gladTeX]:  http://ans.hsh.no/home/mgg/gladtex/\n[mimeTeX]: http://www.forkosh.com/mimetex.html\n[CSL]: http://CitationStyles.org\n\nTemplates\n=========\n\nWhen the `-s/--standalone` option is used, pandoc uses a template to\nadd header and footer material that is needed for a self-standing\ndocument.  To see the default template that is used, just type\n\n    pandoc -D FORMAT\n\nwhere `FORMAT` is the name of the output format. A custom template\ncan be specified using the `--template` option.  You can also override\nthe system default templates for a given output format `FORMAT`\nby putting a file `templates/default.FORMAT` in the user data\ndirectory (see `--data-dir`, above). *Exceptions:* For `odt` output,\ncustomize the `default.opendocument` template.  For `pdf` output,\ncustomize the `default.latex` template.\n\nTemplates may contain *variables*.  Variable names are sequences of\nalphanumerics, `-`, and `_`, starting with a letter.  A variable name\nsurrounded by `$` signs will be replaced by its value.  For example,\nthe string `$title$` in\n\n    <title>$title$</title>\n\nwill be replaced by the document title.\n\nTo write a literal `$` in a template, use `$$`.\n\nSome variables are set automatically by pandoc.  These vary somewhat\ndepending on the output format, but include metadata fields (such\nas `title`, `author`, and `date`) as well as the following:\n\n`header-includes`\n:   contents specified by `-H/--include-in-header` (may have multiple\n    values)\n\n`toc`\n:   non-null value if `--toc/--table-of-contents` was specified\n\n`include-before`\n:   contents specified by `-B/--include-before-body` (may have\n    multiple values)\n\n`include-after`\n:   contents specified by `-A/--include-after-body` (may have\n    multiple values)\n\n`body`\n:   body of document\n\n`lang`\n:   language code for HTML or LaTeX documents\n\n`slidy-url`\n:   base URL for Slidy documents (defaults to\n    `http://www.w3.org/Talks/Tools/Slidy2`)\n\n`slideous-url`\n:   base URL for Slideous documents (defaults to `slideous`)\n\n`s5-url`\n:   base URL for S5 documents (defaults to `s5/default`)\n\n`revealjs-url`\n:   base URL for reveal.js documents (defaults to `reveal.js`)\n\n`theme`\n:   reveal.js or LaTeX beamer theme\n\n`transition`\n:   reveal.js transition\n\n`fontsize`\n:   font size (10pt, 11pt, 12pt) for LaTeX documents\n\n`documentclass`\n:   document class for LaTeX documents\n\n`classoption`\n:   option for LaTeX documentclass, e.g. `oneside`; may be repeated\n    for multiple options\n\n`geometry`\n:   options for LaTeX `geometry` class, e.g. `margin=1in`;\n    may be repeated for multiple options\n\n`linestretch`\n:   adjusts line spacing (requires the `setspace` package)\n\n`fontfamily`\n:   font package to use for LaTeX documents (with pdflatex):\n    TeXLive has `bookman` (Bookman), `utopia` or `fourier` (Utopia),\n    `fouriernc` (New Century Schoolbook), `times` or `txfonts` (Times),\n    `mathpazo` or `pxfonts` or `mathpple` (Palatino),\n    `libertine` (Linux Libertine), `arev` (Arev Sans),\n    and the default `lmodern`, among others.\n\n`mainfont`, `sansfont`, `monofont`, `mathfont`, `CJKmainfont`\n:   fonts for LaTeX documents (works only with xelatex\n    and lualatex).  Note that if `CJKmainfont` is used,\n    the `xeCJK` package must be available.\n\n`colortheme`\n:   colortheme for LaTeX beamer documents\n\n`fonttheme`\n:   fonttheme for LaTeX beamer documents\n\n`linkcolor`\n:   color for internal links in LaTeX documents (`red`, `green`,\n    `magenta`, `cyan`, `blue`, `black`)\n\n`toccolor`\n:    color for links in table of contents in LaTeX documents\n\n`urlcolor`\n:   color for external links in LaTeX documents\n\n`citecolor`\n:   color for citation links in LaTeX documents\n\n`links-as-notes`\n:   causes links to be printed as footnotes in LaTeX documents\n\n`toc`\n:   include table of contents in LaTeX documents\n\n`toc-depth`\n:   level of section to include in table of contents in LaTeX documents\n\n`toc-title`\n:   title of table of contents (works only with EPUB and docx)\n\n`lof`\n:   include list of figures in LaTeX documents\n\n`lot`\n:   include list of tables in LaTeX documents\n\n`bibliography`\n:   bibliography to use for resolving references\n\n`biblio-style`\n:   bibliography style in LaTeX, when used with `--natbib`\n\n`section`\n:   section number in man pages\n\n`header`\n:   header in man pages\n\n`footer`\n:   footer in man pages\n\nVariables may be set at the command line using the `-V/--variable`\noption.  Variables set in this way override metadata fields with\nthe same name.\n\nTemplates may contain conditionals.  The syntax is as follows:\n\n    $if(variable)$\n    X\n    $else$\n    Y\n    $endif$\n\nThis will include `X` in the template if `variable` has a non-null\nvalue; otherwise it will include `Y`. `X` and `Y` are placeholders for\nany valid template text, and may include interpolated variables or other\nconditionals. The `$else$` section may be omitted.\n\nWhen variables can have multiple values (for example, `author` in\na multi-author document), you can use the `$for$` keyword:\n\n    $for(author)$\n    <meta name=\"author\" content=\"$author$\" />\n    $endfor$\n\nYou can optionally specify a separator to be used between\nconsecutive items:\n\n    $for(author)$$author$$sep$, $endfor$\n\nA dot can be used to select a field of a variable that takes\nan object as its value.  So, for example:\n\n    $author.name$ ($author.affiliation$)\n\nIf you use custom templates, you may need to revise them as pandoc\nchanges.  We recommend tracking the changes in the default templates,\nand modifying your custom templates accordingly. An easy way to do this\nis to fork the pandoc-templates repository\n(<http://github.com/jgm/pandoc-templates>) and merge in changes after each\npandoc release.\n\nPandoc's markdown\n=================\n\nPandoc understands an extended and slightly revised version of\nJohn Gruber's [markdown] syntax.  This document explains the syntax,\nnoting differences from standard markdown. Except where noted, these\ndifferences can be suppressed by using the `markdown_strict` format instead\nof `markdown`.  An extensions can be enabled by adding `+EXTENSION`\nto the format name and disabled by adding `-EXTENSION`. For example,\n`markdown_strict+footnotes` is strict markdown with footnotes\nenabled, while `markdown-footnotes-pipe_tables` is pandoc's\nmarkdown without footnotes or pipe tables.\n\nPhilosophy\n----------\n\nMarkdown is designed to be easy to write, and, even more importantly,\neasy to read:\n\n> A Markdown-formatted document should be publishable as-is, as plain\n> text, without looking like it's been marked up with tags or formatting\n> instructions.\n> -- [John Gruber](http://daringfireball.net/projects/markdown/syntax#philosophy)\n\nThis principle has guided pandoc's decisions in finding syntax for\ntables, footnotes, and other extensions.\n\nThere is, however, one respect in which pandoc's aims are different\nfrom the original aims of markdown.  Whereas markdown was originally\ndesigned with HTML generation in mind, pandoc is designed for multiple\noutput formats.  Thus, while pandoc allows the embedding of raw HTML,\nit discourages it, and provides other, non-HTMLish ways of representing\nimportant document elements like definition lists, tables, mathematics, and\nfootnotes.\n\nParagraphs\n----------\n\nA paragraph is one or more lines of text followed by one or more blank lines.\nNewlines are treated as spaces, so you can reflow your paragraphs as you like.\nIf you need a hard line break, put two or more spaces at the end of a line.\n\n#### Extension: `escaped_line_breaks` ####\n\nA backslash followed by a newline is also a hard line break.\nNote:  in multiline and grid table cells, this is the only way\nto create a hard line break, since trailing spaces in the cells\nare ignored.\n\nHeaders\n-------\n\nThere are two kinds of headers, Setext and atx.\n\n### Setext-style headers ###\n\nA setext-style header is a line of text \"underlined\" with a row of `=` signs\n(for a level one header) or `-` signs (for a level two header):\n\n    A level-one header\n    ==================\n\n    A level-two header\n    ------------------\n\nThe header text can contain inline formatting, such as emphasis (see\n[Inline formatting](#inline-formatting), below).\n\n\n### Atx-style headers ###\n\nAn Atx-style header consists of one to six `#` signs and a line of\ntext, optionally followed by any number of `#` signs.  The number of\n`#` signs at the beginning of the line is the header level:\n\n    ## A level-two header\n\n    ### A level-three header ###\n\nAs with setext-style headers, the header text can contain formatting:\n\n    # A level-one header with a [link](/url) and *emphasis*\n\n#### Extension: `blank_before_header` ####\n\nStandard markdown syntax does not require a blank line before a header.\nPandoc does require this (except, of course, at the beginning of the\ndocument). The reason for the requirement is that it is all too easy for a\n`#` to end up at the beginning of a line by accident (perhaps through line\nwrapping). Consider, for example:\n\n    I like several of their flavors of ice cream:\n    #22, for example, and #5.\n\n\n### Header identifiers in HTML, LaTeX, and ConTeXt ###\n\n#### Extension: `header_attributes` ####\n\nHeaders can be assigned attributes using this syntax at the end\nof the line containing the header text:\n\n    {#identifier .class .class key=value key=value}\n\nThus, for example, the following headers will all be assigned the identifier\n`foo`:\n\n    # My header {#foo}\n\n    ## My header ##    {#foo}\n\n    My other header   {#foo}\n    ---------------\n\n(This syntax is compatible with [PHP Markdown Extra].)\n\nNote that although this syntax allows assignment of classes and key/value\nattributes, writers generally don't use all of this information.  Identifiers,\nclasses, and key/value attributes are used in HTML and HTML-based formats such\nas EPUB and slidy.  Identifiers are used for labels and link anchors in the\nLaTeX, ConTeXt, Textile, and AsciiDoc writers.\n\nHeaders with the class `unnumbered` will not be numbered, even if\n`--number-sections` is specified.  A single hyphen (`-`) in an attribute\ncontext is equivalent to `.unnumbered`, and preferable in non-English\ndocuments.  So,\n\n    # My header {-}\n\nis just the same as\n\n    # My header {.unnumbered}\n\n#### Extension: `auto_identifiers` ####\n\nA header without an explicitly specified identifier will be\nautomatically assigned a unique identifier based on the header text.\nTo derive the identifier from the header text,\n\n  - Remove all formatting, links, etc.\n  - Remove all footnotes.\n  - Remove all punctuation, except underscores, hyphens, and periods.\n  - Replace all spaces and newlines with hyphens.\n  - Convert all alphabetic characters to lowercase.\n  - Remove everything up to the first letter (identifiers may\n    not begin with a number or punctuation mark).\n  - If nothing is left after this, use the identifier `section`.\n\nThus, for example,\n\n  Header                            Identifier\n  -------------------------------   ----------------------------\n  Header identifiers in HTML        `header-identifiers-in-html`\n  *Dogs*?--in *my* house?           `dogs--in-my-house`\n  [HTML], [S5], or [RTF]?           `html-s5-or-rtf`\n  3. Applications                   `applications`\n  33                                `section`\n\nThese rules should, in most cases, allow one to determine the identifier\nfrom the header text. The exception is when several headers have the\nsame text; in this case, the first will get an identifier as described\nabove; the second will get the same identifier with `-1` appended; the\nthird with `-2`; and so on.\n\nThese identifiers are used to provide link targets in the table of\ncontents generated by the `--toc|--table-of-contents` option. They\nalso make it easy to provide links from one section of a document to\nanother. A link to this section, for example, might look like this:\n\n    See the section on\n    [header identifiers](#header-identifiers-in-html-latex-and-context).\n\nNote, however, that this method of providing links to sections works\nonly in HTML, LaTeX, and ConTeXt formats.\n\nIf the `--section-divs` option is specified, then each section will\nbe wrapped in a `div` (or a `section`, if `--html5` was specified),\nand the identifier will be attached to the enclosing `<div>`\n(or `<section>`) tag rather than the header itself. This allows entire\nsections to be manipulated using javascript or treated differently in\nCSS.\n\n#### Extension: `implicit_header_references` ####\n\nPandoc behaves as if reference links have been defined for each header.\nSo, instead of\n\n    [header identifiers](#header-identifiers-in-html)\n\nyou can simply write\n\n    [header identifiers]\n\nor\n\n    [header identifiers][]\n\nor\n\n    [the section on header identifiers][header identifiers]\n\nIf there are multiple headers with identical text, the corresponding\nreference will link to the first one only, and you will need to use explicit\nlinks to link to the others, as described above.\n\nLike regular reference links, these references are case-insensitive.\n\nExplicit link reference definitions always take priority over\nimplicit header references.  So, in the following example, the\nlink will point to `bar`, not to `#foo`:\n\n    # Foo\n\n    [foo]: bar\n\n    See [foo]\n\nBlock quotations\n----------------\n\nMarkdown uses email conventions for quoting blocks of text.\nA block quotation is one or more paragraphs or other block elements\n(such as lists or headers), with each line preceded by a `>` character\nand a space. (The `>` need not start at the left margin, but it should\nnot be indented more than three spaces.)\n\n    > This is a block quote. This\n    > paragraph has two lines.\n    >\n    > 1. This is a list inside a block quote.\n    > 2. Second item.\n\nA \"lazy\" form, which requires the `>` character only on the first\nline of each block, is also allowed:\n\n    > This is a block quote. This\n    paragraph has two lines.\n\n    > 1. This is a list inside a block quote.\n    2. Second item.\n\nAmong the block elements that can be contained in a block quote are\nother block quotes. That is, block quotes can be nested:\n\n    > This is a block quote.\n    >\n    > > A block quote within a block quote.\n\n#### Extension: `blank_before_blockquote` ####\n\nStandard markdown syntax does not require a blank line before a block\nquote.  Pandoc does require this (except, of course, at the beginning of the\ndocument). The reason for the requirement is that it is all too easy for a\n`>` to end up at the beginning of a line by accident (perhaps through line\nwrapping). So, unless the `markdown_strict` format is used, the following does\nnot produce a nested block quote in pandoc:\n\n    > This is a block quote.\n    >> Nested.\n\n\nVerbatim (code) blocks\n----------------------\n\n### Indented code blocks ###\n\nA block of text indented four spaces (or one tab) is treated as verbatim\ntext: that is, special characters do not trigger special formatting,\nand all spaces and line breaks are preserved.  For example,\n\n        if (a > 3) {\n          moveShip(5 * gravity, DOWN);\n        }\n\nThe initial (four space or one tab) indentation is not considered part\nof the verbatim text, and is removed in the output.\n\nNote: blank lines in the verbatim text need not begin with four spaces.\n\n\n### Fenced code blocks ###\n\n#### Extension: `fenced_code_blocks` ####\n\nIn addition to standard indented code blocks, Pandoc supports\n*fenced* code blocks.  These begin with a row of three or more\ntildes (`~`) and end with a row of tildes that must be at least as long as\nthe starting row. Everything between these lines is treated as code. No\nindentation is necessary:\n\n    ~~~~~~~\n    if (a > 3) {\n      moveShip(5 * gravity, DOWN);\n    }\n    ~~~~~~~\n\nLike regular code blocks, fenced code blocks must be separated\nfrom surrounding text by blank lines.\n\nIf the code itself contains a row of tildes or backticks, just use a longer\nrow of tildes or backticks at the start and end:\n\n    ~~~~~~~~~~~~~~~~\n    ~~~~~~~~~~\n    code including tildes\n    ~~~~~~~~~~\n    ~~~~~~~~~~~~~~~~\n\n#### Extension: `backtick_code_blocks` ####\n\nSame as `fenced_code_blocks`, but uses backticks (`` ` ``) instead of tildes\n(`~`).\n\n#### Extension: `fenced_code_attributes` ####\n\nOptionally, you may attach attributes to fenced or backtick code block using\nthis syntax:\n\n    ~~~~ {#mycode .haskell .numberLines startFrom=\"100\"}\n    qsort []     = []\n    qsort (x:xs) = qsort (filter (< x) xs) ++ [x] ++\n                   qsort (filter (>= x) xs)\n    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nHere `mycode` is an identifier, `haskell` and `numberLines` are classes, and\n`startFrom` is an attribute with value `100`. Some output formats can use this\ninformation to do syntax highlighting. Currently, the only output formats\nthat uses this information are HTML and LaTeX. If highlighting is supported\nfor your output format and language, then the code block above will appear\nhighlighted, with numbered lines. (To see which languages are supported, do\n`pandoc --version`.) Otherwise, the code block above will appear as follows:\n\n    <pre id=\"mycode\" class=\"haskell numberLines\" startFrom=\"100\">\n      <code>\n      ...\n      </code>\n    </pre>\n\nA shortcut form can also be used for specifying the language of\nthe code block:\n\n    ```haskell\n    qsort [] = []\n    ```\n\nThis is equivalent to:\n\n    ``` {.haskell}\n    qsort [] = []\n    ```\n\nIf the `fenced_code_attributes` extension is disabled, but\ninput contains class attribute(s) for the codeblock, the first\nclass attribute will be printed after the opening fence as a bare\nword.\n\nTo prevent all highlighting, use the `--no-highlight` flag.\nTo set the highlighting style, use `--highlight-style`.\nFor more information on highlighting, see [Syntax highlighting],\nbelow.\n\nLine blocks\n-----------\n\n#### Extension: `line_blocks` ####\n\nA line block is a sequence of lines beginning with a vertical bar (`|`)\nfollowed by a space.  The division into lines will be preserved in\nthe output, as will any leading spaces; otherwise, the lines will\nbe formatted as markdown.  This is useful for verse and addresses:\n\n    | The limerick packs laughs anatomical\n    | In space that is quite economical.\n    |    But the good ones I've seen\n    |    So seldom are clean\n    | And the clean ones so seldom are comical\n\n    | 200 Main St.\n    | Berkeley, CA 94718\n\nThe lines can be hard-wrapped if needed, but the continuation\nline must begin with a space.\n\n    | The Right Honorable Most Venerable and Righteous Samuel L.\n      Constable, Jr.\n    | 200 Main St.\n    | Berkeley, CA 94718\n\nThis syntax is borrowed from [reStructuredText].\n\nLists\n-----\n\n### Bullet lists ###\n\nA bullet list is a list of bulleted list items.  A bulleted list\nitem begins with a bullet (`*`, `+`, or `-`).  Here is a simple\nexample:\n\n    * one\n    * two\n    * three\n\nThis will produce a \"compact\" list. If you want a \"loose\" list, in which\neach item is formatted as a paragraph, put spaces between the items:\n\n    * one\n\n    * two\n\n    * three\n\nThe bullets need not be flush with the left margin; they may be\nindented one, two, or three spaces. The bullet must be followed\nby whitespace.\n\nList items look best if subsequent lines are flush with the first\nline (after the bullet):\n\n    * here is my first\n      list item.\n    * and my second.\n\nBut markdown also allows a \"lazy\" format:\n\n    * here is my first\n    list item.\n    * and my second.\n\n### The four-space rule ###\n\nA list item may contain multiple paragraphs and other block-level\ncontent. However, subsequent paragraphs must be preceded by a blank line\nand indented four spaces or a tab. The list will look better if the first\nparagraph is aligned with the rest:\n\n      * First paragraph.\n\n        Continued.\n\n      * Second paragraph. With a code block, which must be indented\n        eight spaces:\n\n            { code }\n\nList items may include other lists.  In this case the preceding blank\nline is optional.  The nested list must be indented four spaces or\none tab:\n\n    * fruits\n        + apples\n            - macintosh\n            - red delicious\n        + pears\n        + peaches\n    * vegetables\n        + broccoli\n        + chard\n\nAs noted above, markdown allows you to write list items \"lazily,\" instead of\nindenting continuation lines. However, if there are multiple paragraphs or\nother blocks in a list item, the first line of each must be indented.\n\n    + A lazy, lazy, list\n    item.\n\n    + Another one; this looks\n    bad but is legal.\n\n        Second paragraph of second\n    list item.\n\n**Note:**  Although the four-space rule for continuation paragraphs\ncomes from the official [markdown syntax guide], the reference implementation,\n`Markdown.pl`, does not follow it. So pandoc will give different results than\n`Markdown.pl` when authors have indented continuation paragraphs fewer than\nfour spaces.\n\nThe [markdown syntax guide] is not explicit whether the four-space\nrule applies to *all* block-level content in a list item; it only\nmentions paragraphs and code blocks.  But it implies that the rule\napplies to all block-level content (including nested lists), and\npandoc interprets it that way.\n\n  [markdown syntax guide]:\n    http://daringfireball.net/projects/markdown/syntax#list\n\n### Ordered lists ###\n\nOrdered lists work just like bulleted lists, except that the items\nbegin with enumerators rather than bullets.\n\nIn standard markdown, enumerators are decimal numbers followed\nby a period and a space.  The numbers themselves are ignored, so\nthere is no difference between this list:\n\n    1.  one\n    2.  two\n    3.  three\n\nand this one:\n\n    5.  one\n    7.  two\n    1.  three\n\n#### Extension: `fancy_lists` ####\n\nUnlike standard markdown, Pandoc allows ordered list items to be marked\nwith uppercase and lowercase letters and roman numerals, in addition to\narabic numerals. List markers may be enclosed in parentheses or followed by a\nsingle right-parentheses or period. They must be separated from the\ntext that follows by at least one space, and, if the list marker is a\ncapital letter with a period, by at least two spaces.[^2]\n\n[^2]:  The point of this rule is to ensure that normal paragraphs\n    starting with people's initials, like\n\n        B. Russell was an English philosopher.\n\n    do not get treated as list items.\n\n    This rule will not prevent\n\n        (C) 2007 Joe Smith\n\n    from being interpreted as a list item.  In this case, a backslash\n    escape can be used:\n\n        (C\\) 2007 Joe Smith\n\nThe `fancy_lists` extension also allows '`#`' to be used as an\nordered list marker in place of a numeral:\n\n    #. one\n    #. two\n\n#### Extension: `startnum` ####\n\nPandoc also pays attention to the type of list marker used, and to the\nstarting number, and both of these are preserved where possible in the\noutput format. Thus, the following yields a list with numbers followed\nby a single parenthesis, starting with 9, and a sublist with lowercase\nroman numerals:\n\n     9)  Ninth\n    10)  Tenth\n    11)  Eleventh\n           i. subone\n          ii. subtwo\n         iii. subthree\n\nPandoc will start a new list each time a different type of list\nmarker is used.  So, the following will create three lists:\n\n    (2) Two\n    (5) Three\n    1.  Four\n    *   Five\n\nIf default list markers are desired, use `#.`:\n\n    #.  one\n    #.  two\n    #.  three\n\n\n### Definition lists ###\n\n#### Extension: `definition_lists` ####\n\nPandoc supports definition lists, using the syntax of\n[PHP Markdown Extra] with some extensions.[^3]\n\n    Term 1\n\n    :   Definition 1\n\n    Term 2 with *inline markup*\n\n    :   Definition 2\n\n            { some code, part of Definition 2 }\n\n        Third paragraph of definition 2.\n\nEach term must fit on one line, which may optionally be followed by\na blank line, and must be followed by one or more definitions.\nA definition begins with a colon or tilde, which may be indented one\nor two spaces.\n\nA term may have multiple definitions, and each definition may consist of one or\nmore block elements (paragraph, code block, list, etc.), each indented four\nspaces or one tab stop.  The body of the definition (including the first line,\naside from the colon or tilde) should be indented four spaces. However,\nas with other markdown lists, you can \"lazily\" omit indentation except\nat the beginning of a paragraph or other block element:\n\n    Term 1\n\n    :   Definition\n    with lazy continuation.\n\n        Second paragraph of the definition.\n\nIf you leave space before the definition (as in the example above),\nthe text of the definition will be treated as a paragraph.  In some\noutput formats, this will mean greater spacing between term/definition\npairs. For a more compact definition list, omit the space before the\ndefinition:\n\n    Term 1\n      ~ Definition 1\n\n    Term 2\n      ~ Definition 2a\n      ~ Definition 2b\n\nNote that space between items in a definition list is required.\n(A variant that loosens this requirement, but disallows \"lazy\"\nhard wrapping, can be activated with `compact_definition_lists`: see\n[Non-pandoc extensions](#non-pandoc-extensions), below.)\n\n[^3]:  I have been influenced by the suggestions of [David Wheeler](http://www.justatheory.com/computers/markup/modest-markdown-proposal.html).\n\n[PHP Markdown Extra]: http://www.michelf.com/projects/php-markdown/extra/\n\n\n### Numbered example lists ###\n\n#### Extension: `example_lists` ####\n\nThe special list marker `@` can be used for sequentially numbered\nexamples. The first list item with a `@` marker will be numbered '1',\nthe next '2', and so on, throughout the document. The numbered examples\nneed not occur in a single list; each new list using `@` will take up\nwhere the last stopped. So, for example:\n\n    (@)  My first example will be numbered (1).\n    (@)  My second example will be numbered (2).\n\n    Explanation of examples.\n\n    (@)  My third example will be numbered (3).\n\nNumbered examples can be labeled and referred to elsewhere in the\ndocument:\n\n    (@good)  This is a good example.\n\n    As (@good) illustrates, ...\n\nThe label can be any string of alphanumeric characters, underscores,\nor hyphens.\n\n\n### Compact and loose lists ###\n\nPandoc behaves differently from `Markdown.pl` on some \"edge\ncases\" involving lists.  Consider this source:\n\n    +   First\n    +   Second:\n    \t-   Fee\n    \t-   Fie\n    \t-   Foe\n\n    +   Third\n\nPandoc transforms this into a \"compact list\" (with no `<p>` tags around\n\"First\", \"Second\", or \"Third\"), while markdown puts `<p>` tags around\n\"Second\" and \"Third\" (but not \"First\"), because of the blank space\naround \"Third\". Pandoc follows a simple rule: if the text is followed by\na blank line, it is treated as a paragraph. Since \"Second\" is followed\nby a list, and not a blank line, it isn't treated as a paragraph. The\nfact that the list is followed by a blank line is irrelevant. (Note:\nPandoc works this way even when the `markdown_strict` format is specified. This\nbehavior is consistent with the official markdown syntax description,\neven though it is different from that of `Markdown.pl`.)\n\n\n### Ending a list ###\n\nWhat if you want to put an indented code block after a list?\n\n    -   item one\n    -   item two\n\n        { my code block }\n\nTrouble! Here pandoc (like other markdown implementations) will treat\n`{ my code block }` as the second paragraph of item two, and not as\na code block.\n\nTo \"cut off\" the list after item two, you can insert some non-indented\ncontent, like an HTML comment, which won't produce visible output in\nany format:\n\n    -   item one\n    -   item two\n\n    <!-- end of list -->\n\n        { my code block }\n\nYou can use the same trick if you want two consecutive lists instead\nof one big list:\n\n    1.  one\n    2.  two\n    3.  three\n\n    <!-- -->\n\n    1.  uno\n    2.  dos\n    3.  tres\n\nHorizontal rules\n----------------\n\nA line containing a row of three or more `*`, `-`, or `_` characters\n(optionally separated by spaces) produces a horizontal rule:\n\n    *  *  *  *\n\n    ---------------\n\n\nTables\n------\n\nFour kinds of tables may be used. The first three kinds presuppose the use of\na fixed-width font, such as Courier. The fourth kind can be used with\nproportionally spaced fonts, as it does not require lining up columns.\n\n#### Extension: `table_captions` ####\n\nA caption may optionally be provided with all 4 kinds of tables (as\nillustrated in the examples below). A caption is a paragraph beginning\nwith the string `Table:` (or just `:`), which will be stripped off.\nIt may appear either before or after the table.\n\n#### Extension: `simple_tables` ####\n\nSimple tables look like this:\n\n      Right     Left     Center     Default\n    -------     ------ ----------   -------\n         12     12        12            12\n        123     123       123          123\n          1     1          1             1\n\n    Table:  Demonstration of simple table syntax.\n\nThe headers and table rows must each fit on one line.  Column\nalignments are determined by the position of the header text relative\nto the dashed line below it:[^4]\n\n  - If the dashed line is flush with the header text on the right side\n    but extends beyond it on the left, the column is right-aligned.\n  - If the dashed line is flush with the header text on the left side\n    but extends beyond it on the right, the column is left-aligned.\n  - If the dashed line extends beyond the header text on both sides,\n    the column is centered.\n  - If the dashed line is flush with the header text on both sides,\n    the default alignment is used (in most cases, this will be left).\n\n[^4]:  This scheme is due to Michel Fortin, who proposed it on the\n       [Markdown discussion list](http://six.pairlist.net/pipermail/markdown-discuss/2005-March/001097.html).\n\nThe table must end with a blank line, or a line of dashes followed by\na blank line.\n\nThe column headers may be omitted, provided a dashed line is used\nto end the table. For example:\n\n    -------     ------ ----------   -------\n         12     12        12             12\n        123     123       123           123\n          1     1          1              1\n    -------     ------ ----------   -------\n\nWhen headers are omitted, column alignments are determined on the basis\nof the first line of the table body. So, in the tables above, the columns\nwould be right, left, center, and right aligned, respectively.\n\n#### Extension: `multiline_tables` ####\n\nMultiline tables allow headers and table rows to span multiple lines\nof text (but cells that span multiple columns or rows of the table are\nnot supported).  Here is an example:\n\n    -------------------------------------------------------------\n     Centered   Default           Right Left\n      Header    Aligned         Aligned Aligned\n    ----------- ------- --------------- -------------------------\n       First    row                12.0 Example of a row that\n                                        spans multiple lines.\n\n      Second    row                 5.0 Here's another one. Note\n                                        the blank line between\n                                        rows.\n    -------------------------------------------------------------\n\n    Table: Here's the caption. It, too, may span\n    multiple lines.\n\nThese work like simple tables, but with the following differences:\n\n  - They must begin with a row of dashes, before the header text\n    (unless the headers are omitted).\n  - They must end with a row of dashes, then a blank line.\n  - The rows must be separated by blank lines.\n\nIn multiline tables, the table parser pays attention to the widths of\nthe columns, and the writers try to reproduce these relative widths in\nthe output. So, if you find that one of the columns is too narrow in the\noutput, try widening it in the markdown source.\n\nHeaders may be omitted in multiline tables as well as simple tables:\n\n    ----------- ------- --------------- -------------------------\n       First    row                12.0 Example of a row that\n                                        spans multiple lines.\n\n      Second    row                 5.0 Here's another one. Note\n                                        the blank line between\n                                        rows.\n    ----------- ------- --------------- -------------------------\n\n    : Here's a multiline table without headers.\n\nIt is possible for a multiline table to have just one row, but the row\nshould be followed by a blank line (and then the row of dashes that ends\nthe table), or the table may be interpreted as a simple table.\n\n#### Extension: `grid_tables` ####\n\nGrid tables look like this:\n\n    : Sample grid table.\n\n    +---------------+---------------+--------------------+\n    | Fruit         | Price         | Advantages         |\n    +===============+===============+====================+\n    | Bananas       | $1.34         | - built-in wrapper |\n    |               |               | - bright color     |\n    +---------------+---------------+--------------------+\n    | Oranges       | $2.10         | - cures scurvy     |\n    |               |               | - tasty            |\n    +---------------+---------------+--------------------+\n\nThe row of `=`s separates the header from the table body, and can be\nomitted for a headerless table. The cells of grid tables may contain\narbitrary block elements (multiple paragraphs, code blocks, lists,\netc.). Alignments are not supported, nor are cells that span multiple\ncolumns or rows. Grid tables can be created easily using [Emacs table mode].\n\n  [Emacs table mode]: http://table.sourceforge.net/\n\n#### Extension: `pipe_tables` ####\n\nPipe tables look like this:\n\n    | Right | Left | Default | Center |\n    |------:|:-----|---------|:------:|\n    |   12  |  12  |    12   |    12  |\n    |  123  |  123 |   123   |   123  |\n    |    1  |    1 |     1   |     1  |\n\n      : Demonstration of pipe table syntax.\n\nThe syntax is [the same as in PHP markdown extra].  The beginning and\nending pipe characters are optional, but pipes are required between all\ncolumns.  The colons indicate column alignment as shown.  The header\ncannot be omitted.  To simulate a headerless table, include a header\nwith blank cells.\n\nSince the pipes indicate column boundaries, columns need not be vertically\naligned, as they are in the above example.  So, this is a perfectly\nlegal (though ugly) pipe table:\n\n    fruit| price\n    -----|-----:\n    apple|2.05\n    pear|1.37\n    orange|3.09\n\nThe cells of pipe tables cannot contain block elements like paragraphs\nand lists, and cannot span multiple lines.  Note also that in LaTeX/PDF\noutput, the cells produced by pipe tables will not wrap, since there\nis no information available about relative widths.  If you want content\nto wrap within cells, use multiline or grid tables.\n\n  [the same as in PHP markdown extra]:\n    http://michelf.ca/projects/php-markdown/extra/#table\n\nNote:  Pandoc also recognizes pipe tables of the following\nform, as can be produced by Emacs' orgtbl-mode:\n\n    | One | Two   |\n    |-----+-------|\n    | my  | table |\n    | is  | nice  |\n\nThe difference is that `+` is used instead of `|`. Other orgtbl features\nare not supported. In particular, to get non-default column alignment,\nyou'll need to add colons as above.\n\nMetadata blocks\n---------------\n\n#### Extension: `pandoc_title_block` ####\n\nIf the file begins with a title block\n\n    % title\n    % author(s) (separated by semicolons)\n    % date\n\nit will be parsed as bibliographic information, not regular text.  (It\nwill be used, for example, in the title of standalone LaTeX or HTML\noutput.)  The block may contain just a title, a title and an author,\nor all three elements. If you want to include an author but no\ntitle, or a title and a date but no author, you need a blank line:\n\n    %\n    % Author\n\n    % My title\n    %\n    % June 15, 2006\n\nThe title may occupy multiple lines, but continuation lines must\nbegin with leading space, thus:\n\n    % My title\n      on multiple lines\n\nIf a document has multiple authors, the authors may be put on\nseparate lines with leading space, or separated by semicolons, or\nboth.  So, all of the following are equivalent:\n\n    % Author One\n      Author Two\n\n    % Author One; Author Two\n\n    % Author One;\n      Author Two\n\nThe date must fit on one line.\n\nAll three metadata fields may contain standard inline formatting\n(italics, links, footnotes, etc.).\n\nTitle blocks will always be parsed, but they will affect the output only\nwhen the `--standalone` (`-s`) option is chosen. In HTML output, titles\nwill appear twice: once in the document head -- this is the title that\nwill appear at the top of the window in a browser -- and once at the\nbeginning of the document body. The title in the document head can have\nan optional prefix attached (`--title-prefix` or `-T` option). The title\nin the body appears as an H1 element with class \"title\", so it can be\nsuppressed or reformatted with CSS. If a title prefix is specified with\n`-T` and no title block appears in the document, the title prefix will\nbe used by itself as the HTML title.\n\nThe man page writer extracts a title, man page section number, and\nother header and footer information from the title line. The title\nis assumed to be the first word on the title line, which may optionally\nend with a (single-digit) section number in parentheses. (There should\nbe no space between the title and the parentheses.)  Anything after\nthis is assumed to be additional footer and header text. A single pipe\ncharacter (`|`) should be used to separate the footer text from the header\ntext.  Thus,\n\n    % PANDOC(1)\n\nwill yield a man page with the title `PANDOC` and section 1.\n\n    % PANDOC(1) Pandoc User Manuals\n\nwill also have \"Pandoc User Manuals\" in the footer.\n\n    % PANDOC(1) Pandoc User Manuals | Version 4.0\n\nwill also have \"Version 4.0\" in the header.\n\n#### Extension: `yaml_metadata_block` ####\n\nA YAML metadata block is a valid YAML object, delimited by a line of three\nhyphens (`---`) at the top and a line of three hyphens (`---`) or three dots\n(`...`) at the bottom.  A YAML metadata block may occur anywhere in the\ndocument, but if it is not at the beginning, it must be preceded by a blank\nline.  (Note that, because of the way pandoc concatenates input files when\nseveral are provided, you may also keep the metadata in a separate YAML file\nand pass it to pandoc as an argument, along with your markdown files:\n\n    pandoc chap1.md chap2.md chap3.md metadata.yaml -s -o book.html\n\nJust be sure that the YAML file begins with `---` and ends with `---` or\n`...`.)\n\nMetadata will be taken from the fields of the YAML object and added to any\nexisting document metadata.  Metadata can contain lists and objects (nested\narbitrarily), but all string scalars will be interpreted as markdown.  Fields\nwith names ending in an underscore will be ignored by pandoc.  (They may be\ngiven a role by external processors.)\n\nA document may contain multiple metadata blocks.  The metadata fields will\nbe combined through a *left-biased union*:  if two metadata blocks attempt\nto set the same field, the value from the first block will be taken.\n\nWhen pandoc is used with `-t markdown` to create a markdown document,\na YAML metadata block will be produced only if the `-s/--standalone`\noption is used.  All of the metadata will appear in a single block\nat the beginning of the document.\n\nNote that YAML escaping rules must be followed. Thus, for example,\nif a title contains a colon, it must be quoted.  The pipe character\n(`|`) can be used to begin an indented block that will be interpreted\nliterally, without need for escaping.  This form is necessary\nwhen the field contains blank lines:\n\n    ---\n    title:  'This is the title: it contains a colon'\n    author:\n    - name: Author One\n      affiliation: University of Somewhere\n    - name: Author Two\n      affiliation: University of Nowhere\n    tags: [nothing, nothingness]\n    abstract: |\n      This is the abstract.\n\n      It consists of two paragraphs.\n    ...\n\nTemplate variables will be set automatically from the metadata.  Thus, for\nexample, in writing HTML, the variable `abstract` will be set to the HTML\nequivalent of the markdown in the `abstract` field:\n\n    <p>This is the abstract.</p>\n    <p>It consists of two paragraphs.</p>\n\nNote: The `author` variable in the default templates expects a simple list or\nstring.  To use the structured authors in the example, you would need a\ncustom template.  For example:\n\n    $for(author)$\n    $if(author.name)$\n    $author.name$$if(author.affiliation)$ ($author.affiliation$)$endif$\n    $else$\n    $author$\n    $endif$\n    $endfor$\n\n\nBackslash escapes\n-----------------\n\n#### Extension: `all_symbols_escapable` ####\n\nExcept inside a code block or inline code, any punctuation or space\ncharacter preceded by a backslash will be treated literally, even if it\nwould normally indicate formatting.  Thus, for example, if one writes\n\n    *\\*hello\\**\n\none will get\n\n    <em>*hello*</em>\n\ninstead of\n\n    <strong>hello</strong>\n\nThis rule is easier to remember than standard markdown's rule,\nwhich allows only the following characters to be backslash-escaped:\n\n    \\`*_{}[]()>#+-.!\n\n(However, if the `markdown_strict` format is used, the standard markdown rule\nwill be used.)\n\nA backslash-escaped space is parsed as a nonbreaking space.  It will\nappear in TeX output as `~` and in HTML and XML as `\\&#160;` or\n`\\&nbsp;`.\n\nA backslash-escaped newline (i.e. a backslash occurring at the end of\na line) is parsed as a hard line break.  It will appear in TeX output as\n`\\\\` and in HTML as `<br />`.  This is a nice alternative to\nmarkdown's \"invisible\" way of indicating hard line breaks using\ntwo trailing spaces on a line.\n\nBackslash escapes do not work in verbatim contexts.\n\nSmart punctuation\n-----------------\n\n#### Extension ####\n\nIf the `--smart` option is specified, pandoc will produce typographically\ncorrect output, converting straight quotes to curly quotes, `---` to\nem-dashes, `--` to en-dashes, and `...` to ellipses. Nonbreaking spaces\nare inserted after certain abbreviations, such as \"Mr.\"\n\nNote:  if your LaTeX template uses the `csquotes` package, pandoc will\ndetect automatically this and use `\\enquote{...}` for quoted text.\n\nInline formatting\n-----------------\n\n### Emphasis ###\n\nTo *emphasize* some text, surround it with `*`s or `_`, like this:\n\n    This text is _emphasized with underscores_, and this\n    is *emphasized with asterisks*.\n\nDouble `*` or `_` produces **strong emphasis**:\n\n    This is **strong emphasis** and __with underscores__.\n\nA `*` or `_` character surrounded by spaces, or backslash-escaped,\nwill not trigger emphasis:\n\n    This is * not emphasized *, and \\*neither is this\\*.\n\n#### Extension: `intraword_underscores` ####\n\nBecause `_` is sometimes used inside words and identifiers,\npandoc does not interpret a `_` surrounded by alphanumeric\ncharacters as an emphasis marker.  If you want to emphasize\njust part of a word, use `*`:\n\n    feas*ible*, not feas*able*.\n\n\n### Strikeout ###\n\n#### Extension: `strikeout` ####\n\nTo strikeout a section of text with a horizontal line, begin and end it\nwith `~~`. Thus, for example,\n\n    This ~~is deleted text.~~\n\n\n### Superscripts and subscripts ###\n\n#### Extension: `superscript`, `subscript` ####\n\nSuperscripts may be written by surrounding the superscripted text by `^`\ncharacters; subscripts may be written by surrounding the subscripted\ntext by `~` characters.  Thus, for example,\n\n    H~2~O is a liquid.  2^10^ is 1024.\n\nIf the superscripted or subscripted text contains spaces, these spaces\nmust be escaped with backslashes.  (This is to prevent accidental\nsuperscripting and subscripting through the ordinary use of `~` and `^`.)\nThus, if you want the letter P with 'a cat' in subscripts, use\n`P~a\\ cat~`, not `P~a cat~`.\n\n\n### Verbatim ###\n\nTo make a short span of text verbatim, put it inside backticks:\n\n    What is the difference between `>>=` and `>>`?\n\nIf the verbatim text includes a backtick, use double backticks:\n\n    Here is a literal backtick `` ` ``.\n\n(The spaces after the opening backticks and before the closing\nbackticks will be ignored.)\n\nThe general rule is that a verbatim span starts with a string\nof consecutive backticks (optionally followed by a space)\nand ends with a string of the same number of backticks (optionally\npreceded by a space).\n\nNote that backslash-escapes (and other markdown constructs) do not\nwork in verbatim contexts:\n\n    This is a backslash followed by an asterisk: `\\*`.\n\n#### Extension: `inline_code_attributes` ####\n\nAttributes can be attached to verbatim text, just as with\n[fenced code blocks](#fenced-code-blocks):\n\n    `<$>`{.haskell}\n\n### Small caps ###\n\nTo write small caps, you can use an HTML span tag:\n\n    <span style=\"font-variant:small-caps;\">Small caps</span>\n\n(The semicolon is optional and there may be space after the\ncolon.) This will work in all output formats that support small caps.\n\nMath\n----\n\n#### Extension: `tex_math_dollars` ####\n\nAnything between two `$` characters will be treated as TeX math.  The\nopening `$` must have a non-space character immediately to its right,\nwhile the closing `$` must have a non-space character immediately to its\nleft, and must not be followed immediately by a digit.  Thus,\n`$20,000 and $30,000` won't parse as math.  If for some reason\nyou need to enclose text in literal `$` characters, backslash-escape\nthem and they won't be treated as math delimiters.\n\nTeX math will be printed in all output formats. How it is rendered\ndepends on the output format:\n\nMarkdown, LaTeX, Org-Mode, ConTeXt\n  ~ It will appear verbatim between `$` characters.\n\nreStructuredText\n  ~ It will be rendered using an interpreted text role `:math:`, as described\n    [here](http://docutils.sourceforge.net/docs/ref/rst/roles.html#math)\n\nAsciiDoc\n  ~ It will be rendered as `latexmath:[...]`.\n\nTexinfo\n  ~ It will be rendered inside a `@math` command.\n\ngroff man\n  ~ It will be rendered verbatim without `$`'s.\n\nMediaWiki, DokuWiki\n  ~ It will be rendered inside `<math>` tags.\n\nTextile\n  ~ It will be rendered inside `<span class=\"math\">` tags.\n\nRTF, OpenDocument, ODT\n  ~ It will be rendered, if possible, using unicode characters,\n    and will otherwise appear verbatim.\n\nDocbook\n  ~ If the `--mathml` flag is used, it will be rendered using mathml\n    in an `inlineequation` or `informalequation` tag.  Otherwise it\n    will be rendered, if possible, using unicode characters.\n\nDocx\n  ~ It will be rendered using OMML math markup.\n\nFictionBook2\n  ~ If the `--webtex` option is used, formulas are rendered as images\n    using Google Charts or other compatible web service, downloaded\n    and embedded in the e-book. Otherwise, they will appear verbatim.\n\nHTML, Slidy, DZSlides, S5, EPUB\n  ~ The way math is rendered in HTML will depend on the\n    command-line options selected:\n\n    1.  The default is to render TeX math as far as possible using unicode\n        characters, as with RTF, DocBook, and OpenDocument output. Formulas\n        are put inside a `span` with `class=\"math\"`, so that they may be\n        styled differently from the surrounding text if needed.\n\n    2.  If the `--latexmathml` option is used, TeX math will be displayed\n        between `$` or `$$` characters and put in `<span>` tags with class `LaTeX`.\n        The [LaTeXMathML] script will be used to render it as formulas.\n        (This trick does not work in all browsers, but it works in Firefox.\n        In browsers that do not support LaTeXMathML, TeX math will appear\n        verbatim between `$` characters.)\n\n    3.  If the `--jsmath` option is used, TeX math will be put inside\n        `<span>` tags (for inline math) or `<div>` tags (for display math)\n        with class `math`.  The [jsMath] script will be used to render\n        it.\n\n    4.  If the `--mimetex` option is used, the [mimeTeX] CGI script will\n        be called to generate images for each TeX formula. This should\n        work in all browsers. The `--mimetex` option takes an optional URL\n        as argument. If no URL is specified, it will be assumed that the\n        mimeTeX CGI script is at `/cgi-bin/mimetex.cgi`.\n\n    5.  If the `--gladtex` option is used, TeX formulas will be enclosed\n        in `<eq>` tags in the HTML output.  The resulting `htex` file may then\n        be processed by [gladTeX], which will produce image files for each\n        formula and an `html` file with links to these images.  So, the\n        procedure is:\n\n            pandoc -s --gladtex myfile.txt -o myfile.htex\n            gladtex -d myfile-images myfile.htex\n            # produces myfile.html and images in myfile-images\n\n    6.  If the `--webtex` option is used, TeX formulas will be converted\n        to `<img>` tags that link to an external script that converts\n        formulas to images. The formula will be URL-encoded and concatenated\n        with the URL provided. If no URL is specified, the Google Chart\n        API will be used (`http://chart.apis.google.com/chart?cht=tx&chl=`).\n\n    7.  If the `--mathjax` option is used, TeX math will be displayed\n        between `\\(...\\)` (for inline math) or `\\[...\\]` (for display\n        math) and put in `<span>` tags with class `math`.\n        The [MathJax] script will be used to render it as formulas.\n\nRaw HTML\n--------\n\n#### Extension: `raw_html` ####\n\nMarkdown allows you to insert raw HTML (or DocBook) anywhere in a document\n(except verbatim contexts, where `<`, `>`, and `&` are interpreted\nliterally).  (Technically this is not an extension, since standard\nmarkdown allows it, but it has been made an extension so that it can\nbe disabled if desired.)\n\nThe raw HTML is passed through unchanged in HTML, S5, Slidy, Slideous,\nDZSlides, EPUB, Markdown, and Textile output, and suppressed in other\nformats.\n\n#### Extension: `markdown_in_html_blocks` ####\n\nStandard markdown allows you to include HTML \"blocks\":  blocks\nof HTML between balanced tags that are separated from the surrounding text\nwith blank lines, and start and end at the left margin.  Within\nthese blocks, everything is interpreted as HTML, not markdown;\nso (for example), `*` does not signify emphasis.\n\nPandoc behaves this way when the `markdown_strict` format is used; but\nby default, pandoc interprets material between HTML block tags as markdown.\nThus, for example, Pandoc will turn\n\n    <table>\n    <tr>\n    <td>*one*</td>\n    <td>[a link](http://google.com)</td>\n    </tr>\n    </table>\n\ninto\n\n    <table>\n    <tr>\n    <td><em>one</em></td>\n    <td><a href=\"http://google.com\">a link</a></td>\n    </tr>\n    </table>\n\nwhereas `Markdown.pl` will preserve it as is.\n\nThere is one exception to this rule:  text between `<script>` and\n`<style>` tags is not interpreted as markdown.\n\nThis departure from standard markdown should make it easier to mix\nmarkdown with HTML block elements.  For example, one can surround\na block of markdown text with `<div>` tags without preventing it\nfrom being interpreted as markdown.\n\n#### Extension: `native_divs` ####\n\nUse native pandoc `Div` blocks for content inside `<div>` tags.\nFor the most part this should give the same output as\n`markdown_in_html_blocks`, but it makes it easier to write pandoc\nfilters to manipulate groups of blocks.\n\n#### Extension: `native_spans` ####\n\nUse native pandoc `Span` blocks for content inside `<span>` tags.\nFor the most part this should give the same output as `raw_html`,\nbut it makes it easier to write pandoc filters to manipulate groups\nof inlines.\n\nRaw TeX\n-------\n\n#### Extension: `raw_tex` ####\n\nIn addition to raw HTML, pandoc allows raw LaTeX, TeX, and ConTeXt to be\nincluded in a document. Inline TeX commands will be preserved and passed\nunchanged to the LaTeX and ConTeXt writers. Thus, for example, you can use\nLaTeX to include BibTeX citations:\n\n    This result was proved in \\cite{jones.1967}.\n\nNote that in LaTeX environments, like\n\n    \\begin{tabular}{|l|l|}\\hline\n    Age & Frequency \\\\ \\hline\n    18--25  & 15 \\\\\n    26--35  & 33 \\\\\n    36--45  & 22 \\\\ \\hline\n    \\end{tabular}\n\nthe material between the begin and end tags will be interpreted as raw\nLaTeX, not as markdown.\n\nInline LaTeX is ignored in output formats other than Markdown, LaTeX,\nand ConTeXt.\n\nLaTeX macros\n------------\n\n#### Extension: `latex_macros` ####\n\nFor output formats other than LaTeX, pandoc will parse LaTeX `\\newcommand` and\n`\\renewcommand` definitions and apply the resulting macros to all LaTeX\nmath.  So, for example, the following will work in all output formats,\nnot just LaTeX:\n\n    \\newcommand{\\tuple}[1]{\\langle #1 \\rangle}\n\n    $\\tuple{a, b, c}$\n\nIn LaTeX output, the `\\newcommand` definition will simply be passed\nunchanged to the output.\n\n\nLinks\n-----\n\nMarkdown allows links to be specified in several ways.\n\n### Automatic links ###\n\nIf you enclose a URL or email address in pointy brackets, it\nwill become a link:\n\n    <http://google.com>\n    <sam@green.eggs.ham>\n\n### Inline links ###\n\nAn inline link consists of the link text in square brackets,\nfollowed by the URL in parentheses. (Optionally, the URL can\nbe followed by a link title, in quotes.)\n\n    This is an [inline link](/url), and here's [one with\n    a title](http://fsf.org \"click here for a good time!\").\n\nThere can be no space between the bracketed part and the parenthesized part.\nThe link text can contain formatting (such as emphasis), but the title cannot.\n\nEmail addresses in inline links are not autodetected, so they have to be\nprefixed with `mailto`:\n\n    [Write me!](mailto:sam@green.eggs.ham)\n\n### Reference links ###\n\nAn *explicit* reference link has two parts, the link itself and the link\ndefinition, which may occur elsewhere in the document (either\nbefore or after the link).\n\nThe link consists of link text in square brackets, followed by a label in\nsquare brackets. (There can be space between the two.) The link definition\nconsists of the bracketed label, followed by a colon and a space, followed by\nthe URL, and optionally (after a space) a link title either in quotes or in\nparentheses.  The label must not be parseable as a citation (assuming\nthe `citations` extension is enabled):  citations take precedence over\nlink labels.\n\nHere are some examples:\n\n    [my label 1]: /foo/bar.html  \"My title, optional\"\n    [my label 2]: /foo\n    [my label 3]: http://fsf.org (The free software foundation)\n    [my label 4]: /bar#special  'A title in single quotes'\n\nThe URL may optionally be surrounded by angle brackets:\n\n    [my label 5]: <http://foo.bar.baz>\n\nThe title may go on the next line:\n\n    [my label 3]: http://fsf.org\n      \"The free software foundation\"\n\nNote that link labels are not case sensitive.  So, this will work:\n\n    Here is [my link][FOO]\n\n    [Foo]: /bar/baz\n\nIn an *implicit* reference link, the second pair of brackets is\nempty:\n\n    See [my website][].\n\n    [my website]: http://foo.bar.baz\n\nNote:  In `Markdown.pl` and most other markdown implementations,\nreference link definitions cannot occur in nested constructions\nsuch as list items or block quotes.  Pandoc lifts this arbitrary\nseeming restriction.  So the following is fine in pandoc, though\nnot in most other implementations:\n\n    > My block [quote].\n    >\n    > [quote]: /foo\n\n#### Extension: `shortcut_reference_links` ####\n\nIn a *shortcut* reference link, the second pair of brackets may\nbe omitted entirely:\n\n    See [my website].\n\n    [my website]: http://foo.bar.baz\n\n### Internal links ###\n\nTo link to another section of the same document, use the automatically\ngenerated identifier (see [Header identifiers in HTML, LaTeX, and\nConTeXt](#header-identifiers-in-html-latex-and-context), below).\nFor example:\n\n    See the [Introduction](#introduction).\n\nor\n\n    See the [Introduction].\n\n    [Introduction]: #introduction\n\nInternal links are currently supported for HTML formats (including\nHTML slide shows and EPUB), LaTeX, and ConTeXt.\n\nImages\n------\n\nA link immediately preceded by a `!` will be treated as an image.\nThe link text will be used as the image's alt text:\n\n    ![la lune](lalune.jpg \"Voyage to the moon\")\n\n    ![movie reel]\n\n    [movie reel]: movie.gif\n\n#### Extension: `implicit_figures` ####\n\nAn image occurring by itself in a paragraph will be rendered as\na figure with a caption.[^5] (In LaTeX, a figure environment will be\nused; in HTML, the image will be placed in a `div` with class\n`figure`, together with a caption in a `p` with class `caption`.)\nThe image's alt text will be used as the caption.\n\n    ![This is the caption](/url/of/image.png)\n\n[^5]: This feature is not yet implemented for RTF, OpenDocument, or\n    ODT. In those formats, you'll just get an image in a paragraph by\n    itself, with no caption.\n\nIf you just want a regular inline image, just make sure it is not\nthe only thing in the paragraph. One way to do this is to insert a\nnonbreaking space after the image:\n\n    ![This image won't be a figure](/url/of/image.png)\\\n\n\nFootnotes\n---------\n\n#### Extension: `footnotes` ####\n\nPandoc's markdown allows footnotes, using the following syntax:\n\n    Here is a footnote reference,[^1] and another.[^longnote]\n\n    [^1]: Here is the footnote.\n\n    [^longnote]: Here's one with multiple blocks.\n\n        Subsequent paragraphs are indented to show that they\n    belong to the previous footnote.\n\n            { some.code }\n\n        The whole paragraph can be indented, or just the first\n        line.  In this way, multi-paragraph footnotes work like\n        multi-paragraph list items.\n\n    This paragraph won't be part of the note, because it\n    isn't indented.\n\nThe identifiers in footnote references may not contain spaces, tabs,\nor newlines.  These identifiers are used only to correlate the\nfootnote reference with the note itself; in the output, footnotes\nwill be numbered sequentially.\n\nThe footnotes themselves need not be placed at the end of the\ndocument.  They may appear anywhere except inside other block elements\n(lists, block quotes, tables, etc.).\n\n#### Extension: `inline_notes` ####\n\nInline footnotes are also allowed (though, unlike regular notes,\nthey cannot contain multiple paragraphs).  The syntax is as follows:\n\n    Here is an inline note.^[Inlines notes are easier to write, since\n    you don't have to pick an identifier and move down to type the\n    note.]\n\nInline and regular footnotes may be mixed freely.\n\n\nCitations\n---------\n\n#### Extension: `citations` ####\n\nUsing an external filter, `pandoc-citeproc`, pandoc can automatically generate\ncitations and a bibliography in a number of styles.  Basic usage is\n\n    pandoc --filter pandoc-citeproc myinput.txt\n\nIn order to use this feature, you will need to specify a bibliography file\nusing the `bibliography` metadata field in a YAML metadata section, or\n`--bibliography` command line argument. You can supply multiple `--bibliography`\narguments or set `bibliography` metadata field to YAML array, if you want to\nuse multiple bibliography files.\nThe bibliography may have any of these formats:\n\n  Format            File extension\n  ------------      --------------\n  BibLaTeX          .bib\n  BibTeX            .bibtex\n  Copac             .copac\n  CSL JSON          .json\n  CSL YAML          .yaml\n  EndNote           .enl\n  EndNote XML       .xml\n  ISI               .wos\n  MEDLINE           .medline\n  MODS              .mods\n  RIS               .ris\n\nNote that `.bib` can generally be used with both BibTeX and BibLaTeX\nfiles, but you can use `.bibtex` to force BibTeX.\n\nNote that `pandoc-citeproc --bib2json` and `pandoc-citeproc --bib2yaml`\ncan produce `.json` and `.yaml` files from any of the supported formats.\n\nIn-field markup: In bibtex and biblatex databases, pandoc-citeproc parses\n(a subset of) LaTeX markup; in CSL JSON databases, an HTML-like markup\n([specs](http://docs.citationstyles.org/en/1.0/release-notes.html#rich-text-markup-within-fields));\nand in CSL YAML databases, pandoc markdown. `pandoc-citeproc -j` and `-y`\ninterconvert these markup formats as far as possible.\n\nAs an alternative to specifying a bibliography file, you can include\nthe citation data directly in the `references` field of the\ndocument's YAML metadata. The field should contain an array of\nYAML-encoded references, for example:\n\n    ---\n    references:\n    - type: article-journal\n      id: WatsonCrick1953\n      author:\n      - family: Watson\n        given: J. D.\n      - family: Crick\n        given: F. H. C.\n      issued:\n        date-parts:\n        - - 1953\n          - 4\n          - 25\n      title: 'Molecular structure of nucleic acids: a structure for deoxyribose\n        nucleic acid'\n      title-short: Molecular structure of nucleic acids\n      container-title: Nature\n      volume: 171\n      issue: 4356\n      page: 737-738\n      DOI: 10.1038/171737a0\n      URL: http://www.nature.com/nature/journal/v171/n4356/abs/171737a0.html\n      language: en-GB\n    ...\n\n(`pandoc-citeproc --bib2yaml` can produce these from a bibliography file in one\nof the supported formats.)\n\nBy default, `pandoc-citeproc` will use the Chicago Manual of Style author-date\nformat for citations and references.  To use another style, you will need to\nspecify a [CSL] 1.0 style file in the `csl` metadata field.  A repository of CSL\nstyles can be found at <https://github.com/citation-style-language/styles>.  See\nalso <http://zotero.org/styles> for easy browsing. A primer on creating and\nmodifying CSL styles can be found at\n<http://citationstyles.org/downloads/primer.html>.\n\nCitations go inside square brackets and are separated by semicolons.\nEach citation must have a key, composed of '@' + the citation\nidentifier from the database, and may optionally have a prefix,\na locator, and a suffix.  The citation key must begin with a letter, digit,\nor `_`, and may contain alphanumerics, `_`, and internal punctuation\ncharacters (`:.#$%&-+?<>~/`).  Here are some examples:\n\n    Blah blah [see @doe99, pp. 33-35; also @smith04, ch. 1].\n\n    Blah blah [@doe99, pp. 33-35, 38-39 and *passim*].\n\n    Blah blah [@smith04; @doe99].\n\nA minus sign (`-`) before the `@` will suppress mention of\nthe author in the citation.  This can be useful when the\nauthor is already mentioned in the text:\n\n    Smith says blah [-@smith04].\n\nYou can also write an in-text citation, as follows:\n\n    @smith04 says blah.\n\n    @smith04 [p. 33] says blah.\n\nIf the style calls for a list of works cited, it will be placed\nat the end of the document.  Normally, you will want to end your\ndocument with an appropriate header:\n\n    last paragraph...\n\n    # References\n\nThe bibliography will be inserted after this header.  Note that\nthe `unnumbered` class will be added to this header, so that the\nsection will not be numbered.\n\nIf you want to include items in the bibliography without actually\nciting them in the body text, you can define a dummy `nocite` metadata\nfield and put the citations there:\n\n    ---\n    nocite: |\n      @item1, @item2\n    ...\n\n    @item3\n\nIn this example, the document will contain a citation for `item3`\nonly, but the bibliography will contain entries for `item1`, `item2`, and\n`item3`.\n\nFor LaTeX or PDF output, you can also use NatBib or BibLaTeX\nto render bibliography. In order to do so, specify bibliography files as\noutlined above, and add `--natbib` or `--biblatex` argument to `pandoc`\ninvocation. Bear in mind that bibliography files have to be in respective\nformat (either BibTeX or BibLaTeX).\n\nNon-pandoc extensions\n---------------------\n\nThe following markdown syntax extensions are not enabled by default\nin pandoc, but may be enabled by adding `+EXTENSION` to the format\nname, where `EXTENSION` is the name of the extension.  Thus, for\nexample, `markdown+hard_line_breaks` is markdown with hard line breaks.\n\n#### Extension: `lists_without_preceding_blankline` ####\n\nAllow a list to occur right after a paragraph, with no intervening\nblank space.\n\n#### Extension: `hard_line_breaks` ####\n\nCauses all newlines within a paragraph to be interpreted as hard line\nbreaks instead of spaces.\n\n#### Extension: `ignore_line_breaks` ####\n\nCauses newlines within a paragraph to be ignored, rather than being\ntreated as spaces or as hard line breaks.  This option is intended for\nuse with East Asian languages where spaces are not used between words,\nbut text is divided into lines for readability.\n\n#### Extension: `tex_math_single_backslash` ####\n\nCauses anything between `\\(` and `\\)` to be interpreted as inline\nTeX math, and anything between `\\[` and `\\]` to be interpreted\nas display TeX math.  Note: a drawback of this extension is that\nit precludes escaping `(` and `[`.\n\n#### Extension: `tex_math_double_backslash` ####\n\nCauses anything between `\\\\(` and `\\\\)` to be interpreted as inline\nTeX math, and anything between `\\\\[` and `\\\\]` to be interpreted\nas display TeX math.\n\n#### Extension: `markdown_attribute` ####\n\nBy default, pandoc interprets material inside block-level tags as markdown.\nThis extension changes the behavior so that markdown is only parsed\ninside block-level tags if the tags have the attribute `markdown=1`.\n\n#### Extension: `mmd_title_block` ####\n\nEnables a [MultiMarkdown] style title block at the top of\nthe document, for example:\n\n    Title:   My title\n    Author:  John Doe\n    Date:    September 1, 2008\n    Comment: This is a sample mmd title block, with\n             a field spanning multiple lines.\n\nSee the MultiMarkdown documentation for details.  If `pandoc_title_block` or\n`yaml_metadata_block` is enabled, it will take precedence over\n`mmd_title_block`.\n\n  [MultiMarkdown]: http://fletcherpenney.net/multimarkdown/\n\n#### Extension: `abbreviations` ####\n\nParses PHP Markdown Extra abbreviation keys, like\n\n    *[HTML]: Hyper Text Markup Language\n\nNote that the pandoc document model does not support\nabbreviations, so if this extension is enabled, abbreviation keys are\nsimply skipped (as opposed to being parsed as paragraphs).\n\n#### Extension: `autolink_bare_uris` ####\n\nMakes all absolute URIs into links, even when not surrounded by\npointy braces `<...>`.\n\n#### Extension: `ascii_identifiers` ####\n\nCauses the identifiers produced by `auto_identifiers` to be pure ASCII.\nAccents are stripped off of accented latin letters, and non-latin\nletters are omitted.\n\n#### Extension: `link_attributes` ####\n\nParses multimarkdown style key-value attributes on link and image references.\nNote that pandoc's internal document model provides nowhere to put\nthese, so they are presently just ignored.\n\n#### Extension: `mmd_header_identifiers` ####\n\nParses multimarkdown style header identifiers (in square brackets,\nafter the header but before any trailing `#`s in an ATX header).\n\n#### Extension: `compact_definition_lists` ####\n\nActivates the definition list syntax of pandoc 1.12.x and earlier.\nThis syntax differs from the one described [above](#definition-lists)\nin several respects:\n\n  - No blank line is required between consecutive items of the\n    definition list.\n  - To get a \"tight\" or \"compact\" list, omit space between consecutive\n    items; the space between a term and its definition does not affect\n    anything.\n  - Lazy wrapping of paragraphs is not allowed:  the entire definition must\n    be indented four spaces.[^6]\n\n[^6]:  To see why laziness is incompatible with relaxing the requirement\n    of a blank line between items, consider the following example:\n\n        bar\n        :    definition\n        foo\n        :    definition\n\n    Is this a single list item with two definitions of \"bar,\" the first of\n    which is lazily wrapped, or two list items?  To remove the ambiguity\n    we must either disallow lazy wrapping or require a blank line between\n    list items.\n\nMarkdown variants\n-----------------\n\nIn addition to pandoc's extended markdown, the following markdown\nvariants are supported:\n\n`markdown_phpextra` (PHP Markdown Extra)\n:   `footnotes`, `pipe_tables`, `raw_html`, `markdown_attribute`,\n    `fenced_code_blocks`, `definition_lists`, `intraword_underscores`,\n    `header_attributes`, `abbreviations`, `shortcut_reference_links`.\n\n`markdown_github` (GitHub-flavored Markdown)\n:   `pipe_tables`, `raw_html`, `tex_math_single_backslash`,\n    `fenced_code_blocks`, `auto_identifiers`,\n    `ascii_identifiers`, `backtick_code_blocks`, `autolink_bare_uris`,\n    `intraword_underscores`, `strikeout`, `hard_line_breaks`,\n    `shortcut_reference_links`.\n\n`markdown_mmd` (MultiMarkdown)\n:   `pipe_tables` `raw_html`, `markdown_attribute`, `link_attributes`,\n    `raw_tex`, `tex_math_double_backslash`, `intraword_underscores`,\n    `mmd_title_block`, `footnotes`, `definition_lists`,\n    `all_symbols_escapable`, `implicit_header_references`,\n    `auto_identifiers`, `mmd_header_identifiers`,\n    `shortcut_reference_links`.\n\n`markdown_strict` (Markdown.pl)\n:   `raw_html`\n\nExtensions with formats other than markdown\n-------------------------------------------\n\nSome of the extensions discussed above can be used with formats\nother than markdown:\n\n* `auto_identifiers` can be used with `latex`, `rst`, `mediawiki`,\n  and `textile` input (and is used by default).\n\n* `tex_math_dollars`, `tex_math_single_backslash`, and\n  `tex_math_double_backslash` can be used with `html` input.\n  (This is handy for reading web pages formatted using MathJax,\n  for example.)\n\nProducing slide shows with Pandoc\n=================================\n\nYou can use Pandoc to produce an HTML + javascript slide presentation\nthat can be viewed via a web browser.  There are five ways to do this,\nusing [S5], [DZSlides], [Slidy], [Slideous], or [reveal.js].\nYou can also produce a PDF slide show using LaTeX [beamer].\n\nHere's the markdown source for a simple slide show, `habits.txt`:\n\n    % Habits\n    % John Doe\n    % March 22, 2005\n\n    # In the morning\n\n    ## Getting up\n\n    - Turn off alarm\n    - Get out of bed\n\n    ## Breakfast\n\n    - Eat eggs\n    - Drink coffee\n\n    # In the evening\n\n    ## Dinner\n\n    - Eat spaghetti\n    - Drink wine\n\n    ------------------\n\n    ![picture of spaghetti](images/spaghetti.jpg)\n\n    ## Going to sleep\n\n    - Get in bed\n    - Count sheep\n\nTo produce an HTML/javascript slide show, simply type\n\n    pandoc -t FORMAT -s habits.txt -o habits.html\n\nwhere `FORMAT` is either `s5`, `slidy`, `slideous`, `dzslides`, or `revealjs`.\n\nFor Slidy, Slideous, reveal.js, and S5, the file produced by pandoc with the\n`-s/--standalone` option embeds a link to javascripts and CSS files, which are\nassumed to be available at the relative path `s5/default` (for S5), `slideous`\n(for Slideous), `reveal.js` (for reveal.js), or at the Slidy website at\n`w3.org` (for Slidy).  (These paths can be changed by setting the `slidy-url`,\n`slideous-url`, `revealjs-url`, or `s5-url` variables; see `--variable`,\nabove.) For DZSlides, the (relatively short) javascript and css are included in\nthe file by default.\n\nWith all HTML slide formats, the `--self-contained` option can be used to\nproduce a single file that contains all of the data necessary to display the\nslide show, including linked scripts, stylesheets, images, and videos.\n\nTo produce a PDF slide show using beamer, type\n\n    pandoc -t beamer habits.txt -o habits.pdf\n\nNote that a reveal.js slide show can also be converted to a PDF\nby printing it to a file from the browser.\n\nStructuring the slide show\n--------------------------\n\nBy default, the *slide level* is the highest header level in\nthe hierarchy that is followed immediately by content, and not another\nheader, somewhere in the document. In the example above, level 1 headers\nare always followed by level 2 headers, which are followed by content,\nso 2 is the slide level.  This default can be overridden using\nthe `--slide-level` option.\n\nThe document is carved up into slides according to the following\nrules:\n\n  * A horizontal rule always starts a new slide.\n\n  * A header at the slide level always starts a new slide.\n\n  * Headers *below* the slide level in the hierarchy create\n    headers *within* a slide.\n\n  * Headers *above* the slide level in the hierarchy create\n    \"title slides,\" which just contain the section title\n    and help to break the slide show into sections.\n\n  * A title page is constructed automatically from the document's title\n    block, if present.  (In the case of beamer, this can be disabled\n    by commenting out some lines in the default template.)\n\nThese rules are designed to support many different styles of slide show. If\nyou don't care about structuring your slides into sections and subsections,\nyou can just use level 1 headers for all each slide. (In that case, level 1\nwill be the slide level.) But you can also structure the slide show into\nsections, as in the example above.\n\nNote:  in reveal.js slide shows, if slide level is 2, a two-dimensional\nlayout will be produced, with level 1 headers building horizontally\nand level 2 headers building vertically.  It is not recommended that\nyou use deeper nesting of section levels with reveal.js.\n\nIncremental lists\n-----------------\n\nBy default, these writers produce lists that display \"all at once.\"\nIf you want your lists to display incrementally (one item at a time),\nuse the `-i` option. If you want a particular list to depart from the\ndefault (that is, to display incrementally without the `-i` option and\nall at once with the `-i` option), put it in a block quote:\n\n    > - Eat spaghetti\n    > - Drink wine\n\nIn this way incremental and nonincremental lists can be mixed in\na single document.\n\nInserting pauses\n----------------\n\nYou can add \"pauses\" within a slide by including a paragraph containing\nthree dots, separated by spaces:\n\n    # Slide with a pause\n\n    content before the pause\n\n    . . .\n\n    content after the pause\n\nStyling the slides\n------------------\n\nYou can change the style of HTML slides by putting customized CSS files\nin `$DATADIR/s5/default` (for S5), `$DATADIR/slidy` (for Slidy),\nor `$DATADIR/slideous` (for Slideous),\nwhere `$DATADIR` is the user data directory (see `--data-dir`, above).\nThe originals may be found in pandoc's system data directory (generally\n`$CABALDIR/pandoc-VERSION/s5/default`). Pandoc will look there for any\nfiles it does not find in the user data directory.\n\nFor dzslides, the CSS is included in the HTML file itself, and may\nbe modified there.\n\nFor reveal.js, themes can be used by setting the `theme` variable,\nfor example:\n\n    -V theme=moon\n\nOr you can specify a custom stylesheet using the `--css` option.\n\nTo style beamer slides, you can specify a beamer \"theme\" or \"colortheme\"\nusing the `-V` option:\n\n    pandoc -t beamer habits.txt -V theme:Warsaw -o habits.pdf\n\nNote that header attributes will turn into slide attributes\n(on a `<div>` or `<section>`) in HTML slide formats, allowing you\nto style individual slides.  In Beamer, the only header attribute\nthat affects slides is the `allowframebreaks` class, which sets the\n`allowframebreaks` option, causing multiple slides to be created\nif the content overfills the frame.  This is recommended especially for\nbibliographies:\n\n    # References {.allowframebreaks}\n\nSpeaker notes\n-------------\n\nreveal.js has good support for speaker notes.  You can add notes to your\nmarkdown document thus:\n\n    <div class=\"notes\">\n    This is my note.\n\n    - It can contain markdown\n    - like this list\n\n    </div>\n\nTo show the notes window, press `s` while viewing the presentation.\nNotes are not yet supported for other slide formats, but the notes\nwill not appear on the slides themselves.\n\nMarking frames \"fragile\" in beamer\n----------------------------------\n\nSometimes it is necessary to add the LaTeX `[fragile]` option to\na frame in beamer (for example, when using the `minted` environment).\nThis can be forced by adding the `fragile` class to the header\nintroducing the slide:\n\n    # Fragile slide {.fragile}\n\nEPUB Metadata\n=============\n\nEPUB metadata may be specified using the `--epub-metadata` option, but\nif the source document is markdown, it is better to use a YAML metadata\nblock.  Here is an example:\n\n    ---\n    title:\n    - type: main\n      text: My Book\n    - type: subtitle\n      text: An investigation of metadata\n    creator:\n    - role: author\n      text: John Smith\n    - role: editor\n      text: Sarah Jones\n    identifier:\n    - scheme: DOI\n      text: doi:10.234234.234/33\n    publisher:  My Press\n    rights: \194\169 2007 John Smith, CC BY-NC\n    ...\n\nThe following fields are recognized:\n\n`identifier`\n  ~ Either a string value or an object with fields `text` and\n    `scheme`.  Valid values for `scheme` are `ISBN-10`,\n    `GTIN-13`, `UPC`, `ISMN-10`, `DOI`, `LCCN`, `GTIN-14`,\n    `ISBN-13`, `Legal deposit number`, `URN`, `OCLC`,\n    `ISMN-13`, `ISBN-A`, `JP`, `OLCC`.\n\n`title`\n  ~ Either a string value, or an object with fields `file-as` and\n    `type`, or a list of such objects.  Valid values for `type` are\n    `main`, `subtitle`, `short`, `collection`, `edition`, `extended`.\n\n`creator`\n  ~ Either a string value, or an object with fields `role`, `file-as`,\n    and `text`, or a list of such objects.  Valid values for `role` are\n    [marc relators](http://www.loc.gov/marc/relators/relaterm.html), but\n    pandoc will attempt to translate the human-readable versions\n    (like \"author\" and \"editor\") to the appropriate marc relators.\n\n`contributor`\n  ~ Same format as `creator`.\n\n`date`\n  ~ A string value in `YYYY-MM-DD` format.  (Only the year is necessary.)\n    Pandoc will attempt to convert other common date formats.\n\n`language`\n  ~ A string value in [RFC5646] format.  Pandoc will default to the local\n    language if nothing is specified.\n\n`subject`\n  ~ A string value or a list of such values.\n\n`description`\n  ~ A string value.\n\n`type`\n  ~ A string value.\n\n`format`\n  ~ A string value.\n\n`relation`\n  ~ A string value.\n\n`coverage`\n  ~ A string value.\n\n`rights`\n  ~ A string value.\n\n`cover-image`\n  ~ A string value (path to cover image).\n\n`stylesheet`\n  ~ A string value (path to CSS stylesheet).\n\n`page-progression-direction`\n  ~ Either `ltr` or `rtl`. Specifies the `page-progression-direction`\n    spine [attribute][EPUBspine].\n\nLiterate Haskell support\n========================\n\nIf you append `+lhs` (or `+literate_haskell`) to an appropriate input or output\nformat (`markdown`, `markdown_strict`, `rst`, or `latex` for input or output;\n`beamer`, `html` or `html5` for output only), pandoc will treat the document as\nliterate Haskell source. This means that\n\n  - In markdown input, \"bird track\" sections will be parsed as Haskell\n    code rather than block quotations.  Text between `\\begin{code}`\n    and `\\end{code}` will also be treated as Haskell code.\n\n  - In markdown output, code blocks with classes `haskell` and `literate`\n    will be rendered using bird tracks, and block quotations will be\n    indented one space, so they will not be treated as Haskell code.\n    In addition, headers will be rendered setext-style (with underlines)\n    rather than atx-style (with '#' characters). (This is because ghc\n    treats '#' characters in column 1 as introducing line numbers.)\n\n  - In restructured text input, \"bird track\" sections will be parsed\n    as Haskell code.\n\n  - In restructured text output, code blocks with class `haskell` will\n    be rendered using bird tracks.\n\n  - In LaTeX input, text in `code` environments will be parsed as\n    Haskell code.\n\n  - In LaTeX output, code blocks with class `haskell` will be rendered\n    inside `code` environments.\n\n  - In HTML output, code blocks with class `haskell` will be rendered\n    with class `literatehaskell` and bird tracks.\n\nExamples:\n\n    pandoc -f markdown+lhs -t html\n\nreads literate Haskell source formatted with markdown conventions and writes\nordinary HTML (without bird tracks).\n\n    pandoc -f markdown+lhs -t html+lhs\n\nwrites HTML with the Haskell code in bird tracks, so it can be copied\nand pasted as literate Haskell source.\n\nSyntax highlighting\n===================\n\nPandoc will automatically highlight syntax in fenced code blocks that\nare marked with a language name.  (See [Extension:\n`inline_code_attributes`] and [Extension: `fenced_code_attributes`],\nabove.)  The Haskell library [highlighting-kate] is used for\nhighlighting, which works in HTML, Docx, and LaTeX/PDF output.\nThe color scheme can be selected using the `--highlight-style` option.\nThe default color scheme is `pygments`, which imitates the default color\nscheme used by the Python library pygments, but pygments is not actually\nused to do the highlighting.\n\nTo see a list of language names that pandoc will recognize, type\n`pandoc --version`.\n\nTo disable highlighting, use the `--no-highlight` option.\n\nCustom writers\n==============\n\nPandoc can be extended with custom writers written in [lua].  (Pandoc\nincludes a lua interpreter, so lua need not be installed separately.)\n\nTo use a custom writer, simply specify the path to the lua script\nin place of the output format. For example:\n\n    pandoc -t data/sample.lua\n\nCreating a custom writer requires writing a lua function for each\npossible element in a pandoc document.  To get a documented example\nwhich you can modify according to your needs, do\n\n    pandoc --print-default-data-file sample.lua\n\nAuthors\n=======\n\n\194\169 2006-2015 John MacFarlane (jgm@berkeley.edu). Released under the\n[GPL], version 2 or greater.  This software carries no warranty of\nany kind.  (See COPYRIGHT for full copyright and warranty notices.)\n\nContributors include\nAaron Wolen,\nAlbert Krewinkel,\nAlexander Kondratskiy,\nAlexander Sulfrian,\nAlexander V Vershilov,\nAlfred Wechselberger,\nAndreas L\195\182\195\182w,\nAntoine Latter,\nArlo O'Keeffe,\nArtyom Kazak,\nBen Gamari,\nBeni Cherniavsky-Paskin,\nBjorn Buckwalter,\nBradley Kuhn,\nBrent Yorgey,\nBryan O'Sullivan,\nB. Scott Michel,\nCaleb McDaniel,\nCalvin Beck,\nChristoffer Ackelman,\nChristoffer Sawicki,\nClare Macrae,\nClint Adams,\nConal Elliott,\nCraig S. Bosma,\nDaniel Bergey,\nDaniel T. Staal,\nDavid Lazar,\nDavid R\195\182thlisberger,\nDenis Laxalde,\nDouglas Calvert,\nDouglas F. Calvert,\nEric Kow,\nEric Seidel,\nFlorian Eitel,\nFran\195\167ois Gannaz,\nFreiric Barral,\nFyodor Sheremetyev,\nGabor Pali,\nGavin Beatty,\nGreg Maslov,\nGr\195\169gory Bataille,\nGreg Rundlett,\ngwern,\nGwern Branwen,\nHans-Peter Deifel,\nHenry de Valence,\nIlya V. Portnov,\ninfinity0x,\nJaime Marqui\204\129nez Ferra\204\129ndiz,\nJames Aspnes,\nJamie F. Olson,\nJason Ronallo,\nJeff Arnold,\nJeff Runningen,\nJens Petersen,\nJ\195\169r\195\169my Bobbio,\nJesse Rosenthal,\nJ. Lewis Muir,\nJoe Hillenbrand,\nJohn MacFarlane,\nJonas Smedegaard,\nJonathan Daugherty,\nJosef Svenningsson,\nJose Luis Duran,\nJulien Cretel,\nJustin Bogner,\nKelsey Hightower,\nKonstantin Zudov,\nLars-Dominik Braun,\nLuke Plant,\nMark Szepieniec,\nMark Wright,\nMasayoshi Takahashi,\nMatej Kollar,\nMathias Schenner,\nMatthew Pickering,\nMatthias C. M. Troffaes,\nMax Bolingbroke,\nMax Rydahl Andersen,\nmb21,\nMerijn Verstraaten,\nMichael Snoyman,\nMichael Thompson,\nMinRK,\nNathan Gass,\nNeil Mayhew,\nNick Bart,\nNicolas Kaiser,\nNikolay Yakimov,\nPaulo Tanimoto,\nPaul Rivier,\nPeter Wang,\nPhilippe Ombredanne,\nPhillip Alday,\nPuneeth Chaganti,\nqerub,\nRalf Stephan,\nRecai Okta\197\159,\nrodja.trappe,\nRyanGlScott,\nScott Morrison,\nSergei Trofimovich,\nSergey Astanin,\nShahbaz Youssefi,\nShaun Attfield,\nshreevatsa.public,\nSimon Hengel,\nSumit Sahrawat,\ntakahashim,\nthsutton,\nTim Lin,\nTimothy Humphries,\nTodd Sifleet,\nTom Leese,\nUli K\195\182hler,\nV\195\161clav Zeman,\nViktor Kronvall,\nVincent, and\nWikiwide.\n\n[markdown]: http://daringfireball.net/projects/markdown/\n[reStructuredText]: http://docutils.sourceforge.net/docs/ref/rst/introduction.html\n[S5]: http://meyerweb.com/eric/tools/s5/\n[Slidy]: http://www.w3.org/Talks/Tools/Slidy/\n[Slideous]: http://goessner.net/articles/slideous/\n[HTML]:  http://www.w3.org/TR/html40/\n[HTML 5]:  http://www.w3.org/TR/html5/\n[XHTML]:  http://www.w3.org/TR/xhtml1/\n[LaTeX]: http://www.latex-project.org/\n[beamer]: http://www.tex.ac.uk/CTAN/macros/latex/contrib/beamer\n[ConTeXt]: http://www.pragma-ade.nl/\n[RTF]:  http://en.wikipedia.org/wiki/Rich_Text_Format\n[DocBook]:  http://www.docbook.org/\n[OPML]: http://dev.opml.org/spec2.html\n[OpenDocument]: http://opendocument.xml.org/\n[ODT]: http://en.wikipedia.org/wiki/OpenDocument\n[Textile]: http://redcloth.org/textile\n[MediaWiki markup]: http://www.mediawiki.org/wiki/Help:Formatting\n[DokuWiki markup]: https://www.dokuwiki.org/dokuwiki\n[TWiki markup]: http://twiki.org/cgi-bin/view/TWiki/TextFormattingRules\n[Haddock markup]: http://www.haskell.org/haddock/doc/html/ch03s08.html\n[groff man]: http://developer.apple.com/DOCUMENTATION/Darwin/Reference/ManPages/man7/groff_man.7.html\n[Haskell]:  http://www.haskell.org/\n[GNU Texinfo]: http://www.gnu.org/software/texinfo/\n[Emacs Org-Mode]: http://orgmode.org\n[AsciiDoc]: http://www.methods.co.nz/asciidoc/\n[GPL]: http://www.gnu.org/copyleft/gpl.html \"GNU General Public License\"\n[DZSlides]: http://paulrouget.com/dzslides/\n[ISO 8601 format]: http://www.w3.org/TR/NOTE-datetime\n[Word docx]: http://www.microsoft.com/interop/openup/openxml/default.aspx\n[PDF]: http://www.adobe.com/pdf/\n[reveal.js]: http://lab.hakim.se/reveal-js/\n[FictionBook2]: http://www.fictionbook.org/index.php/Eng:XML_Schema_Fictionbook_2.1\n[lua]: http://www.lua.org\n[marc relators]: http://www.loc.gov/marc/relators/relaterm.html\n[RFC5646]: http://tools.ietf.org/html/rfc5646\n[InDesign ICML]: https://www.adobe.com/content/dam/Adobe/en/devnet/indesign/cs55-docs/IDML/idml-specification.pdf\n[txt2tags]: http://txt2tags.org/\n[EPUB]: http://idpf.org/epub\n[EPUBspine]: http://www.idpf.org/epub/301/spec/epub-publications.html#sec-spine-elem\n[KaTeX]: https://github.com/Khan/KaTeX\n[CommonMark]: http://commonmark.org\n[highlighting-kate]: http://github.com/jgm/highlighting-kate\n"
# 7 "src/Text/Pandoc/Data.hsb"
                                     ) : [("epub.css","/* This defines styles and classes used in the book */\nbody { margin: 5%; text-align: justify; font-size: medium; }\ncode { font-family: monospace; }\nh1 { text-align: left; }\nh2 { text-align: left; }\nh3 { text-align: left; }\nh4 { text-align: left; }\nh5 { text-align: left; }\nh6 { text-align: left; }\nh1.title { }\nh2.author { }\nh3.date { }\nol.toc { padding: 0; margin-left: 1em; }\nol.toc li { list-style-type: none; margin: 0; padding: 0; }\na.footnoteRef { vertical-align: super; }"),("LaTeXMathML.js","/*\nLaTeXMathML.js from http://math.etsu.edu/LaTeXMathML/\nAdapted by Jeff Knisely and Douglas Woodall from ASCIIMathML.js v. 1.4.7,\n(c) 2005 Peter Jipsen http://www.chapman.edu/~jipsen.\nReleased under the GNU General Public License version 2 or later.\nSee the GNU General Public License (at http://www.gnu.org/copyleft/gpl.html)\nfor more details.\n*/\nvar checkForMathML=true;var notifyIfNoMathML=true;var alertIfNoMathML=false;var mathcolor=\"\";var mathfontfamily=\"\";var showasciiformulaonhover=true;var isIE=document.createElementNS==null;if(document.getElementById==null)\nalert(\"This webpage requires a recent browser such as \\nMozilla/Netscape 7+ or Internet Explorer 6+MathPlayer\")\nfunction AMcreateElementXHTML(t){if(isIE)return document.createElement(t);else return document.createElementNS(\"http://www.w3.org/1999/xhtml\",t);}\nfunction AMnoMathMLNote(){var nd=AMcreateElementXHTML(\"h3\");nd.setAttribute(\"align\",\"center\")\nnd.appendChild(AMcreateElementXHTML(\"p\"));nd.appendChild(document.createTextNode(\"To view the \"));var an=AMcreateElementXHTML(\"a\");an.appendChild(document.createTextNode(\"LaTeXMathML\"));an.setAttribute(\"href\",\"http://www.maths.nott.ac.uk/personal/drw/lm.html\");nd.appendChild(an);nd.appendChild(document.createTextNode(\" notation use Internet Explorer 6+\"));an=AMcreateElementXHTML(\"a\");an.appendChild(document.createTextNode(\"MathPlayer\"));an.setAttribute(\"href\",\"http://www.dessci.com/en/products/mathplayer/download.htm\");nd.appendChild(an);nd.appendChild(document.createTextNode(\" or Netscape/Mozilla/Firefox\"));nd.appendChild(AMcreateElementXHTML(\"p\"));return nd;}\nfunction AMisMathMLavailable(){if(navigator.appName.slice(0,8)==\"Netscape\")\nif(navigator.appVersion.slice(0,1)>=\"5\")return null;else return AMnoMathMLNote();else if(navigator.appName.slice(0,9)==\"Microsoft\")\ntry{var ActiveX=new ActiveXObject(\"MathPlayer.Factory.1\");return null;}catch(e){return AMnoMathMLNote();}\nelse return AMnoMathMLNote();}\nvar AMcal=[0xEF35,0x212C,0xEF36,0xEF37,0x2130,0x2131,0xEF38,0x210B,0x2110,0xEF39,0xEF3A,0x2112,0x2133,0xEF3B,0xEF3C,0xEF3D,0xEF3E,0x211B,0xEF3F,0xEF40,0xEF41,0xEF42,0xEF43,0xEF44,0xEF45,0xEF46];var AMfrk=[0xEF5D,0xEF5E,0x212D,0xEF5F,0xEF60,0xEF61,0xEF62,0x210C,0x2111,0xEF63,0xEF64,0xEF65,0xEF66,0xEF67,0xEF68,0xEF69,0xEF6A,0x211C,0xEF6B,0xEF6C,0xEF6D,0xEF6E,0xEF6F,0xEF70,0xEF71,0x2128];var AMbbb=[0xEF8C,0xEF8D,0x2102,0xEF8E,0xEF8F,0xEF90,0xEF91,0x210D,0xEF92,0xEF93,0xEF94,0xEF95,0xEF96,0x2115,0xEF97,0x2119,0x211A,0x211D,0xEF98,0xEF99,0xEF9A,0xEF9B,0xEF9C,0xEF9D,0xEF9E,0x2124];var CONST=0,UNARY=1,BINARY=2,INFIX=3,LEFTBRACKET=4,RIGHTBRACKET=5,SPACE=6,UNDEROVER=7,DEFINITION=8,TEXT=9,BIG=10,LONG=11,STRETCHY=12,MATRIX=13;var AMsqrt={input:\"\\\\sqrt\",tag:\"msqrt\",output:\"sqrt\",ttype:UNARY},AMroot={input:\"\\\\root\",tag:\"mroot\",output:\"root\",ttype:BINARY},AMfrac={input:\"\\\\frac\",tag:\"mfrac\",output:\"/\",ttype:BINARY},AMover={input:\"\\\\stackrel\",tag:\"mover\",output:\"stackrel\",ttype:BINARY},AMatop={input:\"\\\\atop\",tag:\"mfrac\",output:\"\",ttype:INFIX},AMchoose={input:\"\\\\choose\",tag:\"mfrac\",output:\"\",ttype:INFIX},AMsub={input:\"_\",tag:\"msub\",output:\"_\",ttype:INFIX},AMsup={input:\"^\",tag:\"msup\",output:\"^\",ttype:INFIX},AMtext={input:\"\\\\mathrm\",tag:\"mtext\",output:\"text\",ttype:TEXT},AMmbox={input:\"\\\\mbox\",tag:\"mtext\",output:\"mbox\",ttype:TEXT};var AMsymbols=[{input:\"\\\\alpha\",tag:\"mi\",output:\"\\u03B1\",ttype:CONST},{input:\"\\\\beta\",tag:\"mi\",output:\"\\u03B2\",ttype:CONST},{input:\"\\\\gamma\",tag:\"mi\",output:\"\\u03B3\",ttype:CONST},{input:\"\\\\delta\",tag:\"mi\",output:\"\\u03B4\",ttype:CONST},{input:\"\\\\epsilon\",tag:\"mi\",output:\"\\u03B5\",ttype:CONST},{input:\"\\\\varepsilon\",tag:\"mi\",output:\"\\u025B\",ttype:CONST},{input:\"\\\\zeta\",tag:\"mi\",output:\"\\u03B6\",ttype:CONST},{input:\"\\\\eta\",tag:\"mi\",output:\"\\u03B7\",ttype:CONST},{input:\"\\\\theta\",tag:\"mi\",output:\"\\u03B8\",ttype:CONST},{input:\"\\\\vartheta\",tag:\"mi\",output:\"\\u03D1\",ttype:CONST},{input:\"\\\\iota\",tag:\"mi\",output:\"\\u03B9\",ttype:CONST},{input:\"\\\\kappa\",tag:\"mi\",output:\"\\u03BA\",ttype:CONST},{input:\"\\\\lambda\",tag:\"mi\",output:\"\\u03BB\",ttype:CONST},{input:\"\\\\mu\",tag:\"mi\",output:\"\\u03BC\",ttype:CONST},{input:\"\\\\nu\",tag:\"mi\",output:\"\\u03BD\",ttype:CONST},{input:\"\\\\xi\",tag:\"mi\",output:\"\\u03BE\",ttype:CONST},{input:\"\\\\pi\",tag:\"mi\",output:\"\\u03C0\",ttype:CONST},{input:\"\\\\varpi\",tag:\"mi\",output:\"\\u03D6\",ttype:CONST},{input:\"\\\\rho\",tag:\"mi\",output:\"\\u03C1\",ttype:CONST},{input:\"\\\\varrho\",tag:\"mi\",output:\"\\u03F1\",ttype:CONST},{input:\"\\\\varsigma\",tag:\"mi\",output:\"\\u03C2\",ttype:CONST},{input:\"\\\\sigma\",tag:\"mi\",output:\"\\u03C3\",ttype:CONST},{input:\"\\\\tau\",tag:\"mi\",output:\"\\u03C4\",ttype:CONST},{input:\"\\\\upsilon\",tag:\"mi\",output:\"\\u03C5\",ttype:CONST},{input:\"\\\\phi\",tag:\"mi\",output:\"\\u03C6\",ttype:CONST},{input:\"\\\\varphi\",tag:\"mi\",output:\"\\u03D5\",ttype:CONST},{input:\"\\\\chi\",tag:\"mi\",output:\"\\u03C7\",ttype:CONST},{input:\"\\\\psi\",tag:\"mi\",output:\"\\u03C8\",ttype:CONST},{input:\"\\\\omega\",tag:\"mi\",output:\"\\u03C9\",ttype:CONST},{input:\"\\\\Gamma\",tag:\"mo\",output:\"\\u0393\",ttype:CONST},{input:\"\\\\Delta\",tag:\"mo\",output:\"\\u0394\",ttype:CONST},{input:\"\\\\Theta\",tag:\"mo\",output:\"\\u0398\",ttype:CONST},{input:\"\\\\Lambda\",tag:\"mo\",output:\"\\u039B\",ttype:CONST},{input:\"\\\\Xi\",tag:\"mo\",output:\"\\u039E\",ttype:CONST},{input:\"\\\\Pi\",tag:\"mo\",output:\"\\u03A0\",ttype:CONST},{input:\"\\\\Sigma\",tag:\"mo\",output:\"\\u03A3\",ttype:CONST},{input:\"\\\\Upsilon\",tag:\"mo\",output:\"\\u03A5\",ttype:CONST},{input:\"\\\\Phi\",tag:\"mo\",output:\"\\u03A6\",ttype:CONST},{input:\"\\\\Psi\",tag:\"mo\",output:\"\\u03A8\",ttype:CONST},{input:\"\\\\Omega\",tag:\"mo\",output:\"\\u03A9\",ttype:CONST},{input:\"\\\\frac12\",tag:\"mo\",output:\"\\u00BD\",ttype:CONST},{input:\"\\\\frac14\",tag:\"mo\",output:\"\\u00BC\",ttype:CONST},{input:\"\\\\frac34\",tag:\"mo\",output:\"\\u00BE\",ttype:CONST},{input:\"\\\\frac13\",tag:\"mo\",output:\"\\u2153\",ttype:CONST},{input:\"\\\\frac23\",tag:\"mo\",output:\"\\u2154\",ttype:CONST},{input:\"\\\\frac15\",tag:\"mo\",output:\"\\u2155\",ttype:CONST},{input:\"\\\\frac25\",tag:\"mo\",output:\"\\u2156\",ttype:CONST},{input:\"\\\\frac35\",tag:\"mo\",output:\"\\u2157\",ttype:CONST},{input:\"\\\\frac45\",tag:\"mo\",output:\"\\u2158\",ttype:CONST},{input:\"\\\\frac16\",tag:\"mo\",output:\"\\u2159\",ttype:CONST},{input:\"\\\\frac56\",tag:\"mo\",output:\"\\u215A\",ttype:CONST},{input:\"\\\\frac18\",tag:\"mo\",output:\"\\u215B\",ttype:CONST},{input:\"\\\\frac38\",tag:\"mo\",output:\"\\u215C\",ttype:CONST},{input:\"\\\\frac58\",tag:\"mo\",output:\"\\u215D\",ttype:CONST},{input:\"\\\\frac78\",tag:\"mo\",output:\"\\u215E\",ttype:CONST},{input:\"\\\\pm\",tag:\"mo\",output:\"\\u00B1\",ttype:CONST},{input:\"\\\\mp\",tag:\"mo\",output:\"\\u2213\",ttype:CONST},{input:\"\\\\triangleleft\",tag:\"mo\",output:\"\\u22B2\",ttype:CONST},{input:\"\\\\triangleright\",tag:\"mo\",output:\"\\u22B3\",ttype:CONST},{input:\"\\\\cdot\",tag:\"mo\",output:\"\\u22C5\",ttype:CONST},{input:\"\\\\star\",tag:\"mo\",output:\"\\u22C6\",ttype:CONST},{input:\"\\\\ast\",tag:\"mo\",output:\"\\u002A\",ttype:CONST},{input:\"\\\\times\",tag:\"mo\",output:\"\\u00D7\",ttype:CONST},{input:\"\\\\div\",tag:\"mo\",output:\"\\u00F7\",ttype:CONST},{input:\"\\\\circ\",tag:\"mo\",output:\"\\u2218\",ttype:CONST},{input:\"\\\\bullet\",tag:\"mo\",output:\"\\u2022\",ttype:CONST},{input:\"\\\\oplus\",tag:\"mo\",output:\"\\u2295\",ttype:CONST},{input:\"\\\\ominus\",tag:\"mo\",output:\"\\u2296\",ttype:CONST},{input:\"\\\\otimes\",tag:\"mo\",output:\"\\u2297\",ttype:CONST},{input:\"\\\\bigcirc\",tag:\"mo\",output:\"\\u25CB\",ttype:CONST},{input:\"\\\\oslash\",tag:\"mo\",output:\"\\u2298\",ttype:CONST},{input:\"\\\\odot\",tag:\"mo\",output:\"\\u2299\",ttype:CONST},{input:\"\\\\land\",tag:\"mo\",output:\"\\u2227\",ttype:CONST},{input:\"\\\\wedge\",tag:\"mo\",output:\"\\u2227\",ttype:CONST},{input:\"\\\\lor\",tag:\"mo\",output:\"\\u2228\",ttype:CONST},{input:\"\\\\vee\",tag:\"mo\",output:\"\\u2228\",ttype:CONST},{input:\"\\\\cap\",tag:\"mo\",output:\"\\u2229\",ttype:CONST},{input:\"\\\\cup\",tag:\"mo\",output:\"\\u222A\",ttype:CONST},{input:\"\\\\sqcap\",tag:\"mo\",output:\"\\u2293\",ttype:CONST},{input:\"\\\\sqcup\",tag:\"mo\",output:\"\\u2294\",ttype:CONST},{input:\"\\\\uplus\",tag:\"mo\",output:\"\\u228E\",ttype:CONST},{input:\"\\\\amalg\",tag:\"mo\",output:\"\\u2210\",ttype:CONST},{input:\"\\\\bigtriangleup\",tag:\"mo\",output:\"\\u25B3\",ttype:CONST},{input:\"\\\\bigtriangledown\",tag:\"mo\",output:\"\\u25BD\",ttype:CONST},{input:\"\\\\dag\",tag:\"mo\",output:\"\\u2020\",ttype:CONST},{input:\"\\\\dagger\",tag:\"mo\",output:\"\\u2020\",ttype:CONST},{input:\"\\\\ddag\",tag:\"mo\",output:\"\\u2021\",ttype:CONST},{input:\"\\\\ddagger\",tag:\"mo\",output:\"\\u2021\",ttype:CONST},{input:\"\\\\lhd\",tag:\"mo\",output:\"\\u22B2\",ttype:CONST},{input:\"\\\\rhd\",tag:\"mo\",output:\"\\u22B3\",ttype:CONST},{input:\"\\\\unlhd\",tag:\"mo\",output:\"\\u22B4\",ttype:CONST},{input:\"\\\\unrhd\",tag:\"mo\",output:\"\\u22B5\",ttype:CONST},{input:\"\\\\sum\",tag:\"mo\",output:\"\\u2211\",ttype:UNDEROVER},{input:\"\\\\prod\",tag:\"mo\",output:\"\\u220F\",ttype:UNDEROVER},{input:\"\\\\bigcap\",tag:\"mo\",output:\"\\u22C2\",ttype:UNDEROVER},{input:\"\\\\bigcup\",tag:\"mo\",output:\"\\u22C3\",ttype:UNDEROVER},{input:\"\\\\bigwedge\",tag:\"mo\",output:\"\\u22C0\",ttype:UNDEROVER},{input:\"\\\\bigvee\",tag:\"mo\",output:\"\\u22C1\",ttype:UNDEROVER},{input:\"\\\\bigsqcap\",tag:\"mo\",output:\"\\u2A05\",ttype:UNDEROVER},{input:\"\\\\bigsqcup\",tag:\"mo\",output:\"\\u2A06\",ttype:UNDEROVER},{input:\"\\\\coprod\",tag:\"mo\",output:\"\\u2210\",ttype:UNDEROVER},{input:\"\\\\bigoplus\",tag:\"mo\",output:\"\\u2A01\",ttype:UNDEROVER},{input:\"\\\\bigotimes\",tag:\"mo\",output:\"\\u2A02\",ttype:UNDEROVER},{input:\"\\\\bigodot\",tag:\"mo\",output:\"\\u2A00\",ttype:UNDEROVER},{input:\"\\\\biguplus\",tag:\"mo\",output:\"\\u2A04\",ttype:UNDEROVER},{input:\"\\\\int\",tag:\"mo\",output:\"\\u222B\",ttype:CONST},{input:\"\\\\oint\",tag:\"mo\",output:\"\\u222E\",ttype:CONST},{input:\":=\",tag:\"mo\",output:\":=\",ttype:CONST},{input:\"\\\\lt\",tag:\"mo\",output:\"<\",ttype:CONST},{input:\"\\\\gt\",tag:\"mo\",output:\">\",ttype:CONST},{input:\"\\\\ne\",tag:\"mo\",output:\"\\u2260\",ttype:CONST},{input:\"\\\\neq\",tag:\"mo\",output:\"\\u2260\",ttype:CONST},{input:\"\\\\le\",tag:\"mo\",output:\"\\u2264\",ttype:CONST},{input:\"\\\\leq\",tag:\"mo\",output:\"\\u2264\",ttype:CONST},{input:\"\\\\leqslant\",tag:\"mo\",output:\"\\u2264\",ttype:CONST},{input:\"\\\\ge\",tag:\"mo\",output:\"\\u2265\",ttype:CONST},{input:\"\\\\geq\",tag:\"mo\",output:\"\\u2265\",ttype:CONST},{input:\"\\\\geqslant\",tag:\"mo\",output:\"\\u2265\",ttype:CONST},{input:\"\\\\equiv\",tag:\"mo\",output:\"\\u2261\",ttype:CONST},{input:\"\\\\ll\",tag:\"mo\",output:\"\\u226A\",ttype:CONST},{input:\"\\\\gg\",tag:\"mo\",output:\"\\u226B\",ttype:CONST},{input:\"\\\\doteq\",tag:\"mo\",output:\"\\u2250\",ttype:CONST},{input:\"\\\\prec\",tag:\"mo\",output:\"\\u227A\",ttype:CONST},{input:\"\\\\succ\",tag:\"mo\",output:\"\\u227B\",ttype:CONST},{input:\"\\\\preceq\",tag:\"mo\",output:\"\\u227C\",ttype:CONST},{input:\"\\\\succeq\",tag:\"mo\",output:\"\\u227D\",ttype:CONST},{input:\"\\\\subset\",tag:\"mo\",output:\"\\u2282\",ttype:CONST},{input:\"\\\\supset\",tag:\"mo\",output:\"\\u2283\",ttype:CONST},{input:\"\\\\subseteq\",tag:\"mo\",output:\"\\u2286\",ttype:CONST},{input:\"\\\\supseteq\",tag:\"mo\",output:\"\\u2287\",ttype:CONST},{input:\"\\\\sqsubset\",tag:\"mo\",output:\"\\u228F\",ttype:CONST},{input:\"\\\\sqsupset\",tag:\"mo\",output:\"\\u2290\",ttype:CONST},{input:\"\\\\sqsubseteq\",tag:\"mo\",output:\"\\u2291\",ttype:CONST},{input:\"\\\\sqsupseteq\",tag:\"mo\",output:\"\\u2292\",ttype:CONST},{input:\"\\\\sim\",tag:\"mo\",output:\"\\u223C\",ttype:CONST},{input:\"\\\\simeq\",tag:\"mo\",output:\"\\u2243\",ttype:CONST},{input:\"\\\\approx\",tag:\"mo\",output:\"\\u2248\",ttype:CONST},{input:\"\\\\cong\",tag:\"mo\",output:\"\\u2245\",ttype:CONST},{input:\"\\\\Join\",tag:\"mo\",output:\"\\u22C8\",ttype:CONST},{input:\"\\\\bowtie\",tag:\"mo\",output:\"\\u22C8\",ttype:CONST},{input:\"\\\\in\",tag:\"mo\",output:\"\\u2208\",ttype:CONST},{input:\"\\\\ni\",tag:\"mo\",output:\"\\u220B\",ttype:CONST},{input:\"\\\\owns\",tag:\"mo\",output:\"\\u220B\",ttype:CONST},{input:\"\\\\propto\",tag:\"mo\",output:\"\\u221D\",ttype:CONST},{input:\"\\\\vdash\",tag:\"mo\",output:\"\\u22A2\",ttype:CONST},{input:\"\\\\dashv\",tag:\"mo\",output:\"\\u22A3\",ttype:CONST},{input:\"\\\\models\",tag:\"mo\",output:\"\\u22A8\",ttype:CONST},{input:\"\\\\perp\",tag:\"mo\",output:\"\\u22A5\",ttype:CONST},{input:\"\\\\smile\",tag:\"mo\",output:\"\\u2323\",ttype:CONST},{input:\"\\\\frown\",tag:\"mo\",output:\"\\u2322\",ttype:CONST},{input:\"\\\\asymp\",tag:\"mo\",output:\"\\u224D\",ttype:CONST},{input:\"\\\\notin\",tag:\"mo\",output:\"\\u2209\",ttype:CONST},{input:\"\\\\begin{eqnarray}\",output:\"X\",ttype:MATRIX,invisible:true},{input:\"\\\\begin{array}\",output:\"X\",ttype:MATRIX,invisible:true},{input:\"\\\\\\\\\",output:\"}&{\",ttype:DEFINITION},{input:\"\\\\end{eqnarray}\",output:\"}}\",ttype:DEFINITION},{input:\"\\\\end{array}\",output:\"}}\",ttype:DEFINITION},{input:\"\\\\big\",tag:\"mo\",output:\"X\",atval:\"1.2\",ieval:\"2.2\",ttype:BIG},{input:\"\\\\Big\",tag:\"mo\",output:\"X\",atval:\"1.6\",ieval:\"2.6\",ttype:BIG},{input:\"\\\\bigg\",tag:\"mo\",output:\"X\",atval:\"2.2\",ieval:\"3.2\",ttype:BIG},{input:\"\\\\Bigg\",tag:\"mo\",output:\"X\",atval:\"2.9\",ieval:\"3.9\",ttype:BIG},{input:\"\\\\left\",tag:\"mo\",output:\"X\",ttype:LEFTBRACKET},{input:\"\\\\right\",tag:\"mo\",output:\"X\",ttype:RIGHTBRACKET},{input:\"{\",output:\"{\",ttype:LEFTBRACKET,invisible:true},{input:\"}\",output:\"}\",ttype:RIGHTBRACKET,invisible:true},{input:\"(\",tag:\"mo\",output:\"(\",atval:\"1\",ttype:STRETCHY},{input:\"[\",tag:\"mo\",output:\"[\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\lbrack\",tag:\"mo\",output:\"[\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\{\",tag:\"mo\",output:\"{\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\lbrace\",tag:\"mo\",output:\"{\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\langle\",tag:\"mo\",output:\"\\u2329\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\lfloor\",tag:\"mo\",output:\"\\u230A\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\lceil\",tag:\"mo\",output:\"\\u2308\",atval:\"1\",ttype:STRETCHY},{input:\")\",tag:\"mo\",output:\")\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"]\",tag:\"mo\",output:\"]\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\rbrack\",tag:\"mo\",output:\"]\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\}\",tag:\"mo\",output:\"}\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\rbrace\",tag:\"mo\",output:\"}\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\rangle\",tag:\"mo\",output:\"\\u232A\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\rfloor\",tag:\"mo\",output:\"\\u230B\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\rceil\",tag:\"mo\",output:\"\\u2309\",rtag:\"mi\",atval:\"1\",ttype:STRETCHY},{input:\"|\",tag:\"mo\",output:\"\\u2223\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\|\",tag:\"mo\",output:\"\\u2225\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\vert\",tag:\"mo\",output:\"\\u2223\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\Vert\",tag:\"mo\",output:\"\\u2225\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\mid\",tag:\"mo\",output:\"\\u2223\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\parallel\",tag:\"mo\",output:\"\\u2225\",atval:\"1\",ttype:STRETCHY},{input:\"/\",tag:\"mo\",output:\"/\",atval:\"1.01\",ttype:STRETCHY},{input:\"\\\\backslash\",tag:\"mo\",output:\"\\u2216\",atval:\"1\",ttype:STRETCHY},{input:\"\\\\setminus\",tag:\"mo\",output:\"\\\\\",ttype:CONST},{input:\"\\\\!\",tag:\"mspace\",atname:\"width\",atval:\"-0.167em\",ttype:SPACE},{input:\"\\\\,\",tag:\"mspace\",atname:\"width\",atval:\"0.167em\",ttype:SPACE},{input:\"\\\\>\",tag:\"mspace\",atname:\"width\",atval:\"0.222em\",ttype:SPACE},{input:\"\\\\:\",tag:\"mspace\",atname:\"width\",atval:\"0.222em\",ttype:SPACE},{input:\"\\\\;\",tag:\"mspace\",atname:\"width\",atval:\"0.278em\",ttype:SPACE},{input:\"~\",tag:\"mspace\",atname:\"width\",atval:\"0.333em\",ttype:SPACE},{input:\"\\\\quad\",tag:\"mspace\",atname:\"width\",atval:\"1em\",ttype:SPACE},{input:\"\\\\qquad\",tag:\"mspace\",atname:\"width\",atval:\"2em\",ttype:SPACE},{input:\"\\\\prime\",tag:\"mo\",output:\"\\u2032\",ttype:CONST},{input:\"'\",tag:\"mo\",output:\"\\u02B9\",ttype:CONST},{input:\"''\",tag:\"mo\",output:\"\\u02BA\",ttype:CONST},{input:\"'''\",tag:\"mo\",output:\"\\u2034\",ttype:CONST},{input:\"''''\",tag:\"mo\",output:\"\\u2057\",ttype:CONST},{input:\"\\\\ldots\",tag:\"mo\",output:\"\\u2026\",ttype:CONST},{input:\"\\\\cdots\",tag:\"mo\",output:\"\\u22EF\",ttype:CONST},{input:\"\\\\vdots\",tag:\"mo\",output:\"\\u22EE\",ttype:CONST},{input:\"\\\\ddots\",tag:\"mo\",output:\"\\u22F1\",ttype:CONST},{input:\"\\\\forall\",tag:\"mo\",output:\"\\u2200\",ttype:CONST},{input:\"\\\\exists\",tag:\"mo\",output:\"\\u2203\",ttype:CONST},{input:\"\\\\Re\",tag:\"mo\",output:\"\\u211C\",ttype:CONST},{input:\"\\\\Im\",tag:\"mo\",output:\"\\u2111\",ttype:CONST},{input:\"\\\\aleph\",tag:\"mo\",output:\"\\u2135\",ttype:CONST},{input:\"\\\\hbar\",tag:\"mo\",output:\"\\u210F\",ttype:CONST},{input:\"\\\\ell\",tag:\"mo\",output:\"\\u2113\",ttype:CONST},{input:\"\\\\wp\",tag:\"mo\",output:\"\\u2118\",ttype:CONST},{input:\"\\\\emptyset\",tag:\"mo\",output:\"\\u2205\",ttype:CONST},{input:\"\\\\infty\",tag:\"mo\",output:\"\\u221E\",ttype:CONST},{input:\"\\\\surd\",tag:\"mo\",output:\"\\\\sqrt{}\",ttype:DEFINITION},{input:\"\\\\partial\",tag:\"mo\",output:\"\\u2202\",ttype:CONST},{input:\"\\\\nabla\",tag:\"mo\",output:\"\\u2207\",ttype:CONST},{input:\"\\\\triangle\",tag:\"mo\",output:\"\\u25B3\",ttype:CONST},{input:\"\\\\therefore\",tag:\"mo\",output:\"\\u2234\",ttype:CONST},{input:\"\\\\angle\",tag:\"mo\",output:\"\\u2220\",ttype:CONST},{input:\"\\\\diamond\",tag:\"mo\",output:\"\\u22C4\",ttype:CONST},{input:\"\\\\Diamond\",tag:\"mo\",output:\"\\u25C7\",ttype:CONST},{input:\"\\\\neg\",tag:\"mo\",output:\"\\u00AC\",ttype:CONST},{input:\"\\\\lnot\",tag:\"mo\",output:\"\\u00AC\",ttype:CONST},{input:\"\\\\bot\",tag:\"mo\",output:\"\\u22A5\",ttype:CONST},{input:\"\\\\top\",tag:\"mo\",output:\"\\u22A4\",ttype:CONST},{input:\"\\\\square\",tag:\"mo\",output:\"\\u25AB\",ttype:CONST},{input:\"\\\\Box\",tag:\"mo\",output:\"\\u25A1\",ttype:CONST},{input:\"\\\\wr\",tag:\"mo\",output:\"\\u2240\",ttype:CONST},{input:\"\\\\arccos\",tag:\"mi\",output:\"arccos\",ttype:UNARY,func:true},{input:\"\\\\arcsin\",tag:\"mi\",output:\"arcsin\",ttype:UNARY,func:true},{input:\"\\\\arctan\",tag:\"mi\",output:\"arctan\",ttype:UNARY,func:true},{input:\"\\\\arg\",tag:\"mi\",output:\"arg\",ttype:UNARY,func:true},{input:\"\\\\cos\",tag:\"mi\",output:\"cos\",ttype:UNARY,func:true},{input:\"\\\\cosh\",tag:\"mi\",output:\"cosh\",ttype:UNARY,func:true},{input:\"\\\\cot\",tag:\"mi\",output:\"cot\",ttype:UNARY,func:true},{input:\"\\\\coth\",tag:\"mi\",output:\"coth\",ttype:UNARY,func:true},{input:\"\\\\csc\",tag:\"mi\",output:\"csc\",ttype:UNARY,func:true},{input:\"\\\\deg\",tag:\"mi\",output:\"deg\",ttype:UNARY,func:true},{input:\"\\\\det\",tag:\"mi\",output:\"det\",ttype:UNARY,func:true},{input:\"\\\\dim\",tag:\"mi\",output:\"dim\",ttype:UNARY,func:true},{input:\"\\\\exp\",tag:\"mi\",output:\"exp\",ttype:UNARY,func:true},{input:\"\\\\gcd\",tag:\"mi\",output:\"gcd\",ttype:UNARY,func:true},{input:\"\\\\hom\",tag:\"mi\",output:\"hom\",ttype:UNARY,func:true},{input:\"\\\\inf\",tag:\"mo\",output:\"inf\",ttype:UNDEROVER},{input:\"\\\\ker\",tag:\"mi\",output:\"ker\",ttype:UNARY,func:true},{input:\"\\\\lg\",tag:\"mi\",output:\"lg\",ttype:UNARY,func:true},{input:\"\\\\lim\",tag:\"mo\",output:\"lim\",ttype:UNDEROVER},{input:\"\\\\liminf\",tag:\"mo\",output:\"liminf\",ttype:UNDEROVER},{input:\"\\\\limsup\",tag:\"mo\",output:\"limsup\",ttype:UNDEROVER},{input:\"\\\\ln\",tag:\"mi\",output:\"ln\",ttype:UNARY,func:true},{input:\"\\\\log\",tag:\"mi\",output:\"log\",ttype:UNARY,func:true},{input:\"\\\\max\",tag:\"mo\",output:\"max\",ttype:UNDEROVER},{input:\"\\\\min\",tag:\"mo\",output:\"min\",ttype:UNDEROVER},{input:\"\\\\Pr\",tag:\"mi\",output:\"Pr\",ttype:UNARY,func:true},{input:\"\\\\sec\",tag:\"mi\",output:\"sec\",ttype:UNARY,func:true},{input:\"\\\\sin\",tag:\"mi\",output:\"sin\",ttype:UNARY,func:true},{input:\"\\\\sinh\",tag:\"mi\",output:\"sinh\",ttype:UNARY,func:true},{input:\"\\\\sup\",tag:\"mo\",output:\"sup\",ttype:UNDEROVER},{input:\"\\\\tan\",tag:\"mi\",output:\"tan\",ttype:UNARY,func:true},{input:\"\\\\tanh\",tag:\"mi\",output:\"tanh\",ttype:UNARY,func:true},{input:\"\\\\gets\",tag:\"mo\",output:\"\\u2190\",ttype:CONST},{input:\"\\\\leftarrow\",tag:\"mo\",output:\"\\u2190\",ttype:CONST},{input:\"\\\\to\",tag:\"mo\",output:\"\\u2192\",ttype:CONST},{input:\"\\\\rightarrow\",tag:\"mo\",output:\"\\u2192\",ttype:CONST},{input:\"\\\\leftrightarrow\",tag:\"mo\",output:\"\\u2194\",ttype:CONST},{input:\"\\\\uparrow\",tag:\"mo\",output:\"\\u2191\",ttype:CONST},{input:\"\\\\downarrow\",tag:\"mo\",output:\"\\u2193\",ttype:CONST},{input:\"\\\\updownarrow\",tag:\"mo\",output:\"\\u2195\",ttype:CONST},{input:\"\\\\Leftarrow\",tag:\"mo\",output:\"\\u21D0\",ttype:CONST},{input:\"\\\\Rightarrow\",tag:\"mo\",output:\"\\u21D2\",ttype:CONST},{input:\"\\\\Leftrightarrow\",tag:\"mo\",output:\"\\u21D4\",ttype:CONST},{input:\"\\\\iff\",tag:\"mo\",output:\"~\\\\Longleftrightarrow~\",ttype:DEFINITION},{input:\"\\\\Uparrow\",tag:\"mo\",output:\"\\u21D1\",ttype:CONST},{input:\"\\\\Downarrow\",tag:\"mo\",output:\"\\u21D3\",ttype:CONST},{input:\"\\\\Updownarrow\",tag:\"mo\",output:\"\\u21D5\",ttype:CONST},{input:\"\\\\mapsto\",tag:\"mo\",output:\"\\u21A6\",ttype:CONST},{input:\"\\\\longleftarrow\",tag:\"mo\",output:\"\\u2190\",ttype:LONG},{input:\"\\\\longrightarrow\",tag:\"mo\",output:\"\\u2192\",ttype:LONG},{input:\"\\\\longleftrightarrow\",tag:\"mo\",output:\"\\u2194\",ttype:LONG},{input:\"\\\\Longleftarrow\",tag:\"mo\",output:\"\\u21D0\",ttype:LONG},{input:\"\\\\Longrightarrow\",tag:\"mo\",output:\"\\u21D2\",ttype:LONG},{input:\"\\\\Longleftrightarrow\",tag:\"mo\",output:\"\\u21D4\",ttype:LONG},{input:\"\\\\longmapsto\",tag:\"mo\",output:\"\\u21A6\",ttype:CONST},AMsqrt,AMroot,AMfrac,AMover,AMsub,AMsup,AMtext,AMmbox,AMatop,AMchoose,{input:\"\\\\acute\",tag:\"mover\",output:\"\\u00B4\",ttype:UNARY,acc:true},{input:\"\\\\grave\",tag:\"mover\",output:\"\\u0060\",ttype:UNARY,acc:true},{input:\"\\\\breve\",tag:\"mover\",output:\"\\u02D8\",ttype:UNARY,acc:true},{input:\"\\\\check\",tag:\"mover\",output:\"\\u02C7\",ttype:UNARY,acc:true},{input:\"\\\\dot\",tag:\"mover\",output:\".\",ttype:UNARY,acc:true},{input:\"\\\\ddot\",tag:\"mover\",output:\"..\",ttype:UNARY,acc:true},{input:\"\\\\mathring\",tag:\"mover\",output:\"\\u00B0\",ttype:UNARY,acc:true},{input:\"\\\\vec\",tag:\"mover\",output:\"\\u20D7\",ttype:UNARY,acc:true},{input:\"\\\\overrightarrow\",tag:\"mover\",output:\"\\u20D7\",ttype:UNARY,acc:true},{input:\"\\\\overleftarrow\",tag:\"mover\",output:\"\\u20D6\",ttype:UNARY,acc:true},{input:\"\\\\hat\",tag:\"mover\",output:\"\\u005E\",ttype:UNARY,acc:true},{input:\"\\\\widehat\",tag:\"mover\",output:\"\\u0302\",ttype:UNARY,acc:true},{input:\"\\\\tilde\",tag:\"mover\",output:\"~\",ttype:UNARY,acc:true},{input:\"\\\\widetilde\",tag:\"mover\",output:\"\\u02DC\",ttype:UNARY,acc:true},{input:\"\\\\bar\",tag:\"mover\",output:\"\\u203E\",ttype:UNARY,acc:true},{input:\"\\\\overbrace\",tag:\"mover\",output:\"\\uFE37\",ttype:UNARY,acc:true},{input:\"\\\\overbracket\",tag:\"mover\",output:\"\\u23B4\",ttype:UNARY,acc:true},{input:\"\\\\overline\",tag:\"mover\",output:\"\\u00AF\",ttype:UNARY,acc:true},{input:\"\\\\underbrace\",tag:\"munder\",output:\"\\uFE38\",ttype:UNARY,acc:true},{input:\"\\\\underbracket\",tag:\"munder\",output:\"\\u23B5\",ttype:UNARY,acc:true},{input:\"\\\\underline\",tag:\"munder\",output:\"\\u00AF\",ttype:UNARY,acc:true},{input:\"\\\\displaystyle\",tag:\"mstyle\",atname:\"displaystyle\",atval:\"true\",ttype:UNARY},{input:\"\\\\textstyle\",tag:\"mstyle\",atname:\"displaystyle\",atval:\"false\",ttype:UNARY},{input:\"\\\\scriptstyle\",tag:\"mstyle\",atname:\"scriptlevel\",atval:\"1\",ttype:UNARY},{input:\"\\\\scriptscriptstyle\",tag:\"mstyle\",atname:\"scriptlevel\",atval:\"2\",ttype:UNARY},{input:\"\\\\textrm\",tag:\"mstyle\",output:\"\\\\mathrm\",ttype:DEFINITION},{input:\"\\\\mathbf\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"bold\",ttype:UNARY},{input:\"\\\\textbf\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"bold\",ttype:UNARY},{input:\"\\\\mathit\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"italic\",ttype:UNARY},{input:\"\\\\textit\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"italic\",ttype:UNARY},{input:\"\\\\mathtt\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"monospace\",ttype:UNARY},{input:\"\\\\texttt\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"monospace\",ttype:UNARY},{input:\"\\\\mathsf\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"sans-serif\",ttype:UNARY},{input:\"\\\\mathbb\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"double-struck\",ttype:UNARY,codes:AMbbb},{input:\"\\\\mathcal\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"script\",ttype:UNARY,codes:AMcal},{input:\"\\\\mathfrak\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"fraktur\",ttype:UNARY,codes:AMfrk},{input:\"\\\\textcolor\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"mathcolor\",ttype:BINARY},{input:\"\\\\colorbox\",tag:\"mstyle\",atname:\"mathvariant\",atval:\"background\",ttype:BINARY}];function compareNames(s1,s2){if(s1.input>s2.input)return 1\nelse return-1;}\nvar AMnames=[];function AMinitSymbols(){AMsymbols.sort(compareNames);for(i=0;i<AMsymbols.length;i++)AMnames[i]=AMsymbols[i].input;}\nvar AMmathml=\"http://www.w3.org/1998/Math/MathML\";function AMcreateElementMathML(t){if(isIE)return document.createElement(\"m:\"+t);else return document.createElementNS(AMmathml,t);}\nfunction AMcreateMmlNode(t,frag){if(isIE)var node=document.createElement(\"m:\"+t);else var node=document.createElementNS(AMmathml,t);node.appendChild(frag);return node;}\nfunction newcommand(oldstr,newstr){AMsymbols=AMsymbols.concat([{input:oldstr,tag:\"mo\",output:newstr,ttype:DEFINITION}]);}\nfunction AMremoveCharsAndBlanks(str,n){var st;st=str.slice(n);for(var i=0;i<st.length&&st.charCodeAt(i)<=32;i=i+1);return st.slice(i);}\nfunction AMposition(arr,str,n){if(n==0){var h,m;n=-1;h=arr.length;while(n+1<h){m=(n+h)>>1;if(arr[m]<str)n=m;else h=m;}\nreturn h;}else\nfor(var i=n;i<arr.length&&arr[i]<str;i++);return i;}\nfunction AMgetSymbol(str){var k=0;var j=0;var mk;var st;var tagst;var match=\"\";var more=true;for(var i=1;i<=str.length&&more;i++){st=str.slice(0,i);j=k;k=AMposition(AMnames,st,j);if(k<AMnames.length&&str.slice(0,AMnames[k].length)==AMnames[k]){match=AMnames[k];mk=k;i=match.length;}\nmore=k<AMnames.length&&str.slice(0,AMnames[k].length)>=AMnames[k];}\nAMpreviousSymbol=AMcurrentSymbol;if(match!=\"\"){AMcurrentSymbol=AMsymbols[mk].ttype;return AMsymbols[mk];}\nAMcurrentSymbol=CONST;k=1;st=str.slice(0,1);if(\"0\"<=st&&st<=\"9\")tagst=\"mn\";else tagst=((\"A\">st||st>\"Z\")&&(\"a\">st||st>\"z\")?\"mo\":\"mi\");return{input:st,tag:tagst,output:st,ttype:CONST};}\nvar AMpreviousSymbol,AMcurrentSymbol;function AMparseSexpr(str){var symbol,node,result,result2,i,st,newFrag=document.createDocumentFragment();str=AMremoveCharsAndBlanks(str,0);symbol=AMgetSymbol(str);if(symbol==null||symbol.ttype==RIGHTBRACKET)\nreturn[null,str,null];if(symbol.ttype==DEFINITION){str=symbol.output+AMremoveCharsAndBlanks(str,symbol.input.length);symbol=AMgetSymbol(str);if(symbol==null||symbol.ttype==RIGHTBRACKET)\nreturn[null,str,null];}\nstr=AMremoveCharsAndBlanks(str,symbol.input.length);switch(symbol.ttype){case SPACE:node=AMcreateElementMathML(symbol.tag);node.setAttribute(symbol.atname,symbol.atval);return[node,str,symbol.tag];case UNDEROVER:if(isIE){if(symbol.input.substr(0,4)==\"\\\\big\"){str=\"\\\\\"+symbol.input.substr(4)+str;symbol=AMgetSymbol(str);symbol.ttype=UNDEROVER;str=AMremoveCharsAndBlanks(str,symbol.input.length);}}\nreturn[AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output)),str,symbol.tag];case CONST:var output=symbol.output;if(isIE){if(symbol.input==\"'\")\noutput=\"\\u2032\";else if(symbol.input==\"''\")\noutput=\"\\u2033\";else if(symbol.input==\"'''\")\noutput=\"\\u2033\\u2032\";else if(symbol.input==\"''''\")\noutput=\"\\u2033\\u2033\";else if(symbol.input==\"\\\\square\")\noutput=\"\\u25A1\";else if(symbol.input.substr(0,5)==\"\\\\frac\"){var denom=symbol.input.substr(6,1);if(denom==\"5\"||denom==\"6\"){str=symbol.input.replace(/\\\\frac/,\"\\\\frac \")+str;return[node,str,symbol.tag];}}}\nnode=AMcreateMmlNode(symbol.tag,document.createTextNode(output));return[node,str,symbol.tag];case LONG:node=AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output));node.setAttribute(\"minsize\",\"1.5\");node.setAttribute(\"maxsize\",\"1.5\");node=AMcreateMmlNode(\"mover\",node);node.appendChild(AMcreateElementMathML(\"mspace\"));return[node,str,symbol.tag];case STRETCHY:if(isIE&&symbol.input==\"\\\\backslash\")\nsymbol.output=\"\\\\\";node=AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output));if(symbol.input==\"|\"||symbol.input==\"\\\\vert\"||symbol.input==\"\\\\|\"||symbol.input==\"\\\\Vert\"){node.setAttribute(\"lspace\",\"0em\");node.setAttribute(\"rspace\",\"0em\");}\nnode.setAttribute(\"maxsize\",symbol.atval);if(symbol.rtag!=null)\nreturn[node,str,symbol.rtag];else\nreturn[node,str,symbol.tag];case BIG:var atval=symbol.atval;if(isIE)\natval=symbol.ieval;symbol=AMgetSymbol(str);if(symbol==null)\nreturn[null,str,null];str=AMremoveCharsAndBlanks(str,symbol.input.length);node=AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output));if(isIE){var space=AMcreateElementMathML(\"mspace\");space.setAttribute(\"height\",atval+\"ex\");node=AMcreateMmlNode(\"mrow\",node);node.appendChild(space);}else{node.setAttribute(\"minsize\",atval);node.setAttribute(\"maxsize\",atval);}\nreturn[node,str,symbol.tag];case LEFTBRACKET:if(symbol.input==\"\\\\left\"){symbol=AMgetSymbol(str);if(symbol!=null){if(symbol.input==\".\")\nsymbol.invisible=true;str=AMremoveCharsAndBlanks(str,symbol.input.length);}}\nresult=AMparseExpr(str,true,false);if(symbol==null||(typeof symbol.invisible==\"boolean\"&&symbol.invisible))\nnode=AMcreateMmlNode(\"mrow\",result[0]);else{node=AMcreateMmlNode(\"mo\",document.createTextNode(symbol.output));node=AMcreateMmlNode(\"mrow\",node);node.appendChild(result[0]);}\nreturn[node,result[1],result[2]];case MATRIX:if(symbol.input==\"\\\\begin{array}\"){var mask=\"\";symbol=AMgetSymbol(str);str=AMremoveCharsAndBlanks(str,0);if(symbol==null)\nmask=\"l\";else{str=AMremoveCharsAndBlanks(str,symbol.input.length);if(symbol.input!=\"{\")\nmask=\"l\";else do{symbol=AMgetSymbol(str);if(symbol!=null){str=AMremoveCharsAndBlanks(str,symbol.input.length);if(symbol.input!=\"}\")\nmask=mask+symbol.input;}}while(symbol!=null&&symbol.input!=\"\"&&symbol.input!=\"}\");}\nresult=AMparseExpr(\"{\"+str,true,true);node=AMcreateMmlNode(\"mtable\",result[0]);mask=mask.replace(/l/g,\"left \");mask=mask.replace(/r/g,\"right \");mask=mask.replace(/c/g,\"center \");node.setAttribute(\"columnalign\",mask);node.setAttribute(\"displaystyle\",\"false\");if(isIE)\nreturn[node,result[1],null];var lspace=AMcreateElementMathML(\"mspace\");lspace.setAttribute(\"width\",\"0.167em\");var rspace=AMcreateElementMathML(\"mspace\");rspace.setAttribute(\"width\",\"0.167em\");var node1=AMcreateMmlNode(\"mrow\",lspace);node1.appendChild(node);node1.appendChild(rspace);return[node1,result[1],null];}else{result=AMparseExpr(\"{\"+str,true,true);node=AMcreateMmlNode(\"mtable\",result[0]);if(isIE)\nnode.setAttribute(\"columnspacing\",\"0.25em\");else\nnode.setAttribute(\"columnspacing\",\"0.167em\");node.setAttribute(\"columnalign\",\"right center left\");node.setAttribute(\"displaystyle\",\"true\");node=AMcreateMmlNode(\"mrow\",node);return[node,result[1],null];}\ncase TEXT:if(str.charAt(0)==\"{\")i=str.indexOf(\"}\");else i=0;if(i==-1)\ni=str.length;st=str.slice(1,i);if(st.charAt(0)==\" \"){node=AMcreateElementMathML(\"mspace\");node.setAttribute(\"width\",\"0.33em\");newFrag.appendChild(node);}\nnewFrag.appendChild(AMcreateMmlNode(symbol.tag,document.createTextNode(st)));if(st.charAt(st.length-1)==\" \"){node=AMcreateElementMathML(\"mspace\");node.setAttribute(\"width\",\"0.33em\");newFrag.appendChild(node);}\nstr=AMremoveCharsAndBlanks(str,i+1);return[AMcreateMmlNode(\"mrow\",newFrag),str,null];case UNARY:result=AMparseSexpr(str);if(result[0]==null)return[AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output)),str];if(typeof symbol.func==\"boolean\"&&symbol.func){st=str.charAt(0);if(st==\"^\"||st==\"_\"||st==\",\"){return[AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output)),str,symbol.tag];}else{node=AMcreateMmlNode(\"mrow\",AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output)));if(isIE){var space=AMcreateElementMathML(\"mspace\");space.setAttribute(\"width\",\"0.167em\");node.appendChild(space);}\nnode.appendChild(result[0]);return[node,result[1],symbol.tag];}}\nif(symbol.input==\"\\\\sqrt\"){if(isIE){var space=AMcreateElementMathML(\"mspace\");space.setAttribute(\"height\",\"1.2ex\");space.setAttribute(\"width\",\"0em\");node=AMcreateMmlNode(symbol.tag,result[0])\nnode.appendChild(space);return[node,result[1],symbol.tag];}else\nreturn[AMcreateMmlNode(symbol.tag,result[0]),result[1],symbol.tag];}else if(typeof symbol.acc==\"boolean\"&&symbol.acc){node=AMcreateMmlNode(symbol.tag,result[0]);var output=symbol.output;if(isIE){if(symbol.input==\"\\\\hat\")\noutput=\"\\u0302\";else if(symbol.input==\"\\\\widehat\")\noutput=\"\\u005E\";else if(symbol.input==\"\\\\bar\")\noutput=\"\\u00AF\";else if(symbol.input==\"\\\\grave\")\noutput=\"\\u0300\";else if(symbol.input==\"\\\\tilde\")\noutput=\"\\u0303\";}\nvar node1=AMcreateMmlNode(\"mo\",document.createTextNode(output));if(symbol.input==\"\\\\vec\"||symbol.input==\"\\\\check\")\nnode1.setAttribute(\"maxsize\",\"1.2\");if(isIE&&symbol.input==\"\\\\bar\")\nnode1.setAttribute(\"maxsize\",\"0.5\");if(symbol.input==\"\\\\underbrace\"||symbol.input==\"\\\\underline\")\nnode1.setAttribute(\"accentunder\",\"true\");else\nnode1.setAttribute(\"accent\",\"true\");node.appendChild(node1);if(symbol.input==\"\\\\overbrace\"||symbol.input==\"\\\\underbrace\")\nnode.ttype=UNDEROVER;return[node,result[1],symbol.tag];}else{if(!isIE&&typeof symbol.codes!=\"undefined\"){for(i=0;i<result[0].childNodes.length;i++)\nif(result[0].childNodes[i].nodeName==\"mi\"||result[0].nodeName==\"mi\"){st=(result[0].nodeName==\"mi\"?result[0].firstChild.nodeValue:result[0].childNodes[i].firstChild.nodeValue);var newst=[];for(var j=0;j<st.length;j++)\nif(st.charCodeAt(j)>64&&st.charCodeAt(j)<91)newst=newst+\nString.fromCharCode(symbol.codes[st.charCodeAt(j)-65]);else newst=newst+st.charAt(j);if(result[0].nodeName==\"mi\")\nresult[0]=AMcreateElementMathML(\"mo\").appendChild(document.createTextNode(newst));else result[0].replaceChild(AMcreateElementMathML(\"mo\").appendChild(document.createTextNode(newst)),result[0].childNodes[i]);}}\nnode=AMcreateMmlNode(symbol.tag,result[0]);node.setAttribute(symbol.atname,symbol.atval);if(symbol.input==\"\\\\scriptstyle\"||symbol.input==\"\\\\scriptscriptstyle\")\nnode.setAttribute(\"displaystyle\",\"false\");return[node,result[1],symbol.tag];}\ncase BINARY:result=AMparseSexpr(str);if(result[0]==null)return[AMcreateMmlNode(\"mo\",document.createTextNode(symbol.input)),str,null];result2=AMparseSexpr(result[1]);if(result2[0]==null)return[AMcreateMmlNode(\"mo\",document.createTextNode(symbol.input)),str,null];if(symbol.input==\"\\\\textcolor\"||symbol.input==\"\\\\colorbox\"){var tclr=str.match(/\\{\\s*([#\\w]+)\\s*\\}/);str=str.replace(/\\{\\s*[#\\w]+\\s*\\}/,\"\");if(tclr!=null){if(IsColorName.test(tclr[1].toLowerCase())){tclr=LaTeXColor[tclr[1].toLowerCase()];}else{tclr=tclr[1];}\nnode=AMcreateElementMathML(\"mstyle\");node.setAttribute(symbol.atval,tclr);node.appendChild(result2[0]);return[node,result2[1],symbol.tag];}}\nif(symbol.input==\"\\\\root\"||symbol.input==\"\\\\stackrel\")newFrag.appendChild(result2[0]);newFrag.appendChild(result[0]);if(symbol.input==\"\\\\frac\")newFrag.appendChild(result2[0]);return[AMcreateMmlNode(symbol.tag,newFrag),result2[1],symbol.tag];case INFIX:str=AMremoveCharsAndBlanks(str,symbol.input.length);return[AMcreateMmlNode(\"mo\",document.createTextNode(symbol.output)),str,symbol.tag];default:return[AMcreateMmlNode(symbol.tag,document.createTextNode(symbol.output)),str,symbol.tag];}}\nfunction AMparseIexpr(str){var symbol,sym1,sym2,node,result,tag,underover;str=AMremoveCharsAndBlanks(str,0);sym1=AMgetSymbol(str);result=AMparseSexpr(str);node=result[0];str=result[1];tag=result[2];symbol=AMgetSymbol(str);if(symbol.ttype==INFIX){str=AMremoveCharsAndBlanks(str,symbol.input.length);result=AMparseSexpr(str);if(result[0]==null)\nresult[0]=AMcreateMmlNode(\"mo\",document.createTextNode(\"\\u25A1\"));str=result[1];tag=result[2];if(symbol.input==\"_\"||symbol.input==\"^\"){sym2=AMgetSymbol(str);tag=null;underover=((sym1.ttype==UNDEROVER)||(node.ttype==UNDEROVER));if(symbol.input==\"_\"&&sym2.input==\"^\"){str=AMremoveCharsAndBlanks(str,sym2.input.length);var res2=AMparseSexpr(str);str=res2[1];tag=res2[2];node=AMcreateMmlNode((underover?\"munderover\":\"msubsup\"),node);node.appendChild(result[0]);node.appendChild(res2[0]);}else if(symbol.input==\"_\"){node=AMcreateMmlNode((underover?\"munder\":\"msub\"),node);node.appendChild(result[0]);}else{node=AMcreateMmlNode((underover?\"mover\":\"msup\"),node);node.appendChild(result[0]);}\nnode=AMcreateMmlNode(\"mrow\",node);}else{node=AMcreateMmlNode(symbol.tag,node);if(symbol.input==\"\\\\atop\"||symbol.input==\"\\\\choose\")\nnode.setAttribute(\"linethickness\",\"0ex\");node.appendChild(result[0]);if(symbol.input==\"\\\\choose\")\nnode=AMcreateMmlNode(\"mfenced\",node);}}\nreturn[node,str,tag];}\nfunction AMparseExpr(str,rightbracket,matrix){var symbol,node,result,i,tag,newFrag=document.createDocumentFragment();do{str=AMremoveCharsAndBlanks(str,0);result=AMparseIexpr(str);node=result[0];str=result[1];tag=result[2];symbol=AMgetSymbol(str);if(node!=undefined){if((tag==\"mn\"||tag==\"mi\")&&symbol!=null&&typeof symbol.func==\"boolean\"&&symbol.func){var space=AMcreateElementMathML(\"mspace\");space.setAttribute(\"width\",\"0.167em\");node=AMcreateMmlNode(\"mrow\",node);node.appendChild(space);}\nnewFrag.appendChild(node);}}while((symbol.ttype!=RIGHTBRACKET)&&symbol!=null&&symbol.output!=\"\");tag=null;if(symbol.ttype==RIGHTBRACKET){if(symbol.input==\"\\\\right\"){str=AMremoveCharsAndBlanks(str,symbol.input.length);symbol=AMgetSymbol(str);if(symbol!=null&&symbol.input==\".\")\nsymbol.invisible=true;if(symbol!=null)\ntag=symbol.rtag;}\nif(symbol!=null)\nstr=AMremoveCharsAndBlanks(str,symbol.input.length);var len=newFrag.childNodes.length;if(matrix&&len>0&&newFrag.childNodes[len-1].nodeName==\"mrow\"&&len>1&&newFrag.childNodes[len-2].nodeName==\"mo\"&&newFrag.childNodes[len-2].firstChild.nodeValue==\"&\"){var pos=[];var m=newFrag.childNodes.length;for(i=0;matrix&&i<m;i=i+2){pos[i]=[];node=newFrag.childNodes[i];for(var j=0;j<node.childNodes.length;j++)\nif(node.childNodes[j].firstChild.nodeValue==\"&\")\npos[i][pos[i].length]=j;}\nvar row,frag,n,k,table=document.createDocumentFragment();for(i=0;i<m;i=i+2){row=document.createDocumentFragment();frag=document.createDocumentFragment();node=newFrag.firstChild;n=node.childNodes.length;k=0;for(j=0;j<n;j++){if(typeof pos[i][k]!=\"undefined\"&&j==pos[i][k]){node.removeChild(node.firstChild);row.appendChild(AMcreateMmlNode(\"mtd\",frag));k++;}else frag.appendChild(node.firstChild);}\nrow.appendChild(AMcreateMmlNode(\"mtd\",frag));if(newFrag.childNodes.length>2){newFrag.removeChild(newFrag.firstChild);newFrag.removeChild(newFrag.firstChild);}\ntable.appendChild(AMcreateMmlNode(\"mtr\",row));}\nreturn[table,str];}\nif(typeof symbol.invisible!=\"boolean\"||!symbol.invisible){node=AMcreateMmlNode(\"mo\",document.createTextNode(symbol.output));newFrag.appendChild(node);}}\nreturn[newFrag,str,tag];}\nfunction AMparseMath(str){var result,node=AMcreateElementMathML(\"mstyle\");var cclr=str.match(/\\\\color\\s*\\{\\s*([#\\w]+)\\s*\\}/);str=str.replace(/\\\\color\\s*\\{\\s*[#\\w]+\\s*\\}/g,\"\");if(cclr!=null){if(IsColorName.test(cclr[1].toLowerCase())){cclr=LaTeXColor[cclr[1].toLowerCase()];}else{cclr=cclr[1];}\nnode.setAttribute(\"mathcolor\",cclr);}else{if(mathcolor!=\"\")node.setAttribute(\"mathcolor\",mathcolor);};if(mathfontfamily!=\"\")node.setAttribute(\"fontfamily\",mathfontfamily);node.appendChild(AMparseExpr(str.replace(/^\\s+/g,\"\"),false,false)[0]);node=AMcreateMmlNode(\"math\",node);if(showasciiformulaonhover)\nnode.setAttribute(\"title\",str.replace(/\\s+/g,\" \"));if(false){var fnode=AMcreateElementXHTML(\"font\");fnode.setAttribute(\"face\",mathfontfamily);fnode.appendChild(node);return fnode;}\nreturn node;}\nfunction AMstrarr2docFrag(arr,linebreaks){var newFrag=document.createDocumentFragment();var expr=false;for(var i=0;i<arr.length;i++){if(expr)newFrag.appendChild(AMparseMath(arr[i]));else{var arri=(linebreaks?arr[i].split(\"\\n\\n\"):[arr[i]]);newFrag.appendChild(AMcreateElementXHTML(\"span\").appendChild(document.createTextNode(arri[0])));for(var j=1;j<arri.length;j++){newFrag.appendChild(AMcreateElementXHTML(\"p\"));newFrag.appendChild(AMcreateElementXHTML(\"span\").appendChild(document.createTextNode(arri[j])));}}\nexpr=!expr;}\nreturn newFrag;}\nfunction AMprocessNodeR(n,linebreaks){var mtch,str,arr,frg,i;if(n.childNodes.length==0){if((n.nodeType!=8||linebreaks)&&n.parentNode.nodeName!=\"form\"&&n.parentNode.nodeName!=\"FORM\"&&n.parentNode.nodeName!=\"textarea\"&&n.parentNode.nodeName!=\"TEXTAREA\"&&n.parentNode.nodeName!=\"pre\"&&n.parentNode.nodeName!=\"PRE\"){str=n.nodeValue;if(!(str==null)){str=str.replace(/\\r\\n\\r\\n/g,\"\\n\\n\");str=str.replace(/\\x20+/g,\" \");str=str.replace(/\\s*\\r\\n/g,\" \");mtch=(str.indexOf(\"\\$\")==-1?false:true);str=str.replace(/([^\\\\])\\$/g,\"$1 \\$\");str=str.replace(/^\\$/,\" \\$\");arr=str.split(\" \\$\");for(i=0;i<arr.length;i++)\narr[i]=arr[i].replace(/\\\\\\$/g,\"\\$\");if(arr.length>1||mtch){if(checkForMathML){checkForMathML=false;var nd=AMisMathMLavailable();AMnoMathML=nd!=null;if(AMnoMathML&&notifyIfNoMathML)\nif(alertIfNoMathML)\nalert(\"To view the ASCIIMathML notation use Internet Explorer 6 +\\nMathPlayer (free from www.dessci.com)\\nor Firefox/Mozilla/Netscape\");else AMbody.insertBefore(nd,AMbody.childNodes[0]);}\nif(!AMnoMathML){frg=AMstrarr2docFrag(arr,n.nodeType==8);var len=frg.childNodes.length;n.parentNode.replaceChild(frg,n);return len-1;}else return 0;}}}else return 0;}else if(n.nodeName!=\"math\"){for(i=0;i<n.childNodes.length;i++)\ni+=AMprocessNodeR(n.childNodes[i],linebreaks);}\nreturn 0;}\nfunction AMprocessNode(n,linebreaks,spanclassAM){var frag,st;if(spanclassAM!=null){frag=document.getElementsByTagName(\"span\")\nfor(var i=0;i<frag.length;i++)\nif(frag[i].className==\"AM\")\nAMprocessNodeR(frag[i],linebreaks);}else{try{st=n.innerHTML;}catch(err){}\nif(st==null||st.indexOf(\"\\$\")!=-1)\nAMprocessNodeR(n,linebreaks);}\nif(isIE){frag=document.getElementsByTagName('math');for(var i=0;i<frag.length;i++)frag[i].update()}}\nvar inAppendix=false;var sectionCntr=0;var IEcommentWarning=true;var biblist=[];var bibcntr=0;var LaTeXCounter=[];LaTeXCounter[\"definition\"]=0;LaTeXCounter[\"proposition\"]=0;LaTeXCounter[\"lemma\"]=0;LaTeXCounter[\"theorem\"]=0;LaTeXCounter[\"corollary\"]=0;LaTeXCounter[\"example\"]=0;LaTeXCounter[\"exercise\"]=0;LaTeXCounter[\"subsection\"]=0;LaTeXCounter[\"subsubsection\"]=0;LaTeXCounter[\"figure\"]=0;LaTeXCounter[\"equation\"]=0;LaTeXCounter[\"table\"]=0;var LaTeXColor=[];LaTeXColor[\"greenyellow\"]=\"#D9FF4F\";LaTeXColor[\"yellow\"]=\"#FFFF00\";LaTeXColor[\"goldenrod\"]=\"#FFE529\";LaTeXColor[\"dandelion\"]=\"#FFB529\";LaTeXColor[\"apricot\"]=\"#FFAD7A\";LaTeXColor[\"peach\"]=\"#FF804D\";LaTeXColor[\"melon\"]=\"#FF8A80\";LaTeXColor[\"yelloworange\"]=\"#FF9400\";LaTeXColor[\"orange\"]=\"#FF6321\";LaTeXColor[\"burntorange\"]=\"#FF7D00\";LaTeXColor[\"bittersweet\"]=\"#C20300\";LaTeXColor[\"redorange\"]=\"#FF3B21\";LaTeXColor[\"mahogany\"]=\"#A60000\";LaTeXColor[\"maroon\"]=\"#AD0000\";LaTeXColor[\"brickred\"]=\"#B80000\";LaTeXColor[\"red\"]=\"#FF0000\";LaTeXColor[\"orangered\"]=\"#FF0080\";LaTeXColor[\"rubinered\"]=\"#FF00DE\";LaTeXColor[\"wildstrawberry\"]=\"#FF0A9C\";LaTeXColor[\"salmon\"]=\"#FF789E\";LaTeXColor[\"carnationpink\"]=\"#FF5EFF\";LaTeXColor[\"magenta\"]=\"#FF00FF\";LaTeXColor[\"violetred\"]=\"#FF30FF\";LaTeXColor[\"rhodamine\"]=\"#FF2EFF\";LaTeXColor[\"mulberry\"]=\"#A314FA\";LaTeXColor[\"redviolet\"]=\"#9600A8\";LaTeXColor[\"fuchsia\"]=\"#7303EB\";LaTeXColor[\"lavender\"]=\"#FF85FF\";LaTeXColor[\"thistle\"]=\"#E069FF\";LaTeXColor[\"orchid\"]=\"#AD5CFF\";LaTeXColor[\"darkorchid\"]=\"#9933CC\";LaTeXColor[\"purple\"]=\"#8C24FF\";LaTeXColor[\"plum\"]=\"#8000FF\";LaTeXColor[\"violet\"]=\"#361FFF\";LaTeXColor[\"royalpurple\"]=\"#401AFF\";LaTeXColor[\"blueviolet\"]=\"#1A0DF5\";LaTeXColor[\"periwinkle\"]=\"#6E73FF\";LaTeXColor[\"cadetblue\"]=\"#616EC4\";LaTeXColor[\"cornflowerblue\"]=\"#59DEFF\";LaTeXColor[\"midnightblue\"]=\"#007091\";LaTeXColor[\"navyblue\"]=\"#0F75FF\";LaTeXColor[\"royalblue\"]=\"#0080FF\";LaTeXColor[\"blue\"]=\"#0000FF\";LaTeXColor[\"cerulean\"]=\"#0FE3FF\";LaTeXColor[\"cyan\"]=\"#00FFFF\";LaTeXColor[\"processblue\"]=\"#0AFFFF\";LaTeXColor[\"skyblue\"]=\"#61FFE0\";LaTeXColor[\"turquoise\"]=\"#26FFCC\";LaTeXColor[\"tealblue\"]=\"#1FFAA3\";LaTeXColor[\"aquamarine\"]=\"#2EFFB2\";LaTeXColor[\"bluegreen\"]=\"#26FFAB\";LaTeXColor[\"emerald\"]=\"#00FF80\";LaTeXColor[\"junglegreen\"]=\"#03FF7A\";LaTeXColor[\"seagreen\"]=\"#4FFF80\";LaTeXColor[\"green\"]=\"#00FF00\";LaTeXColor[\"forestgreen\"]=\"#00E000\";LaTeXColor[\"pinegreen\"]=\"#00BF29\";LaTeXColor[\"limegreen\"]=\"#80FF00\";LaTeXColor[\"yellowgreen\"]=\"#8FFF42\";LaTeXColor[\"springgreen\"]=\"#BDFF3D\";LaTeXColor[\"olivegreen\"]=\"#009900\";LaTeXColor[\"rawsienna\"]=\"#8C0000\";LaTeXColor[\"sepia\"]=\"#4D0000\";LaTeXColor[\"brown\"]=\"#660000\";LaTeXColor[\"tan\"]=\"#DB9470\";LaTeXColor[\"gray\"]=\"#808080\";LaTeXColor[\"grey\"]=\"#808080\";LaTeXColor[\"black\"]=\"#000000\";LaTeXColor[\"white\"]=\"#FFFFFF\";var IsColorName=/^(?:greenyellow|yellow|goldenrod|dandelion|apricot|peach|melon|yelloworange|orange|burntorange|bittersweet|redorange|mahogany|maroon|brickred|red|orangered|rubinered|wildstrawberry|salmon|carnationpink|magenta|violetred|rhodamine|mulberry|redviolet|fuchsia|lavender|thistle|orchid|darkorchid|purple|plum|violet|royalpurple|blueviolet|periwinkle|cadetblue|cornflowerblue|midnightblue|navyblue|royalblue|blue|cerulean|cyan|processblue|skyblue|turquoise|tealblue|aquamarine|bluegreen|emerald|junglegreen|seagreen|green|forestgreen|pinegreen|limegreen|yellowgreen|springgreen|olivegreen|rawsienna|sepia|brown|tan|gray|grey|black|white)$/;var IsCounter=/^(?:definition|proposition|lemma|theorem|corollary|example|exercise|subsection|subsubsection|figure|equation|table)$/;var IsLaTeXElement=/^(?:displayequation|title|author|address|date|abstract|keyword|section|subsection|subsubsection|ref|cite|thebibliography|definition|proposition|lemma|theorem|corollary|example|exercise|itemize|enumerate|enddefinition|endproposition|endlemma|endtheorem|endcorollary|endexample|endexercise|enditemize|endenumerate|LaTeXMathMLlabel|LaTeXMathML|smallskip|medskip|bigskip|quote|quotation|endquote|endquotation|center|endcenter|description|enddescription|inlinemath)$/;var IsTextOnlyArea=/^(?:form|textarea|pre)$/i;var tableid=0;function makeNumberString(cntr){if(sectionCntr>0){if(inAppendix){return\"A\"+sectionCntr+\".\"+cntr;}else{return sectionCntr+\".\"+cntr;}}else{return\"\"+cntr;}};function LaTeXpreProcess(thebody){var TheBody=thebody;if(TheBody.hasChildNodes()){if(!(IsLaTeXElement.test(TheBody.className)))\n{for(var i=0;i<TheBody.childNodes.length;i++){LaTeXpreProcess(TheBody.childNodes[i])}}}\nelse{if(TheBody.nodeType==3&&!(IsTextOnlyArea.test(TheBody.parentNode.nodeName)))\n{var str=TheBody.nodeValue;if(!(str==null)){str=str.replace(/\\\\%/g,\"<per>\");str=str.replace(/%[^\\n]*(?=\\n)/g,\"\");str=str.replace(/%[^\\r]*(?=\\r)/g,\"\");str=str.replace(/%[^\\n]*$/,\"\")\nif(isIE&&str.match(/%/g)!=null&&IEcommentWarning){alert(\"Comments may not have parsed properly.  Try putting in <pre class='LaTeX><div>..</div></pre> structure.\");IEcommentWarning=false;}\nstr=str.replace(/<per>/g,\"%\");if(str.match(/XXX[\\s\\S]*/)!=null){var tmp=str.match(/XXX[\\s\\S]*/)[0];var tmpstr=tmp.charCodeAt(7)+\"::\"+tmp.charCodeAt(8)+\"::\"+tmp.charCodeAt(9)+\"::\"+tmp.charCodeAt(10)+\"::\"+tmp.charCodeAt(11)+\"::\"+tmp.charCodeAt(12)+\"::\"+tmp.charCodeAt(13);alert(tmpstr);}\nstr=str.replace(/([^\\\\])\\\\(\\s)/g,\"$1\\u00A0$2\");str=str.replace(/\\\\quad/g,\"\\u2001\");str=str.replace(/\\\\qquad/g,\"\\u2001\\u2001\");str=str.replace(/\\\\enspace/g,\"\\u2002\");str=str.replace(/\\\\;/g,\"\\u2004\");str=str.replace(/\\\\:/g,\"\\u2005\");str=str.replace(/\\\\,/g,\"\\u2006\");str=str.replace(/\\\\thinspace/g,\"\\u200A\");str=str.replace(/([^\\\\])~/g,\"$1\\u00A0\");str=str.replace(/\\\\~/g,\"~\");str=str.replace(/\\\\\\[/g,\" <DEQ> $\\\\displaystyle{\");str=str.replace(/\\\\\\]/g,\"}$ <DEQ> \");str=str.replace(/\\$\\$/g,\"${$<DEQ>$}$\");str=str.replace(/\\\\begin\\s*\\{\\s*array\\s*\\}/g,\"\\\\begin{array}\");str=str.replace(/\\\\end\\s*\\{\\s*array\\s*\\}/g,\"\\\\end{array}\");str=str.replace(/\\\\begin\\s*\\{\\s*eqnarray\\s*\\}/g,\"  <DEQ>eqno$\\\\begin{eqnarray}\");str=str.replace(/\\\\end\\s*\\{\\s*eqnarray\\s*\\}/g,\"\\\\end{eqnarray}$<DEQ>  \");str=str.replace(/\\\\begin\\s*\\{\\s*eqnarray\\*\\s*\\}/g,\"  <DEQ>$\\\\begin{eqnarray}\");str=str.replace(/\\\\end\\s*\\{\\s*eqnarray\\*\\s*\\}/g,\"\\\\end{eqnarray}$<DEQ>  \");str=str.replace(/\\\\begin\\s*\\{\\s*displaymath\\s*\\}/g,\" <DEQ> $\\\\displaystyle{\");str=str.replace(/\\\\end\\s*\\{\\s*displaymath\\s*\\}/g,\"}$ <DEQ> \");str=str.replace(/\\\\begin\\s*\\{\\s*equation\\s*\\*\\s*\\}/g,\" <DEQ> $\\\\displaystyle{\");str=str.replace(/\\\\end\\s*\\{\\s*equation\\s*\\*\\s*\\}/g,\"}$ <DEQ> \");str=str.replace(/\\\\begin\\s*\\{\\s*equation\\s*\\}/g,\" <DEQ>eqno$\\\\displaystyle{\");str=str.replace(/\\\\end\\s*\\{\\s*equation\\s*\\}/g,\"}$ <DEQ> \");str=str.split(\"<DEQ>\");var newFrag=document.createDocumentFragment();for(var i=0;i<str.length;i++){if(i%2){var DEQtable=document.createElement(\"table\");DEQtable.className='displayequation';var DEQtbody=document.createElement(\"tbody\");var DEQtr=document.createElement(\"tr\");var DEQtdeq=document.createElement(\"td\");DEQtdeq.className='eq';str[i]=str[i].replace(/\\$\\}\\$/g,\"$\\\\displaystyle{\");str[i]=str[i].replace(/\\$\\{\\$/g,\"}\");var lbl=str[i].match(/\\\\label\\s*\\{\\s*(\\w+)\\s*\\}/);var ISeqno=str[i].match(/^eqno/);str[i]=str[i].replace(/^eqno/,\" \");str[i]=str[i].replace(/\\\\label\\s*\\{\\s*\\w+\\s*\\}/,\" \");DEQtdeq.appendChild(document.createTextNode(str[i]));DEQtr.appendChild(DEQtdeq);str[i]=str[i].replace(/\\\\nonumber/g,\"\");if(ISeqno!=null||lbl!=null){var DEQtdno=document.createElement(\"td\");DEQtdno.className='eqno';LaTeXCounter[\"equation\"]++;var eqnoString=makeNumberString(LaTeXCounter[\"equation\"]);var DEQanchor=document.createElement(\"a\");if(lbl!=null){DEQanchor.id=lbl[1]};DEQanchor.className=\"eqno\";var anchorSpan=document.createElement(\"span\");anchorSpan.className=\"eqno\";anchorSpan.style.display=\"none\";anchorSpan.appendChild(document.createTextNode(eqnoString));DEQanchor.appendChild(anchorSpan);DEQtdno.appendChild(DEQanchor);var DEQspan=document.createElement(\"span\");DEQspan.className=\"eqno\";DEQspan.appendChild(document.createTextNode(\"(\"+eqnoString+\")\"));DEQtdno.appendChild(DEQspan);DEQtr.appendChild(DEQtdno);}\nDEQtbody.appendChild(DEQtr);DEQtable.appendChild(DEQtbody);newFrag.appendChild(DEQtable);}\nelse{str[i]=str[i].replace(/\\$\\}\\$/g,\"\");str[i]=str[i].replace(/\\$\\{\\$/g,\"\");str[i]=str[i].replace(/\\\\maketitle/g,\"\");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*document\\s*\\}/g,\"\");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*document\\s*\\}/g,\"\");str[i]=str[i].replace(/\\\\documentclass[^\\}]*?\\}/g,\"\");str[i]=str[i].replace(/\\\\usepackage[^\\}]*?\\}/g,\"\");str[i]=str[i].replace(/\\\\noindent/g,\"\");str[i]=str[i].replace(/\\\\notag/g,\"\");str[i]=str[i].replace(/\\\\ref\\s*\\{\\s*(\\w+)\\}/g,\" \\\\[ref\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\url\\s*\\{\\s*([^\\}\\n]+)\\}/g,\" \\\\[url\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\href\\s*\\{\\s*([^\\}]+)\\}\\s*\\{\\s*([^\\}]+)\\}/g,\" \\\\[href\\\\]$1\\\\]$2\\\\[ \");str[i]=str[i].replace(/\\\\cite\\s*\\{\\s*(\\w+)\\}/g,\" \\\\[cite\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\qed/g,\"\\u220E\");str[i]=str[i].replace(/\\\\endproof/g,\"\\u220E\");str[i]=str[i].replace(/\\\\proof/g,\"\\\\textbf{Proof: }\");str[i]=str[i].replace(/\\\\n(?=\\s)/g,\" \\\\[br\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\newline/g,\" \\\\[br\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\linebreak/g,\" \\\\[br\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\smallskip/g,\" \\\\[logicalbreak\\\\]smallskip\\\\[ \");str[i]=str[i].replace(/\\\\medskip/g,\" \\\\[logicalbreak\\\\]medskip\\\\[ \");str[i]=str[i].replace(/\\\\bigskip/g,\" \\\\[logicalbreak\\\\]bigskip\\\\[ \");str[i]=str[i].replace(/[\\n\\r]+[ \\f\\n\\r\\t\\v\\u2028\\u2029]*[\\n\\r]+/g,\" \\\\[logicalbreak\\\\]LaTeXMathML\\\\[ \");if(isIE){str[i]=str[i].replace(/\\r/g,\" \");}\nstr[i]=str[i].replace(/\\\\bibitem\\s*([^\\{]*\\{\\s*\\w*\\s*\\})/g,\" \\\\[bibitem\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\bibitem\\s*/g,\" \\\\[bibitem\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\item\\s*\\[\\s*(\\w+)\\s*\\]/g,\" \\\\[alistitem\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\item\\s*/g,\" \\\\[alistitem\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\appendix/g,\" \\\\[appendix\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*figure\\s*\\}([\\s\\S]+?)\\\\end\\s*\\{\\s*figure\\s*\\}/g,\" \\\\[figure\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*table\\s*\\}([\\s\\S]+?)\\\\end\\s*\\{\\s*table\\s*\\}/g,\" \\\\[table\\\\]$1\\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*theorem\\s*\\}/g,\" \\\\[theorem\\\\]Theorem \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*theorem\\s*\\}/g,\" \\\\[endtheorem\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*definition\\s*\\}/g,\" \\\\[definition\\\\]Definition \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*definition\\s*\\}/g,\" \\\\[enddefinition\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*lemma\\s*\\}/g,\" \\\\[lemma\\\\]Lemma \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*lemma\\s*\\}/g,\" \\\\[endlemma\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*corollary\\s*\\}/g,\" \\\\[corollary\\\\]Corollary \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*corollary\\s*\\}/g,\" \\\\[endcorollary\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*proposition\\s*\\}/g,\" \\\\[proposition\\\\]Proposition \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*proposition\\s*\\}/g,\" \\\\[endproposition\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*example\\s*\\}/g,\" \\\\[example\\\\]Example \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*example\\s*\\}/g,\" \\\\[endexample\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*exercise\\s*\\}/g,\" \\\\[exercise\\\\]Exercise \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*exercise\\s*\\}/g,\" \\\\[endexercise\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*thebibliography\\s*\\}\\s*\\{\\s*\\w+\\s*\\}/g,\" \\\\[thebibliography\\\\]References \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*thebibliography\\s*\\}/g,\" \\\\[thebibliography\\\\]References \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*thebibliography\\s*\\}/g,\" \\\\[endthebibliography\\\\]References \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*proof\\s*\\}/g,\" \\\\[proof\\\\]Proof: \\\\[ \");if(isIE){str[i]=str[i].replace(/\\\\end\\s*\\{\\s*proof\\s*\\}/g,\"\\u220E \\\\[endproof\\\\] \\\\[ \");}else{str[i]=str[i].replace(/\\\\end\\s*\\{\\s*proof\\s*\\}/g,\" \\\\[endproof\\\\] \\\\[ \");}\nstr[i]=str[i].replace(/\\\\title\\s*\\{\\s*([^\\}]+)\\}/g,\" \\\\[title\\\\] \\\\[$1 \\\\[endtitle\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\author\\s*\\{\\s*([^\\}]+)\\}/g,\" \\\\[author\\\\] \\\\[$1 \\\\[endauthor\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\address\\s*\\{\\s*([^\\}]+)\\}/g,\" \\\\[address\\\\] \\\\[$1 \\\\[endaddress\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\date\\s*\\{\\s*([^\\}]+)\\}/g,\" \\\\[date\\\\] \\\\[$1 \\\\[enddate\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*keyword\\s*\\}/g,\" \\\\[keyword\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*keyword\\s*\\}/g,\" \\\\[endkeyword\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*abstract\\s*\\}/g,\" \\\\[abstract\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*abstract\\s*\\}/g,\" \\\\[endabstract\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\begin\\s*\\{\\s*(?!array|tabular)(\\w+)\\s*\\}/g,\" \\\\[$1\\\\] \\\\[ \");str[i]=str[i].replace(/\\\\end\\s*\\{\\s*(?!array|tabular)(\\w+)\\s*\\}/g,\" \\\\[end$1\\\\] \\\\[ \");var sectionIndex=str[i].search(/\\\\section\\s*\\{\\s*[\\s\\S]+\\}/);while(sectionIndex>=0){str[i]=str[i].replace(/\\\\section\\s*\\{/,\" \\\\[section\\\\]\");var delimcnt=1;for(var ii=sectionIndex;ii<str[i].length;ii++){if(str[i].charAt(ii)==\"{\"){delimcnt++};if(str[i].charAt(ii)==\"}\"){delimcnt--};if(delimcnt==0){str[i]=str[i].substring(0,ii)+\"\\\\[ \"+str[i].substring(ii+1,str[i].length);break;}};sectionIndex=str[i].search(/\\\\section\\s*\\{\\s*[\\s\\S]+\\}/);}\nsectionIndex=str[i].search(/\\\\subsection\\s*\\{\\s*[\\s\\S]+\\}/);while(sectionIndex>=0){str[i]=str[i].replace(/\\\\subsection\\s*\\{/,\" \\\\[subsection\\\\]\");var delimcnt=1;for(var ii=sectionIndex;ii<str[i].length;ii++){if(str[i].charAt(ii)==\"{\"){delimcnt++};if(str[i].charAt(ii)==\"}\"){delimcnt--};if(delimcnt==0){str[i]=str[i].substring(0,ii)+\"\\\\[ \"+str[i].substring(ii+1,str[i].length);break;}};sectionIndex=str[i].search(/\\\\subsection\\s*\\{\\s*[\\s\\S]+\\}/);}\nsectionIndex=str[i].search(/\\\\subsubsection\\s*\\{\\s*[\\s\\S]+\\}/);while(sectionIndex>=0){str[i]=str[i].replace(/\\\\subsubsection\\s*\\{/,\" \\\\[subsubsection\\\\]\");var delimcnt=1;for(var ii=sectionIndex;ii<str[i].length;ii++){if(str[i].charAt(ii)==\"{\"){delimcnt++};if(str[i].charAt(ii)==\"}\"){delimcnt--};if(delimcnt==0){str[i]=str[i].substring(0,ii)+\"\\\\[ \"+str[i].substring(ii+1,str[i].length);break;}};sectionIndex=str[i].search(/\\\\subsubsection\\s*\\{\\s*[\\s\\S]+\\}/);}\nvar CatToNextEven=\"\";var strtmp=str[i].split(\"\\\\[\");for(var j=0;j<strtmp.length;j++){if(j%2){var strtmparray=strtmp[j].split(\"\\\\]\");switch(strtmparray[0]){case\"section\":var nodeTmp=document.createElement(\"H2\");nodeTmp.className='section';sectionCntr++;for(var div in LaTeXCounter){LaTeXCounter[div]=0};var nodeAnchor=document.createElement(\"a\");if(inAppendix){nodeAnchor.className='appendixsection';}else{nodeAnchor.className='section';}\nvar nodeNumString=makeNumberString(\"\");var anchorSpan=document.createElement(\"span\");anchorSpan.className=\"section\";anchorSpan.style.display=\"none\";anchorSpan.appendChild(document.createTextNode(nodeNumString));nodeAnchor.appendChild(anchorSpan);nodeTmp.appendChild(nodeAnchor);var nodeSpan=document.createElement(\"span\");nodeSpan.className='section';nodeSpan.appendChild(document.createTextNode(nodeNumString+\" \"));nodeTmp.appendChild(nodeSpan);nodeTmp.appendChild(document.createTextNode(strtmparray[1]));newFrag.appendChild(nodeTmp);break;case\"subsection\":var nodeTmp=document.createElement(\"H3\");nodeTmp.className='subsection';LaTeXCounter[\"subsection\"]++;LaTeXCounter[\"subsubsection\"]=0;var nodeAnchor=document.createElement(\"a\");nodeAnchor.className='subsection';var nodeNumString=makeNumberString(LaTeXCounter[\"subsection\"]);var anchorSpan=document.createElement(\"span\");anchorSpan.className=\"subsection\";anchorSpan.style.display=\"none\";anchorSpan.appendChild(document.createTextNode(nodeNumString));nodeAnchor.appendChild(anchorSpan);nodeTmp.appendChild(nodeAnchor);var nodeSpan=document.createElement(\"span\");nodeSpan.className='subsection';nodeSpan.appendChild(document.createTextNode(nodeNumString+\". \"));nodeTmp.appendChild(nodeSpan);nodeTmp.appendChild(document.createTextNode(strtmparray[1]));newFrag.appendChild(nodeTmp);break;case\"subsubsection\":var nodeTmp=document.createElement(\"H4\");nodeTmp.className='subsubsection';LaTeXCounter[\"subsubsection\"]++;var nodeAnchor=document.createElement(\"a\");nodeAnchor.className='subsubsection';var nodeNumString=makeNumberString(LaTeXCounter[\"subsection\"]+\".\"+LaTeXCounter[\"subsubsection\"]);var anchorSpan=document.createElement(\"span\");anchorSpan.className=\"subsubsection\";anchorSpan.style.display=\"none\";anchorSpan.appendChild(document.createTextNode(nodeNumString));nodeAnchor.appendChild(anchorSpan);nodeTmp.appendChild(nodeAnchor);var nodeSpan=document.createElement(\"span\");nodeSpan.className='subsubsection';nodeSpan.appendChild(document.createTextNode(nodeNumString+\". \"));nodeTmp.appendChild(nodeSpan);nodeTmp.appendChild(document.createTextNode(strtmparray[1]));newFrag.appendChild(nodeTmp);break;case\"href\":var nodeTmp=document.createElement(\"a\");nodeTmp.className='LaTeXMathML';nodeTmp.href=strtmparray[1];nodeTmp.appendChild(document.createTextNode(strtmparray[2]));newFrag.appendChild(nodeTmp);break;case\"url\":var nodeTmp=document.createElement(\"a\");nodeTmp.className='LaTeXMathML';nodeTmp.href=strtmparray[1];nodeTmp.appendChild(document.createTextNode(strtmparray[1]));newFrag.appendChild(nodeTmp);break;case\"figure\":var nodeTmp=document.createElement(\"table\");nodeTmp.className='figure';var FIGtbody=document.createElement(\"tbody\");var FIGlbl=strtmparray[1].match(/\\\\label\\s*\\{\\s*(\\w+)\\s*\\}/);strtmparray[1]=strtmparray[1].replace(/\\\\label\\s*\\{\\w+\\}/g,\"\");var capIndex=strtmparray[1].search(/\\\\caption\\s*\\{[\\s\\S]+\\}/);var FIGcap=\"\";if(capIndex>=0){var tmp=strtmparray[1];var delimcnt=0;var capstart=-1;for(var pos=capIndex;pos<tmp.length;pos++){if(tmp.charAt(pos)==\"{\"){delimcnt++};if(tmp.charAt(pos)==\"}\"){delimcnt--};if(delimcnt==1&&capstart<0){capstart=pos+1};if(delimcnt==0&&capstart>0){capend=pos-1;FIGcap=tmp.substring(capstart,pos);break}}}\nvar FIGtr2=document.createElement(\"tr\");var FIGtd2=document.createElement(\"td\");FIGtd2.className=\"caption\";var FIGanchor=document.createElement(\"a\");FIGanchor.className=\"figure\";if(FIGlbl!=null){FIGanchor.id=FIGlbl[1];}\nLaTeXCounter[\"figure\"]++;var fignmbr=makeNumberString(LaTeXCounter[\"figure\"]);var anchorSpan=document.createElement(\"span\");anchorSpan.className=\"figure\";anchorSpan.style.display=\"none\";anchorSpan.appendChild(document.createTextNode(fignmbr));FIGanchor.appendChild(anchorSpan);FIGtd2.appendChild(FIGanchor);var FIGspan=document.createElement(\"span\");FIGspan.className=\"figure\";FIGspan.appendChild(document.createTextNode(\"Figure \"+fignmbr+\". \"));FIGtd2.appendChild(FIGspan);FIGtd2.appendChild(document.createTextNode(\"\"+FIGcap));FIGtr2.appendChild(FIGtd2);FIGtbody.appendChild(FIGtr2);var IsSpecial=false;var FIGinfo=strtmparray[1].match(/\\\\includegraphics\\s*\\{([^\\}]+)\\}/);if(FIGinfo==null){FIGinfo=strtmparray[1].match(/\\\\includegraphics\\s*\\[[^\\]]*\\]\\s*\\{\\s*([^\\}]+)\\s*\\}/);}\nif(FIGinfo==null){FIGinfo=strtmparray[1].match(/\\\\special\\s*\\{\\s*([^\\}]+)\\}/);IsSpecial=true};if(FIGinfo!=null){var FIGtr1=document.createElement(\"tr\");var FIGtd1=document.createElement(\"td\");FIGtd1.className=\"image\";var FIGimg=document.createElement(\"img\");var FIGsrc=FIGinfo[1];FIGimg.src=FIGsrc;FIGimg.alt=\"Figure \"+FIGsrc+\" did not load\";FIGimg.title=\"Figure \"+fignmbr+\". \"+FIGcap;FIGimg.id=\"figure\"+fignmbr;FIGtd1.appendChild(FIGimg);FIGtr1.appendChild(FIGtd1);FIGtbody.appendChild(FIGtr1);}\nnodeTmp.appendChild(FIGtbody);newFrag.appendChild(nodeTmp);break;case\"table\":var nodeTmp=document.createElement(\"table\");if(strtmparray[1].search(/\\\\centering/)>=0){nodeTmp.className='LaTeXtable centered';nodeTmp.align=\"center\";}else{nodeTmp.className='LaTeXtable';};tableid++;nodeTmp.id=\"LaTeXtable\"+tableid;var TABlbl=strtmparray[1].match(/\\\\label\\s*\\{\\s*(\\w+)\\s*\\}/);strtmparray[1]=strtmparray[1].replace(/\\\\label\\s*\\{\\w+\\}/g,\"\");var capIndex=strtmparray[1].search(/\\\\caption\\s*\\{[\\s\\S]+\\}/);var TABcap=\"\";if(capIndex>=0){var tmp=strtmparray[1];var delimcnt=0;var capstart=-1;for(var pos=capIndex;pos<tmp.length;pos++){if(tmp.charAt(pos)==\"{\"){delimcnt++};if(tmp.charAt(pos)==\"}\"){delimcnt--};if(delimcnt==1&&capstart<0){capstart=pos+1};if(delimcnt==0&&capstart>0){capend=pos-1;TABcap=tmp.substring(capstart,pos);break}}}\nif(TABcap!=\"\"){var TABtbody=document.createElement(\"tbody\");var TABcaption=document.createElement(\"caption\");TABcaption.className=\"LaTeXtable centered\";var TABanchor=document.createElement(\"a\");TABanchor.className=\"LaTeXtable\";if(TABlbl!=null){TABanchor.id=TABlbl[1];}\nLaTeXCounter[\"table\"]++;var tabnmbr=makeNumberString(LaTeXCounter[\"table\"]);var anchorSpan=document.createElement(\"span\");anchorSpan.className=\"LaTeXtable\";anchorSpan.style.display=\"none\";anchorSpan.appendChild(document.createTextNode(tabnmbr));TABanchor.appendChild(anchorSpan);TABcaption.appendChild(TABanchor);var TABspan=document.createElement(\"span\");TABspan.className=\"LaTeXtable\";TABspan.appendChild(document.createTextNode(\"Table \"+tabnmbr+\". \"));TABcaption.appendChild(TABspan);TABcaption.appendChild(document.createTextNode(\"\"+TABcap));nodeTmp.appendChild(TABcaption);}\nvar TABinfo=strtmparray[1].match(/\\\\begin\\s*\\{\\s*tabular\\s*\\}([\\s\\S]+)\\\\end\\s*\\{\\s*tabular\\s*\\}/);if(TABinfo!=null){var TABtbody=document.createElement('tbody');var TABrow=null;var TABcell=null;var row=0;var col=0;var TABalign=TABinfo[1].match(/^\\s*\\{([^\\}]+)\\}/);TABinfo=TABinfo[1].replace(/^\\s*\\{[^\\}]+\\}/,\"\");TABinfo=TABinfo.replace(/\\\\hline/g,\"\");TABalign[1]=TABalign[1].replace(/\\|/g,\"\");TABalign[1]=TABalign[1].replace(/\\s/g,\"\");TABinfo=TABinfo.split(\"\\\\\\\\\");for(row=0;row<TABinfo.length;row++){TABrow=document.createElement(\"tr\");TABinfo[row]=TABinfo[row].split(\"&\");for(col=0;col<TABinfo[row].length;col++){TABcell=document.createElement(\"td\");switch(TABalign[1].charAt(col)){case\"l\":TABcell.align=\"left\";break;case\"c\":TABcell.align=\"center\";break;case\"r\":TABcell.align=\"right\";break;default:TABcell.align=\"left\";};TABcell.appendChild(document.createTextNode(TABinfo[row][col]));TABrow.appendChild(TABcell);}\nTABtbody.appendChild(TABrow);}\nnodeTmp.appendChild(TABtbody);}\nnewFrag.appendChild(nodeTmp);break;case\"logicalbreak\":var nodeTmp=document.createElement(\"p\");nodeTmp.className=strtmparray[1];nodeTmp.appendChild(document.createTextNode(\"\\u00A0\"));newFrag.appendChild(nodeTmp);break;case\"appendix\":inAppendix=true;sectionCntr=0;break;case\"alistitem\":var EndDiv=document.createElement(\"div\");EndDiv.className=\"endlistitem\";newFrag.appendChild(EndDiv);var BegDiv=document.createElement(\"div\");BegDiv.className=\"listitem\";if(strtmparray[1]!=\" \"){var BegSpan=document.createElement(\"span\");BegSpan.className=\"listitemmarker\";var boldBegSpan=document.createElement(\"b\");boldBegSpan.appendChild(document.createTextNode(strtmparray[1]+\" \"));BegSpan.appendChild(boldBegSpan);BegDiv.appendChild(BegSpan);}\nnewFrag.appendChild(BegDiv);break;case\"br\":newFrag.appendChild(document.createElement(\"br\"));break;case\"bibitem\":newFrag.appendChild(document.createElement(\"br\"));var nodeTmp=document.createElement(\"a\");nodeTmp.className='bibitem';var nodeSpan=document.createElement(\"span\");nodeSpan.className='bibitem';bibcntr++;var lbl=strtmparray[1].match(/\\{\\s*(\\w+)\\s*\\}/);strtmparray[1]=strtmparray[1].replace(/\\s*\\{\\s*\\w+\\s*\\}/g,\"\");strtmparray[1]=strtmparray[1].replace(/^\\s*\\[/,\"\");strtmparray[1]=strtmparray[1].replace(/\\s*\\]$/,\"\");strtmparray[1]=strtmparray[1].replace(/^\\s+|\\s+$/g,\"\");if(lbl==null){biblist[bibcntr]=\"bibitem\"+bibcntr}else{biblist[bibcntr]=lbl[1];};nodeTmp.name=biblist[bibcntr];nodeTmp.id=biblist[bibcntr];if(strtmparray[1]!=\"\"){nodeSpan.appendChild(document.createTextNode(strtmparray[1]));}else{nodeSpan.appendChild(document.createTextNode(\"[\"+bibcntr+\"]\"));}\nnodeTmp.appendChild(nodeSpan);newFrag.appendChild(nodeTmp);break;case\"cite\":var nodeTmp=document.createElement(\"a\");nodeTmp.className='cite';nodeTmp.name='cite';nodeTmp.href=\"#\"+strtmparray[1];newFrag.appendChild(nodeTmp);break;case\"ref\":var nodeTmp=document.createElement(\"a\");nodeTmp.className='ref';nodeTmp.name='ref';nodeTmp.href=\"#\"+strtmparray[1];newFrag.appendChild(nodeTmp);break;default:var nodeTmp=document.createElement(\"div\");nodeTmp.className=strtmparray[0];if(IsCounter.test(strtmparray[0])){LaTeXCounter[strtmparray[0]]++;var nodeAnchor=document.createElement(\"a\");nodeAnchor.className=strtmparray[0];var divnum=makeNumberString(LaTeXCounter[strtmparray[0]]);var anchorSpan=document.createElement(\"span\");anchorSpan.className=strtmparray[0];anchorSpan.appendChild(document.createTextNode(divnum));anchorSpan.style.display=\"none\";nodeAnchor.appendChild(anchorSpan);nodeTmp.appendChild(nodeAnchor);var nodeSpan=document.createElement(\"span\");nodeSpan.className=strtmparray[0];nodeSpan.appendChild(document.createTextNode(strtmparray[1]+\" \"+divnum+\". \"));nodeTmp.appendChild(nodeSpan);}\nif(isIE){if(strtmparray[0]==(\"thebibliography\"||\"abstract\"||\"keyword\"||\"proof\")){var nodeSpan=document.createElement(\"span\");nodeSpan.className=strtmparray[0];nodeSpan.appendChild(document.createTextNode(strtmparray[1]));nodeTmp.appendChild(nodeSpan);}}\nif(strtmparray[0]==\"endenumerate\"||strtmparray[0]==\"enditemize\"||strtmparray[0]==\"enddescription\"){var endDiv=document.createElement(\"div\");endDiv.className=\"endlistitem\";newFrag.appendChild(endDiv);}\nnewFrag.appendChild(nodeTmp);if(strtmparray[0]==\"enumerate\"||strtmparray[0]==\"itemize\"||strtmparray[0]==\"description\"){var endDiv=document.createElement(\"div\");endDiv.className=\"listitem\";newFrag.appendChild(endDiv);}}}else{strtmp[j]=strtmp[j].replace(/\\\\\\$/g,\"<per>\");strtmp[j]=strtmp[j].replace(/\\$([^\\$]+)\\$/g,\" \\\\[$1\\\\[ \");strtmp[j]=strtmp[j].replace(/<per>/g,\"\\\\$\");strtmp[j]=strtmp[j].replace(/\\\\begin\\s*\\{\\s*math\\s*\\}([\\s\\S]+?)\\\\end\\s*\\{\\s*math\\s*\\}/g,\" \\\\[$1\\\\[ \");var strtmptmp=strtmp[j].split(\"\\\\[\");for(var jjj=0;jjj<strtmptmp.length;jjj++){if(jjj%2){var nodeTmp=document.createElement(\"span\");nodeTmp.className='inlinemath';nodeTmp.appendChild(document.createTextNode(\"$\"+strtmptmp[jjj]+\"$\"));newFrag.appendChild(nodeTmp);}else{var TagIndex=strtmptmp[jjj].search(/\\\\\\w+/);var tmpIndex=TagIndex;while(tmpIndex>-1){if(/^\\\\textcolor/.test(strtmptmp[jjj].substring(TagIndex,strtmptmp[jjj].length))){strtmptmp[jjj]=strtmptmp[jjj].replace(/\\\\textcolor\\s*\\{\\s*(\\w+)\\s*\\}\\s*/,\" \\\\[textcolor\\\\]$1\\\\]|\");}else{if(/^\\\\colorbox/.test(strtmptmp[jjj].substring(TagIndex,strtmptmp[jjj].length))){strtmptmp[jjj]=strtmptmp[jjj].replace(/\\\\colorbox\\s*\\{\\s*(\\w+)\\s*\\}\\s*/,\" \\\\[colorbox\\\\]$1\\\\]|\");}else{strtmptmp[jjj]=strtmptmp[jjj].substring(0,TagIndex)+strtmptmp[jjj].substring(TagIndex,strtmptmp[jjj].length).replace(/\\\\\\s*(\\w+)\\s*/,\" \\\\[$1\\\\]|\");}}\nTagIndex+=strtmptmp[jjj].substring(TagIndex,strtmptmp[jjj].length).search(/\\|/);TagIndex++;strtmptmp[jjj]=strtmptmp[jjj].replace(/\\\\\\]\\|/,\"\\\\] \");if(strtmptmp[jjj].charAt(TagIndex)==\"{\"){strtmptmp[jjj]=strtmptmp[jjj].substring(0,TagIndex)+strtmptmp[jjj].substring(TagIndex+1,strtmptmp[jjj].length);var delimcnt=1;for(var kk=TagIndex;kk<strtmptmp[jjj].length;kk++){if(strtmptmp[jjj].charAt(kk)==\"{\"){delimcnt++};if(strtmptmp[jjj].charAt(kk)==\"}\"){delimcnt--};if(delimcnt==0){break;}}\nstrtmptmp[jjj]=strtmptmp[jjj].substring(0,kk)+\"\\\\[ \"+strtmptmp[jjj].substring(kk+1,strtmptmp[jjj].length);TagIndex=kk+3;}else{strtmptmp[jjj]=strtmptmp[jjj].substring(0,TagIndex)+\"\\\\[ \"+strtmptmp[jjj].substring(TagIndex+1,strtmptmp[jjj].length);TagIndex=TagIndex+3;}\nif(TagIndex<strtmptmp[jjj].length){tmpIndex=strtmptmp[jjj].substring(TagIndex,strtmptmp[jjj].length).search(/\\\\\\w+/);}\nelse{tmpIndex=-1};TagIndex+=tmpIndex;}\nstrtmptmp[jjj]=strtmptmp[jjj].replace(/\\\\\\\\\\s*\\\\\\\\/g,\"\\\\\\\\\");strtmptmp[jjj]=strtmptmp[jjj].replace(/\\\\\\\\/g,\" \\\\[br\\\\] \\\\[ \");strtmptmp[jjj]=strtmptmp[jjj].replace(/\\\\label\\s*\\{\\s*(\\w+)\\s*\\}/g,\" \\\\[a\\\\]$1\\\\[ \");var strlbls=strtmptmp[jjj].split(\"\\\\[\");for(var jj=0;jj<strlbls.length;jj++){if(jj%2){var strtmparray=strlbls[jj].split(\"\\\\]\");switch(strtmparray[0]){case\"textcolor\":var nodeTmp=document.createElement(\"span\");nodeTmp.className='LaTeXColor';if(IsColorName.test(strtmparray[1].toLowerCase())){nodeTmp.style.color=LaTeXColor[strtmparray[1].toLowerCase()];}else{nodeTmp.style.color=strtmparray[1];};nodeTmp.appendChild(document.createTextNode(strtmparray[2]));newFrag.appendChild(nodeTmp);break;case\"colorbox\":var nodeTmp=document.createElement(\"span\");nodeTmp.className='LaTeXColor';if(IsColorName.test(strtmparray[1].toLowerCase())){nodeTmp.style.background=LaTeXColor[strtmparray[1].toLowerCase()];}else{nodeTmp.style.background=strtmparray[1];};nodeTmp.appendChild(document.createTextNode(strtmparray[2]));newFrag.appendChild(nodeTmp);break;case\"br\":newFrag.appendChild(document.createElement(\"br\"));break;case\"a\":var nodeTmp=document.createElement(\"a\");nodeTmp.className='LaTeXMathMLlabel';nodeTmp.id=strtmparray[1];nodeTmp.style.display=\"none\";newFrag.appendChild(nodeTmp);break;default:var nodeTmp=document.createElement(\"span\");nodeTmp.className=strtmparray[0];nodeTmp.appendChild(document.createTextNode(strtmparray[1]))\nnewFrag.appendChild(nodeTmp);}}else{newFrag.appendChild(document.createTextNode(strlbls[jj]));}}}}}}}};TheBody.parentNode.replaceChild(newFrag,TheBody);}}}\nreturn TheBody;}\nfunction LaTeXDivsAndRefs(thebody){var TheBody=thebody;var EndDivClass=null;var AllDivs=TheBody.getElementsByTagName(\"div\");var lbl2id=\"\";var lblnode=null;for(var i=AllDivs.length-1;i>=0;i--){EndDivClass=AllDivs[i].className.match(/end\\w+/);if(EndDivClass!=null){EndDivClass=EndDivClass[0];var DivClass=EndDivClass.substring(3,EndDivClass.length);var EndDivNode=AllDivs[i];break;}}\nwhile(EndDivClass!=null){var newFrag=document.createDocumentFragment();var RootNode=EndDivNode.parentNode;var ClassCount=1;while(EndDivNode.previousSibling!=null&&ClassCount>0){switch(EndDivNode.previousSibling.className){case EndDivClass:ClassCount++;newFrag.insertBefore(EndDivNode.previousSibling,newFrag.firstChild);break;case DivClass:if(EndDivNode.previousSibling.nodeName==\"DIV\"){ClassCount--;if(lbl2id!=\"\"){EndDivNode.previousSibling.id=lbl2id;lbl2id=\"\"}\nif(ClassCount==0){RootNode=EndDivNode.previousSibling;}else{newFrag.insertBefore(EndDivNode.previousSibling,newFrag.firstChild);}};break;case'LaTeXMathMLlabel':lbl2id=EndDivNode.previousSibling.id;EndDivNode.parentNode.removeChild(EndDivNode.previousSibling);break;default:newFrag.insertBefore(EndDivNode.previousSibling,newFrag.firstChild);}}\nRootNode.appendChild(newFrag);EndDivNode.parentNode.removeChild(EndDivNode);AllDivs=TheBody.getElementsByTagName(\"DIV\");for(i=AllDivs.length-1;i>=0;i--){EndDivClass=AllDivs[i].className.match(/end\\w+/);if(EndDivClass!=null){ClassCount=0;EndDivClass=EndDivClass[0];DivClass=EndDivClass.substring(3,EndDivClass.length);EndDivNode=AllDivs[i];RootNode=EndDivNode.parentNode;break;}}}\nvar AllDivs=TheBody.getElementsByTagName(\"div\");var DIV2LI=null;for(var i=0;i<AllDivs.length;i++){if(AllDivs[i].className==\"itemize\"||AllDivs[i].className==\"enumerate\"||AllDivs[i].className==\"description\"){if(AllDivs[i].className==\"itemize\"){RootNode=document.createElement(\"UL\");}else{RootNode=document.createElement(\"OL\");}\nRootNode.className='LaTeXMathML';if(AllDivs[i].hasChildNodes()){AllDivs[i].removeChild(AllDivs[i].firstChild)};while(AllDivs[i].hasChildNodes()){if(AllDivs[i].firstChild.hasChildNodes()){DIV2LI=document.createElement(\"LI\");while(AllDivs[i].firstChild.hasChildNodes()){DIV2LI.appendChild(AllDivs[i].firstChild.firstChild);}\nif(DIV2LI.firstChild.className==\"listitemmarker\"){DIV2LI.style.listStyleType=\"none\";}\nRootNode.appendChild(DIV2LI)}\nAllDivs[i].removeChild(AllDivs[i].firstChild);}\nAllDivs[i].appendChild(RootNode);}}\nvar AllAnchors=TheBody.getElementsByTagName(\"a\");for(var i=0;i<AllAnchors.length;i++){if(AllAnchors[i].className==\"ref\"||AllAnchors[i].className==\"cite\"){var label=AllAnchors[i].href.match(/\\#(\\w+)/);if(label!=null){var labelNode=document.getElementById(label[1]);if(labelNode!=null){var TheSpans=labelNode.getElementsByTagName(\"SPAN\");if(TheSpans!=null){var refNode=TheSpans[0].cloneNode(true);refNode.style.display=\"inline\"\nrefNode.className=AllAnchors[i].className;AllAnchors[i].appendChild(refNode);}}}}}\nreturn TheBody;}\nvar AMbody;var AMnoMathML=false,AMtranslated=false;function translate(spanclassAM){if(!AMtranslated){AMtranslated=true;AMinitSymbols();var LaTeXContainers=[];var AllContainers=document.getElementsByTagName('*');var ExtendName=\"\";for(var k=0,l=0;k<AllContainers.length;k++){ExtendName=\" \"+AllContainers[k].className+\" \";if(ExtendName.match(/\\sLaTeX\\s/)!=null){LaTeXContainers[l]=AllContainers[k];l++;}};if(LaTeXContainers.length>0){for(var m=0;m<LaTeXContainers.length;m++){AMbody=LaTeXContainers[m];try{AMbody=LaTeXDivsAndRefs(LaTeXpreProcess(AMbody));}catch(err){alert(\"Unknown Error: Defaulting to Original LaTeXMathML\");}\nif(AMbody.tagName==\"PRE\"){var PreChilds=document.createDocumentFragment();var DivChilds=document.createElement(\"DIV\");while(AMbody.hasChildNodes()){DivChilds.appendChild(AMbody.firstChild);}\nPreChilds.appendChild(DivChilds);AMbody.parentNode.replaceChild(PreChilds,AMbody);AMbody=DivChilds;}\nAMprocessNode(AMbody,false,spanclassAM);}}else{AMbody=document.getElementsByTagName(\"body\")[0];try{AMbody=LaTeXDivsAndRefs(LaTeXpreProcess(AMbody));}catch(err){alert(\"Unknown Error: Defaulting to Original LaTeXMathML\");}\nAMprocessNode(AMbody,false,spanclassAM);}}}\nif(isIE){document.write(\"<object id=\\\"mathplayer\\\" classid=\\\"clsid:32F66A20-7614-11D4-BD11-00104BD3F987\\\"></object>\");document.write(\"<?import namespace=\\\"m\\\" implementation=\\\"#mathplayer\\\"?>\");}\nfunction generic()\n{translate();};if(typeof window.addEventListener!='undefined')\n{window.addEventListener('load',generic,false);}\nelse if(typeof document.addEventListener!='undefined')\n{document.addEventListener('load',generic,false);}\nelse if(typeof window.attachEvent!='undefined')\n{window.attachEvent('onload',generic);}\nelse\n{if(typeof window.onload=='function')\n{var existing=onload;window.onload=function()\n{existing();generic();};}\nelse\n{window.onload=generic;}}\n"),("make-reference-files.hs","import System.Environment\nimport System.Directory\nimport Codec.Archive.Zip\nimport qualified Data.ByteString.Lazy as BS\nimport qualified Control.Exception as E\nimport System.IO.Error (isDoesNotExistError)\nimport System.FilePath\n\nmkzip :: String -> IO ()\nmkzip fmt = do\n  let dir    = \"data\" </> fmt\n      output = \"data\" </> \"reference\" <.> fmt\n  cd <- getCurrentDirectory\n  setCurrentDirectory dir\n  archive <- addFilesToArchive [OptRecursive] emptyArchive [\".\"]\n  setCurrentDirectory cd\n  removeIfExists output\n  BS.writeFile output $ fromArchive archive\n\nremoveIfExists :: FilePath -> IO ()\nremoveIfExists fileName = removeFile fileName `E.catch` handleExists\n  where handleExists e\n          | isDoesNotExistError e = return ()\n          | otherwise = E.throwIO e\n\nmain :: IO ()\nmain = getArgs >>= mkzip . (!!0)\n"),("MathMLinHTML.js","/*\nMarch 19, 2004 MathHTML (c) Peter Jipsen http://www.chapman.edu/~jipsen\nReleased under the GNU General Public License version 2 or later.\nSee the GNU General Public License (at http://www.gnu.org/copyleft/gpl.html)\nfor more details.\n*/\n\nfunction convertMath(node) {// for Gecko\n  if (node.nodeType==1) {\n    var newnode =\n      document.createElementNS(\"http://www.w3.org/1998/Math/MathML\",\n        node.nodeName.toLowerCase());\n    for(var i=0; i < node.attributes.length; i++)\n      newnode.setAttribute(node.attributes[i].nodeName,\n        node.attributes[i].value);\n    for (var i=0; i<node.childNodes.length; i++) {\n      var st = node.childNodes[i].nodeValue;\n      if (st==null || st.slice(0,1)!=\" \" && st.slice(0,1)!=\"\\n\")\n        newnode.appendChild(convertMath(node.childNodes[i]));\n    }\n    return newnode;\n  }\n  else return node;\n}\n\nfunction convert() {\n  var mmlnode = document.getElementsByTagName(\"math\");\n  var st,str,node,newnode;\n  for (var i=0; i<mmlnode.length; i++)\n    if (document.createElementNS!=null)\n      mmlnode[i].parentNode.replaceChild(convertMath(mmlnode[i]),mmlnode[i]);\n    else { // convert for IE\n      str = \"\";\n      node = mmlnode[i];\n      while (node.nodeName!=\"/MATH\") {\n        st = node.nodeName.toLowerCase();\n        if (st==\"#text\") str += node.nodeValue;\n        else {\n          str += (st.slice(0,1)==\"/\" ? \"</m:\"+st.slice(1) : \"<m:\"+st);\n          if (st.slice(0,1)!=\"/\")\n             for(var j=0; j < node.attributes.length; j++)\n               if (node.attributes[j].value!=\"italic\" &&\n                 node.attributes[j].value!=\"\" &&\n                 node.attributes[j].value!=\"inherit\" &&\n                 node.attributes[j].value!=undefined)\n                 str += \" \"+node.attributes[j].nodeName+\"=\"+\n                     \"\\\"\"+node.attributes[j].value+\"\\\"\";\n          str += \">\";\n        }\n        node = node.nextSibling;\n        node.parentNode.removeChild(node.previousSibling);\n      }\n      str += \"</m:math>\";\n      newnode = document.createElement(\"span\");\n      node.parentNode.replaceChild(newnode,node);\n      newnode.innerHTML = str;\n    }\n}\n\nif (document.createElementNS==null) {\n  document.write(\"<object id=\\\"mathplayer\\\"\\\n  classid=\\\"clsid:32F66A20-7614-11D4-BD11-00104BD3F987\\\"></object>\");\n  document.write(\"<?import namespace=\\\"m\\\" implementation=\\\"#mathplayer\\\"?>\");\n}\nif(typeof window.addEventListener != 'undefined'){\n  window.addEventListener('load', convert, false);\n}\nif(typeof window.attachEvent != 'undefined') {\n  window.attachEvent('onload', convert);\n}\n"),("sample.lua","-- This is a sample custom writer for pandoc.  It produces output\n-- that is very similar to that of pandoc's HTML writer.\n-- There is one new feature: code blocks marked with class 'dot'\n-- are piped through graphviz and images are included in the HTML\n-- output using 'data:' URLs.\n--\n-- Invoke with: pandoc -t sample.lua\n--\n-- Note:  you need not have lua installed on your system to use this\n-- custom writer.  However, if you do have lua installed, you can\n-- use it to test changes to the script.  'lua sample.lua' will\n-- produce informative error messages if your code contains\n-- syntax errors.\n\n-- Character escaping\nlocal function escape(s, in_attribute)\n  return s:gsub(\"[<>&\\\"']\",\n    function(x)\n      if x == '<' then\n        return '&lt;'\n      elseif x == '>' then\n        return '&gt;'\n      elseif x == '&' then\n        return '&amp;'\n      elseif x == '\"' then\n        return '&quot;'\n      elseif x == \"'\" then\n        return '&#39;'\n      else\n        return x\n      end\n    end)\nend\n\n-- Helper function to convert an attributes table into\n-- a string that can be put into HTML tags.\nlocal function attributes(attr)\n  local attr_table = {}\n  for x,y in pairs(attr) do\n    if y and y ~= \"\" then\n      table.insert(attr_table, ' ' .. x .. '=\"' .. escape(y,true) .. '\"')\n    end\n  end\n  return table.concat(attr_table)\nend\n\n-- Run cmd on a temporary file containing inp and return result.\nlocal function pipe(cmd, inp)\n  local tmp = os.tmpname()\n  local tmph = io.open(tmp, \"w\")\n  tmph:write(inp)\n  tmph:close()\n  local outh = io.popen(cmd .. \" \" .. tmp,\"r\")\n  local result = outh:read(\"*all\")\n  outh:close()\n  os.remove(tmp)\n  return result\nend\n\n-- Table to store footnotes, so they can be included at the end.\nlocal notes = {}\n\n-- Blocksep is used to separate block elements.\nfunction Blocksep()\n  return \"\\n\\n\"\nend\n\n-- This function is called once for the whole document. Parameters:\n-- body is a string, metadata is a table, variables is a table.\n-- This gives you a fragment.  You could use the metadata table to\n-- fill variables in a custom lua template.  Or, pass `--template=...`\n-- to pandoc, and pandoc will add do the template processing as\n-- usual.\nfunction Doc(body, metadata, variables)\n  local buffer = {}\n  local function add(s)\n    table.insert(buffer, s)\n  end\n  add(body)\n  if #notes > 0 then\n    add('<ol class=\"footnotes\">')\n    for _,note in pairs(notes) do\n      add(note)\n    end\n    add('</ol>')\n  end\n  return table.concat(buffer,'\\n')\nend\n\n-- The functions that follow render corresponding pandoc elements.\n-- s is always a string, attr is always a table of attributes, and\n-- items is always an array of strings (the items in a list).\n-- Comments indicate the types of other variables.\n\nfunction Str(s)\n  return escape(s)\nend\n\nfunction Space()\n  return \" \"\nend\n\nfunction LineBreak()\n  return \"<br/>\"\nend\n\nfunction Emph(s)\n  return \"<em>\" .. s .. \"</em>\"\nend\n\nfunction Strong(s)\n  return \"<strong>\" .. s .. \"</strong>\"\nend\n\nfunction Subscript(s)\n  return \"<sub>\" .. s .. \"</sub>\"\nend\n\nfunction Superscript(s)\n  return \"<sup>\" .. s .. \"</sup>\"\nend\n\nfunction SmallCaps(s)\n  return '<span style=\"font-variant: small-caps;\">' .. s .. '</span>'\nend\n\nfunction Strikeout(s)\n  return '<del>' .. s .. '</del>'\nend\n\nfunction Link(s, src, tit)\n  return \"<a href='\" .. escape(src,true) .. \"' title='\" ..\n         escape(tit,true) .. \"'>\" .. s .. \"</a>\"\nend\n\nfunction Image(s, src, tit)\n  return \"<img src='\" .. escape(src,true) .. \"' title='\" ..\n         escape(tit,true) .. \"'/>\"\nend\n\nfunction Code(s, attr)\n  return \"<code\" .. attributes(attr) .. \">\" .. escape(s) .. \"</code>\"\nend\n\nfunction InlineMath(s)\n  return \"\\\\(\" .. escape(s) .. \"\\\\)\"\nend\n\nfunction DisplayMath(s)\n  return \"\\\\[\" .. escape(s) .. \"\\\\]\"\nend\n\nfunction Note(s)\n  local num = #notes + 1\n  -- insert the back reference right before the final closing tag.\n  s = string.gsub(s,\n          '(.*)</', '%1 <a href=\"#fnref' .. num ..  '\">&#8617;</a></')\n  -- add a list item with the note to the note table.\n  table.insert(notes, '<li id=\"fn' .. num .. '\">' .. s .. '</li>')\n  -- return the footnote reference, linked to the note.\n  return '<a id=\"fnref' .. num .. '\" href=\"#fn' .. num ..\n            '\"><sup>' .. num .. '</sup></a>'\nend\n\nfunction Span(s, attr)\n  return \"<span\" .. attributes(attr) .. \">\" .. s .. \"</span>\"\nend\n\nfunction Cite(s, cs)\n  local ids = {}\n  for _,cit in ipairs(cs) do\n    table.insert(ids, cit.citationId)\n  end\n  return \"<span class=\\\"cite\\\" data-citation-ids=\\\"\" .. table.concat(ids, \",\") ..\n    \"\\\">\" .. s .. \"</span>\"\nend\n\nfunction Plain(s)\n  return s\nend\n\nfunction Para(s)\n  return \"<p>\" .. s .. \"</p>\"\nend\n\n-- lev is an integer, the header level.\nfunction Header(lev, s, attr)\n  return \"<h\" .. lev .. attributes(attr) ..  \">\" .. s .. \"</h\" .. lev .. \">\"\nend\n\nfunction BlockQuote(s)\n  return \"<blockquote>\\n\" .. s .. \"\\n</blockquote>\"\nend\n\nfunction HorizontalRule()\n  return \"<hr/>\"\nend\n\nfunction CodeBlock(s, attr)\n  -- If code block has class 'dot', pipe the contents through dot\n  -- and base64, and include the base64-encoded png as a data: URL.\n  if attr.class and string.match(' ' .. attr.class .. ' ',' dot ') then\n    local png = pipe(\"base64\", pipe(\"dot -Tpng\", s))\n    return '<img src=\"data:image/png;base64,' .. png .. '\"/>'\n  -- otherwise treat as code (one could pipe through a highlighter)\n  else\n    return \"<pre><code\" .. attributes(attr) .. \">\" .. escape(s) ..\n           \"</code></pre>\"\n  end\nend\n\nfunction BulletList(items)\n  local buffer = {}\n  for _, item in pairs(items) do\n    table.insert(buffer, \"<li>\" .. item .. \"</li>\")\n  end\n  return \"<ul>\\n\" .. table.concat(buffer, \"\\n\") .. \"\\n</ul>\"\nend\n\nfunction OrderedList(items)\n  local buffer = {}\n  for _, item in pairs(items) do\n    table.insert(buffer, \"<li>\" .. item .. \"</li>\")\n  end\n  return \"<ol>\\n\" .. table.concat(buffer, \"\\n\") .. \"\\n</ol>\"\nend\n\n-- Revisit association list STackValue instance.\nfunction DefinitionList(items)\n  local buffer = {}\n  for _,item in pairs(items) do\n    for k, v in pairs(item) do\n      table.insert(buffer,\"<dt>\" .. k .. \"</dt>\\n<dd>\" ..\n                        table.concat(v,\"</dd>\\n<dd>\") .. \"</dd>\")\n    end\n  end\n  return \"<dl>\\n\" .. table.concat(buffer, \"\\n\") .. \"\\n</dl>\"\nend\n\n-- Convert pandoc alignment to something HTML can use.\n-- align is AlignLeft, AlignRight, AlignCenter, or AlignDefault.\nfunction html_align(align)\n  if align == 'AlignLeft' then\n    return 'left'\n  elseif align == 'AlignRight' then\n    return 'right'\n  elseif align == 'AlignCenter' then\n    return 'center'\n  else\n    return 'left'\n  end\nend\n\n-- Caption is a string, aligns is an array of strings,\n-- widths is an array of floats, headers is an array of\n-- strings, rows is an array of arrays of strings.\nfunction Table(caption, aligns, widths, headers, rows)\n  local buffer = {}\n  local function add(s)\n    table.insert(buffer, s)\n  end\n  add(\"<table>\")\n  if caption ~= \"\" then\n    add(\"<caption>\" .. caption .. \"</caption>\")\n  end\n  if widths and widths[1] ~= 0 then\n    for _, w in pairs(widths) do\n      add('<col width=\"' .. string.format(\"%d%%\", w * 100) .. '\" />')\n    end\n  end\n  local header_row = {}\n  local empty_header = true\n  for i, h in pairs(headers) do\n    local align = html_align(aligns[i])\n    table.insert(header_row,'<th align=\"' .. align .. '\">' .. h .. '</th>')\n    empty_header = empty_header and h == \"\"\n  end\n  if empty_header then\n    head = \"\"\n  else\n    add('<tr class=\"header\">')\n    for _,h in pairs(header_row) do\n      add(h)\n    end\n    add('</tr>')\n  end\n  local class = \"even\"\n  for _, row in pairs(rows) do\n    class = (class == \"even\" and \"odd\") or \"even\"\n    add('<tr class=\"' .. class .. '\">')\n    for i,c in pairs(row) do\n      add('<td align=\"' .. html_align(aligns[i]) .. '\">' .. c .. '</td>')\n    end\n    add('</tr>')\n  end\n  add('</table')\n  return table.concat(buffer,'\\n')\nend\n\nfunction Div(s, attr)\n  return \"<div\" .. attributes(attr) .. \">\\n\" .. s .. \"</div>\"\nend\n\n-- The following code will produce runtime warnings when you haven't defined\n-- all of the functions you need for the custom writer, so it's useful\n-- to include when you're working on a writer.\nlocal meta = {}\nmeta.__index =\n  function(_, key)\n    io.stderr:write(string.format(\"WARNING: Undefined function '%s'\\n\",key))\n    return function() return \"\" end\n  end\nsetmetatable(_G, meta)\n\n"),("docx/[Content_Types].xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<Types xmlns=\"http://schemas.openxmlformats.org/package/2006/content-types\"><Default Extension=\"xml\" ContentType=\"application/xml\" /><Default Extension=\"rels\" ContentType=\"application/vnd.openxmlformats-package.relationships+xml\" /><Override PartName=\"/word/webSettings.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.webSettings+xml\" /><Override PartName=\"/word/numbering.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.numbering+xml\" /><Override PartName=\"/word/settings.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml\" /><Override PartName=\"/word/theme/theme1.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.theme+xml\" /><Override PartName=\"/word/fontTable.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.fontTable+xml\" /><Override PartName=\"/docProps/app.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.extended-properties+xml\" /><Override PartName=\"/docProps/core.xml\" ContentType=\"application/vnd.openxmlformats-package.core-properties+xml\" /><Override PartName=\"/word/styles.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.styles+xml\" /><Override PartName=\"/word/document.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml\" /><Override PartName=\"/word/footnotes.xml\" ContentType=\"application/vnd.openxmlformats-officedocument.wordprocessingml.footnotes+xml\" /></Types>\n"),("docx/_rels/.rels","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<Relationships xmlns=\"http://schemas.openxmlformats.org/package/2006/relationships\"><Relationship Id=\"rId1\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument\" Target=\"word/document.xml\" /><Relationship Id=\"rId4\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties\" Target=\"docProps/app.xml\" /><Relationship Id=\"rId3\" Type=\"http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties\" Target=\"docProps/core.xml\" /></Relationships>"),("docx/docProps/app.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<Properties xmlns=\"http://schemas.openxmlformats.org/officeDocument/2006/extended-properties\" xmlns:vt=\"http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes\">\n  <Words>83</Words>\n  <SharedDoc>false</SharedDoc>\n  <HyperlinksChanged>false</HyperlinksChanged>\n  <Lines>12</Lines>\n  <AppVersion>12.0000</AppVersion>\n  <LinksUpToDate>false</LinksUpToDate>\n  <Application>Microsoft Word 12.0.0</Application>\n  <CharactersWithSpaces>583</CharactersWithSpaces>\n  <Template>Normal.dotm</Template>\n  <DocSecurity>0</DocSecurity>\n  <TotalTime>6</TotalTime>\n  <ScaleCrop>false</ScaleCrop>\n  <Characters>475</Characters>\n  <Paragraphs>8</Paragraphs>\n  <Pages>1</Pages>\n</Properties>"),("docx/docProps/core.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<cp:coreProperties xmlns:cp=\"http://schemas.openxmlformats.org/package/2006/metadata/core-properties\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:dcmitype=\"http://purl.org/dc/dcmitype/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"><dc:title></dc:title><dc:creator></dc:creator></cp:coreProperties>"),("docx/word/document.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<w:document xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:m=\"http://schemas.openxmlformats.org/officeDocument/2006/math\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:o=\"urn:schemas-microsoft-com:office:office\" xmlns:v=\"urn:schemas-microsoft-com:vml\" xmlns:w10=\"urn:schemas-microsoft-com:office:word\" xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:pic=\"http://schemas.openxmlformats.org/drawingml/2006/picture\" xmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\"><w:body><w:p><w:r><w:t xml:space=\"preserve\">Hello world.</w:t></w:r></w:p></w:body></w:document>\n"),("docx/word/fontTable.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<w:fonts xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\">\n&#9;<w:font w:name=\"Symbol\">\n&#9;&#9;<w:panose1 w:val=\"02000500000000000000\" />\n&#9;&#9;<w:charset w:val=\"02\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000000\" w:usb1=\"00000000\" w:usb2=\"00010000\" w:usb3=\"00000000\" w:csb0=\"80000000\" w:csb1=\"00000000\" />\n&#9;</w:font>\n&#9;<w:font w:name=\"Times New Roman\">\n&#9;&#9;<w:panose1 w:val=\"02020603050405020304\" />\n&#9;&#9;<w:charset w:val=\"00\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000003\" w:usb1=\"00000000\" w:usb2=\"00000000\" w:usb3=\"00000000\" w:csb0=\"00000001\" w:csb1=\"00000000\" />\n&#9;</w:font>\n&#9;<w:font w:name=\"Courier New\">\n&#9;&#9;<w:panose1 w:val=\"02070309020205020404\" />\n&#9;&#9;<w:charset w:val=\"00\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000003\" w:usb1=\"00000000\" w:usb2=\"00000000\" w:usb3=\"00000000\" w:csb0=\"00000001\" w:csb1=\"00000000\" />\n&#9;</w:font>\n&#9;<w:font w:name=\"Wingdings\">\n&#9;&#9;<w:panose1 w:val=\"05020102010804080708\" />\n&#9;&#9;<w:charset w:val=\"02\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000000\" w:usb1=\"00000000\" w:usb2=\"00010000\" w:usb3=\"00000000\" w:csb0=\"80000000\" w:csb1=\"00000000\" />\n&#9;</w:font>\n&#9;<w:font w:name=\"Cambria\">\n&#9;&#9;<w:panose1 w:val=\"02040503050406030204\" />\n&#9;&#9;<w:charset w:val=\"00\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000003\" w:usb1=\"00000000\" w:usb2=\"00000000\" w:usb3=\"00000000\" w:csb0=\"00000001\" w:csb1=\"00000000\" />\n&#9;</w:font>\n&#9;<w:font w:name=\"Calibri\">\n&#9;&#9;<w:panose1 w:val=\"020F0502020204030204\" />\n&#9;&#9;<w:charset w:val=\"00\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000003\" w:usb1=\"00000000\" w:usb2=\"00000000\" w:usb3=\"00000000\" w:csb0=\"00000001\" w:csb1=\"00000000\" />\n&#9;</w:font>\n&#9;<w:font w:name=\"Arial\">\n&#9;&#9;<w:panose1 w:val=\"020B0604020202020204\" />\n&#9;&#9;<w:charset w:val=\"00\" />\n&#9;&#9;<w:family w:val=\"auto\" />\n&#9;&#9;<w:pitch w:val=\"variable\" />\n&#9;&#9;<w:sig w:usb0=\"00000003\" w:usb1=\"00000000\" w:usb2=\"00000000\" w:usb3=\"00000000\" w:csb0=\"00000001\" w:csb1=\"00000000\" />\n&#9;</w:font>\n</w:fonts>"),("docx/word/footnotes.xml","<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<w:footnotes xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\"\nxmlns:m=\"http://schemas.openxmlformats.org/officeDocument/2006/math\"\nxmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\"\nxmlns:o=\"urn:schemas-microsoft-com:office:office\"\nxmlns:v=\"urn:schemas-microsoft-com:vml\"\nxmlns:w10=\"urn:schemas-microsoft-com:office:word\"\nxmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\"\nxmlns:pic=\"http://schemas.openxmlformats.org/drawingml/2006/picture\"\nxmlns:wp=\"http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing\">\n\n  <w:footnote w:type=\"continuationSeparator\" w:id=\"0\">\n    <w:p>\n      <w:r>\n        <w:continuationSeparator />\n      </w:r>\n    </w:p>\n  </w:footnote>\n  <w:footnote w:type=\"separator\" w:id=\"-1\">\n    <w:p>\n      <w:r>\n        <w:separator />\n      </w:r>\n    </w:p>\n  </w:footnote>\n</w:footnotes>\n"),("docx/word/numbering.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<w:numbering xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\"><w:abstractNum w:abstractNumId=\"0\"><w:nsid w:val=\"e17f69ba\" /><w:multiLevelType w:val=\"multilevel\" /><w:lvl w:ilvl=\"0\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"0\" /></w:tabs><w:ind w:left=\"480\" w:hanging=\"480\" /></w:pPr></w:lvl><w:lvl w:ilvl=\"1\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"720\" /></w:tabs><w:ind w:left=\"1200\" w:hanging=\"480\" /></w:pPr></w:lvl><w:lvl w:ilvl=\"2\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"1440\" /></w:tabs><w:ind w:left=\"1920\" w:hanging=\"480\" /></w:pPr></w:lvl><w:lvl w:ilvl=\"3\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"2160\" /></w:tabs><w:ind w:left=\"2640\" w:hanging=\"480\" /></w:pPr></w:lvl><w:lvl w:ilvl=\"4\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"2880\" /></w:tabs><w:ind w:left=\"3360\" w:hanging=\"480\" /></w:pPr></w:lvl><w:lvl w:ilvl=\"5\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"3600\" /></w:tabs><w:ind w:left=\"4080\" w:hanging=\"480\" /></w:pPr></w:lvl><w:lvl w:ilvl=\"6\"><w:numFmt w:val=\"bullet\" /><w:lvlText w:val=\" \" /><w:lvlJc w:val=\"left\" /><w:pPr><w:tabs><w:tab w:val=\"num\" w:pos=\"4320\" /></w:tabs><w:ind w:left=\"4800\" w:hanging=\"480\" /></w:pPr></w:lvl></w:abstractNum><w:num w:numId=\"1\"><w:abstractNumId w:val=\"0\" /></w:num></w:numbering>"),("docx/word/settings.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<w:settings xmlns:o=\"urn:schemas-microsoft-com:office:office\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:m=\"http://schemas.openxmlformats.org/officeDocument/2006/math\" xmlns:v=\"urn:schemas-microsoft-com:vml\" xmlns:w10=\"urn:schemas-microsoft-com:office:word\" xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" xmlns:sl=\"http://schemas.openxmlformats.org/schemaLibrary/2006/main\">\n  <w:zoom w:percent=\"90\" />\n  <w:embedSystemFonts />\n  <w:proofState w:spelling=\"clean\" w:grammar=\"clean\" />\n  <w:stylePaneFormatFilter w:val=\"0004\" />\n  <w:footnotePr>\n    <w:footnote w:id=\"-1\" />\n    <w:footnote w:id=\"0\" />\n  </w:footnotePr>\n  <w:doNotTrackMoves />\n  <w:defaultTabStop w:val=\"720\" />\n  <w:drawingGridHorizontalSpacing w:val=\"360\" />\n  <w:drawingGridVerticalSpacing w:val=\"360\" />\n  <w:displayHorizontalDrawingGridEvery w:val=\"0\" />\n  <w:displayVerticalDrawingGridEvery w:val=\"0\" />\n  <w:characterSpacingControl w:val=\"doNotCompress\" />\n  <w:savePreviewPicture />\n  <w:rsids>\n    <w:rsidRoot w:val=\"00590D07\" />\n    <w:rsid w:val=\"00011C8B\" />\n    <w:rsid w:val=\"004E29B3\" />\n    <w:rsid w:val=\"00590D07\" />\n    <w:rsid w:val=\"00784D58\" />\n    <w:rsid w:val=\"008D6863\" />\n    <w:rsid w:val=\"00B86B75\" />\n    <w:rsid w:val=\"00BC48D5\" />\n    <w:rsid w:val=\"00C36279\" />\n    <w:rsid w:val=\"00E315A3\" />\n  </w:rsids>\n  <m:mathPr>\n    <m:mathFont m:val=\"Lucida Grande\" />\n    <m:brkBin m:val=\"before\" />\n    <m:brkBinSub m:val=\"--\" />\n    <m:smallFrac m:val=\"false\" />\n    <m:dispDef m:val=\"false\" />\n    <m:lMargin m:val=\"0\" />\n    <m:rMargin m:val=\"0\" />\n    <m:wrapRight />\n    <m:intLim m:val=\"subSup\" />\n    <m:naryLim m:val=\"subSup\" />\n  </m:mathPr>\n  <w:themeFontLang w:val=\"en-US\" />\n  <w:clrSchemeMapping w:bg1=\"light1\" w:t1=\"dark1\" w:bg2=\"light2\" w:t2=\"dark2\" w:accent1=\"accent1\" w:accent2=\"accent2\" w:accent3=\"accent3\" w:accent4=\"accent4\" w:accent5=\"accent5\" w:accent6=\"accent6\" w:hyperlink=\"hyperlink\" w:followedHyperlink=\"followedHyperlink\" />\n  <w:decimalSymbol w:val=\".\" />\n  <w:listSeparator w:val=\",\" />\n</w:settings>\n"),("docx/word/styles.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<w:styles xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\">\n  <w:docDefaults>\n    <w:rPrDefault>\n      <w:rPr>\n        <w:rFonts w:asciiTheme=\"minorHAnsi\" w:eastAsiaTheme=\"minorHAnsi\" w:hAnsiTheme=\"minorHAnsi\" w:cstheme=\"minorBidi\" />\n        <w:sz w:val=\"24\" />\n        <w:szCs w:val=\"24\" />\n        <w:lang w:val=\"en-US\" w:eastAsia=\"en-US\" w:bidi=\"ar-SA\" />\n      </w:rPr>\n    </w:rPrDefault>\n    <w:pPrDefault>\n      <w:pPr>\n        <w:spacing w:after=\"200\" />\n      </w:pPr>\n    </w:pPrDefault>\n  </w:docDefaults>\n  <w:latentStyles w:defLockedState=\"0\" w:defUIPriority=\"0\" w:defSemiHidden=\"0\" w:defUnhideWhenUsed=\"0\" w:defQFormat=\"0\" w:count=\"276\" />\n  <w:style w:type=\"paragraph\" w:default=\"1\" w:styleId=\"Normal\">\n    <w:name w:val=\"Normal\" />\n    <w:qFormat />\n  </w:style>\n    <w:style w:type=\"paragraph\" w:styleId=\"BodyText\">\n    <w:name w:val=\"Body Text\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:link w:val=\"BodyTextChar\" />\n    <w:pPr>\n      <w:spacing w:before=\"180\" w:after=\"180\" />\n    </w:pPr>\n    <w:qFormat />\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"FirstParagraph\">\n    <w:name w:val=\"First Paragraph\" />\n    <w:basedOn w:val=\"BodyText\" />\n    <w:next w:val=\"BodyText\" />\n    <w:qFormat />\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"Compact\">\n    <w:name w:val=\"Compact\" />\n    <w:basedOn w:val=\"BodyText\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:spacing w:before=\"36\" w:after=\"36\" />\n    </w:pPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Title\">\n    <w:name w:val=\"Title\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"480\" w:after=\"240\" />\n      <w:jc w:val=\"center\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:b />\n      <w:bCs />\n      <w:color w:val=\"345A8A\" w:themeColor=\"accent1\" w:themeShade=\"B5\" />\n      <w:sz w:val=\"36\" />\n      <w:szCs w:val=\"36\" />\n    </w:rPr>\n  </w:style>\n <w:style w:type=\"paragraph\" w:styleId=\"Subtitle\">\n    <w:name w:val=\"Subtitle\" />\n    <w:basedOn w:val=\"Title\" />\n    <w:next w:val=\"BodyText\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"240\" w:after=\"240\" />\n      <w:jc w:val=\"center\" />\n    </w:pPr>\n    <w:rPr>\n      <w:sz w:val=\"30\" />\n      <w:szCs w:val=\"30\" />\n    </w:rPr>\n </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"Author\">\n    <w:name w:val=\"Author\" />\n    <w:next w:val=\"BodyText\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:jc w:val=\"center\" />\n    </w:pPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Date\">\n    <w:name w:val=\"Date\" />\n    <w:next w:val=\"BodyText\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:jc w:val=\"center\" />\n    </w:pPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"Abstract\">\n    <w:name w:val=\"Abstract\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"300\" w:after=\"300\" />\n    </w:pPr>\n    <w:rPr>\n      <w:sz w:val=\"20\" />\n      <w:szCs w:val=\"20\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Bibliography\">\n    <w:name w:val=\"Bibliography\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"Bibliography\" />\n    <w:qFormat />\n    <w:pPr />\n    <w:rPr />\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Heading1\">\n    <w:name w:val=\"Heading 1\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"480\" w:after=\"0\" />\n      <w:outlineLvl w:val=\"0\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:b />\n      <w:bCs />\n      <w:color w:val=\"345A8A\" w:themeColor=\"accent1\" w:themeShade=\"B5\" />\n      <w:sz w:val=\"32\" />\n      <w:szCs w:val=\"32\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Heading2\">\n    <w:name w:val=\"Heading 2\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"200\" w:after=\"0\" />\n      <w:outlineLvl w:val=\"1\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:b />\n      <w:bCs />\n      <w:color w:val=\"4F81BD\" w:themeColor=\"accent1\" />\n      <w:sz w:val=\"32\" />\n      <w:szCs w:val=\"32\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Heading3\">\n    <w:name w:val=\"Heading 3\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"200\" w:after=\"0\" />\n      <w:outlineLvl w:val=\"1\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:b />\n      <w:bCs />\n      <w:color w:val=\"4F81BD\" w:themeColor=\"accent1\" />\n      <w:sz w:val=\"28\" />\n      <w:szCs w:val=\"28\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Heading4\">\n    <w:name w:val=\"Heading 4\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"200\" w:after=\"0\" />\n      <w:outlineLvl w:val=\"1\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:b />\n      <w:bCs />\n      <w:color w:val=\"4F81BD\" w:themeColor=\"accent1\" />\n      <w:sz w:val=\"24\" />\n      <w:szCs w:val=\"24\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Heading5\">\n    <w:name w:val=\"Heading 5\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:before=\"200\" w:after=\"0\" />\n      <w:outlineLvl w:val=\"1\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:i />\n      <w:iCs />\n      <w:color w:val=\"4F81BD\" w:themeColor=\"accent1\" />\n      <w:sz w:val=\"24\" />\n      <w:szCs w:val=\"24\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"BlockText\">\n    <w:name w:val=\"Block Text\" />\n    <w:basedOn w:val=\"BodyText\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:pPr>\n      <w:spacing w:before=\"100\" w:after=\"100\" />\n      <w:ind w:firstLine=\"0\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:bCs />\n      <w:sz w:val=\"20\" />\n      <w:szCs w:val=\"20\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"FootnoteText\">\n    <w:name w:val=\"Footnote Text\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"FootnoteText\" />\n    <w:uiPriority w:val=\"9\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n  </w:style>\n  <w:style w:type=\"character\" w:default=\"1\" w:styleId=\"DefaultParagraphFont\">\n    <w:name w:val=\"Default Paragraph Font\" />\n    <w:semiHidden />\n    <w:unhideWhenUsed />\n  </w:style>\n  <w:style w:type=\"table\" w:default=\"1\" w:styleId=\"TableNormal\">\n    <w:name w:val=\"Normal Table\" />\n    <w:semiHidden />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:tblPr>\n      <w:tblInd w:w=\"0\" w:type=\"dxa\" />\n      <w:tblCellMar>\n        <w:top w:w=\"0\" w:type=\"dxa\" />\n        <w:left w:w=\"108\" w:type=\"dxa\" />\n        <w:bottom w:w=\"0\" w:type=\"dxa\" />\n        <w:right w:w=\"108\" w:type=\"dxa\" />\n      </w:tblCellMar>\n    </w:tblPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"DefinitionTerm\">\n    <w:name w:val=\"Definition Term\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:next w:val=\"Definition\" />\n    <w:pPr>\n      <w:keepNext />\n      <w:keepLines />\n      <w:spacing w:after=\"0\" />\n    </w:pPr>\n    <w:rPr>\n      <w:b />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"Definition\">\n    <w:name w:val=\"Definition\" />\n    <w:basedOn w:val=\"Normal\" />\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"Caption\">\n    <w:name w:val=\"Caption\" />\n    <w:basedOn w:val=\"Normal\" />\n    <w:link w:val=\"BodyTextChar\" />\n    <w:pPr>\n      <w:spacing w:before=\"0\" w:after=\"120\" />\n    </w:pPr>\n    <w:rPr>\n      <w:i />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"TableCaption\">\n    <w:name w:val=\"Table Caption\" />\n    <w:basedOn w:val=\"Caption\" />\n    <w:pPr>\n      <w:keepNext />\n    </w:pPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"ImageCaption\">\n    <w:name w:val=\"Image Caption\" />\n    <w:basedOn w:val=\"Caption\" />\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"Figure\">\n    <w:name w:val=\"Figure\" />\n    <w:basedOn w:val=\"Normal\" />\n  </w:style>\n  <w:style w:type=\"paragraph\" w:customStyle=\"1\" w:styleId=\"FigureWithCaption\">\n    <w:name w:val=\"Figure with Caption\" />\n    <w:basedOn w:val=\"Figure\" />\n    <w:pPr>\n      <w:keepNext />\n    </w:pPr>\n  </w:style>\n  <w:style w:type=\"character\" w:customStyle=\"1\" w:styleId=\"BodyTextChar\">\n    <w:name w:val=\"Body Text Char\" />\n    <w:basedOn w:val=\"DefaultParagraphFont\" />\n    <w:link w:val=\"BodyText\" />\n  </w:style>\n  <w:style w:type=\"character\" w:customStyle=\"1\" w:styleId=\"VerbatimChar\">\n    <w:name w:val=\"Verbatim Char\" />\n    <w:basedOn w:val=\"BodyTextChar\" />\n    <w:rPr>\n      <w:rFonts w:ascii=\"Consolas\" w:hAnsi=\"Consolas\" />\n      <w:sz w:val=\"22\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"character\" w:styleId=\"FootnoteReference\">\n    <w:name w:val=\"Footnote Reference\" />\n    <w:basedOn w:val=\"BodyTextChar\" />\n    <w:rPr>\n      <w:vertAlign w:val=\"superscript\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"character\" w:styleId=\"Hyperlink\">\n    <w:name w:val=\"Hyperlink\" />\n    <w:basedOn w:val=\"BodyTextChar\" />\n    <w:rPr>\n      <w:color w:val=\"4F81BD\" w:themeColor=\"accent1\" />\n    </w:rPr>\n  </w:style>\n  <w:style w:type=\"paragraph\" w:styleId=\"TOCHeading\">\n    <w:name w:val=\"TOC Heading\" />\n    <w:basedOn w:val=\"Heading1\" />\n    <w:next w:val=\"BodyText\" />\n    <w:uiPriority w:val=\"39\" />\n    <w:unhideWhenUsed />\n    <w:qFormat />\n    <w:pPr>\n      <w:spacing w:before=\"240\" w:line=\"259\" w:lineRule=\"auto\" />\n      <w:outlineLvl w:val=\"9\" />\n    </w:pPr>\n    <w:rPr>\n      <w:rFonts w:asciiTheme=\"majorHAnsi\" w:eastAsiaTheme=\"majorEastAsia\" w:hAnsiTheme=\"majorHAnsi\" w:cstheme=\"majorBidi\" />\n      <w:b w:val=\"0\" />\n      <w:bCs w:val=\"0\" />\n      <w:color w:val=\"365F91\" w:themeColor=\"accent1\"\n      w:themeShade=\"BF\" />\n    </w:rPr>\n  </w:style>\n</w:styles>\n"),("docx/word/webSettings.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<ns0:webSettings xmlns:ns0=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\">\n  <ns0:allowPNG />\n  <ns0:doNotSaveAsSingleFile />\n</ns0:webSettings>"),("docx/word/_rels/document.xml.rels","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<Relationships xmlns=\"http://schemas.openxmlformats.org/package/2006/relationships\"><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/numbering\" Id=\"rId1\" Target=\"numbering.xml\" /><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles\" Id=\"rId2\" Target=\"styles.xml\" /><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/settings\" Id=\"rId3\" Target=\"settings.xml\" /><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/webSettings\" Id=\"rId4\" Target=\"webSettings.xml\" /><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/fontTable\" Id=\"rId5\" Target=\"fontTable.xml\" /><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme\" Id=\"rId6\" Target=\"theme/theme1.xml\" /><Relationship Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/footnotes\" Id=\"rId7\" Target=\"footnotes.xml\" /></Relationships>\n"),("docx/word/_rels/footnotes.xml.rels","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<Relationships xmlns=\"http://schemas.openxmlformats.org/package/2006/relationships\" />"),("docx/word/theme/theme1.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<a:theme xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" name=\"Office Theme\"><a:themeElements><a:clrScheme name=\"Office\"><a:dk1><a:sysClr val=\"windowText\" lastClr=\"000000\" /></a:dk1><a:lt1><a:sysClr val=\"window\" lastClr=\"FFFFFF\" /></a:lt1><a:dk2><a:srgbClr val=\"1F497D\" /></a:dk2><a:lt2><a:srgbClr val=\"EEECE1\" /></a:lt2><a:accent1><a:srgbClr val=\"4F81BD\" /></a:accent1><a:accent2><a:srgbClr val=\"C0504D\" /></a:accent2><a:accent3><a:srgbClr val=\"9BBB59\" /></a:accent3><a:accent4><a:srgbClr val=\"8064A2\" /></a:accent4><a:accent5><a:srgbClr val=\"4BACC6\" /></a:accent5><a:accent6><a:srgbClr val=\"F79646\" /></a:accent6><a:hlink><a:srgbClr val=\"0000FF\" /></a:hlink><a:folHlink><a:srgbClr val=\"800080\" /></a:folHlink></a:clrScheme><a:fontScheme name=\"Office\"><a:majorFont><a:latin typeface=\"Calibri\" /><a:ea typeface=\"\" /><a:cs typeface=\"\" /><a:font script=\"Jpan\" typeface=\"\239\188\173\239\188\179 \227\130\180\227\130\183\227\131\131\227\130\175\" /><a:font script=\"Hang\" typeface=\"\235\167\145\236\157\128 \234\179\160\235\148\149\" /><a:font script=\"Hans\" typeface=\"\229\174\139\228\189\147\" /><a:font script=\"Hant\" typeface=\"\230\150\176\231\180\176\230\152\142\233\171\148\" /><a:font script=\"Arab\" typeface=\"Times New Roman\" /><a:font script=\"Hebr\" typeface=\"Times New Roman\" /><a:font script=\"Thai\" typeface=\"Angsana New\" /><a:font script=\"Ethi\" typeface=\"Nyala\" /><a:font script=\"Beng\" typeface=\"Vrinda\" /><a:font script=\"Gujr\" typeface=\"Shruti\" /><a:font script=\"Khmr\" typeface=\"MoolBoran\" /><a:font script=\"Knda\" typeface=\"Tunga\" /><a:font script=\"Guru\" typeface=\"Raavi\" /><a:font script=\"Cans\" typeface=\"Euphemia\" /><a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" /><a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" /><a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" /><a:font script=\"Thaa\" typeface=\"MV Boli\" /><a:font script=\"Deva\" typeface=\"Mangal\" /><a:font script=\"Telu\" typeface=\"Gautami\" /><a:font script=\"Taml\" typeface=\"Latha\" /><a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" /><a:font script=\"Orya\" typeface=\"Kalinga\" /><a:font script=\"Mlym\" typeface=\"Kartika\" /><a:font script=\"Laoo\" typeface=\"DokChampa\" /><a:font script=\"Sinh\" typeface=\"Iskoola Pota\" /><a:font script=\"Mong\" typeface=\"Mongolian Baiti\" /><a:font script=\"Viet\" typeface=\"Times New Roman\" /><a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" /></a:majorFont><a:minorFont><a:latin typeface=\"Cambria\" /><a:ea typeface=\"\" /><a:cs typeface=\"\" /><a:font script=\"Jpan\" typeface=\"\239\188\173\239\188\179 \230\152\142\230\156\157\" /><a:font script=\"Hang\" typeface=\"\235\167\145\236\157\128 \234\179\160\235\148\149\" /><a:font script=\"Hans\" typeface=\"\229\174\139\228\189\147\" /><a:font script=\"Hant\" typeface=\"\230\150\176\231\180\176\230\152\142\233\171\148\" /><a:font script=\"Arab\" typeface=\"Arial\" /><a:font script=\"Hebr\" typeface=\"Arial\" /><a:font script=\"Thai\" typeface=\"Cordia New\" /><a:font script=\"Ethi\" typeface=\"Nyala\" /><a:font script=\"Beng\" typeface=\"Vrinda\" /><a:font script=\"Gujr\" typeface=\"Shruti\" /><a:font script=\"Khmr\" typeface=\"DaunPenh\" /><a:font script=\"Knda\" typeface=\"Tunga\" /><a:font script=\"Guru\" typeface=\"Raavi\" /><a:font script=\"Cans\" typeface=\"Euphemia\" /><a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" /><a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" /><a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" /><a:font script=\"Thaa\" typeface=\"MV Boli\" /><a:font script=\"Deva\" typeface=\"Mangal\" /><a:font script=\"Telu\" typeface=\"Gautami\" /><a:font script=\"Taml\" typeface=\"Latha\" /><a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" /><a:font script=\"Orya\" typeface=\"Kalinga\" /><a:font script=\"Mlym\" typeface=\"Kartika\" /><a:font script=\"Laoo\" typeface=\"DokChampa\" /><a:font script=\"Sinh\" typeface=\"Iskoola Pota\" /><a:font script=\"Mong\" typeface=\"Mongolian Baiti\" /><a:font script=\"Viet\" typeface=\"Arial\" /><a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" /></a:minorFont></a:fontScheme><a:fmtScheme name=\"Office\"><a:fillStyleLst><a:solidFill><a:schemeClr val=\"phClr\" /></a:solidFill><a:gradFill rotWithShape=\"1\"><a:gsLst><a:gs pos=\"0\"><a:schemeClr val=\"phClr\"><a:tint val=\"50000\" /><a:satMod val=\"300000\" /></a:schemeClr></a:gs><a:gs pos=\"35000\"><a:schemeClr val=\"phClr\"><a:tint val=\"37000\" /><a:satMod val=\"300000\" /></a:schemeClr></a:gs><a:gs pos=\"100000\"><a:schemeClr val=\"phClr\"><a:tint val=\"15000\" /><a:satMod val=\"350000\" /></a:schemeClr></a:gs></a:gsLst><a:lin ang=\"16200000\" scaled=\"1\" /></a:gradFill><a:gradFill rotWithShape=\"1\"><a:gsLst><a:gs pos=\"0\"><a:schemeClr val=\"phClr\"><a:tint val=\"100000\" /><a:shade val=\"100000\" /><a:satMod val=\"130000\" /></a:schemeClr></a:gs><a:gs pos=\"100000\"><a:schemeClr val=\"phClr\"><a:tint val=\"50000\" /><a:shade val=\"100000\" /><a:satMod val=\"350000\" /></a:schemeClr></a:gs></a:gsLst><a:lin ang=\"16200000\" scaled=\"0\" /></a:gradFill></a:fillStyleLst><a:lnStyleLst><a:ln w=\"9525\" cap=\"flat\" cmpd=\"sng\" algn=\"ctr\"><a:solidFill><a:schemeClr val=\"phClr\"><a:shade val=\"95000\" /><a:satMod val=\"105000\" /></a:schemeClr></a:solidFill><a:prstDash val=\"solid\" /></a:ln><a:ln w=\"25400\" cap=\"flat\" cmpd=\"sng\" algn=\"ctr\"><a:solidFill><a:schemeClr val=\"phClr\" /></a:solidFill><a:prstDash val=\"solid\" /></a:ln><a:ln w=\"38100\" cap=\"flat\" cmpd=\"sng\" algn=\"ctr\"><a:solidFill><a:schemeClr val=\"phClr\" /></a:solidFill><a:prstDash val=\"solid\" /></a:ln></a:lnStyleLst><a:effectStyleLst><a:effectStyle><a:effectLst><a:outerShdw blurRad=\"40000\" dist=\"20000\" dir=\"5400000\" rotWithShape=\"0\"><a:srgbClr val=\"000000\"><a:alpha val=\"38000\" /></a:srgbClr></a:outerShdw></a:effectLst></a:effectStyle><a:effectStyle><a:effectLst><a:outerShdw blurRad=\"40000\" dist=\"23000\" dir=\"5400000\" rotWithShape=\"0\"><a:srgbClr val=\"000000\"><a:alpha val=\"35000\" /></a:srgbClr></a:outerShdw></a:effectLst></a:effectStyle><a:effectStyle><a:effectLst><a:outerShdw blurRad=\"40000\" dist=\"23000\" dir=\"5400000\" rotWithShape=\"0\"><a:srgbClr val=\"000000\"><a:alpha val=\"35000\" /></a:srgbClr></a:outerShdw></a:effectLst><a:scene3d><a:camera prst=\"orthographicFront\"><a:rot lat=\"0\" lon=\"0\" rev=\"0\" /></a:camera><a:lightRig rig=\"threePt\" dir=\"t\"><a:rot lat=\"0\" lon=\"0\" rev=\"1200000\" /></a:lightRig></a:scene3d><a:sp3d><a:bevelT w=\"63500\" h=\"25400\" /></a:sp3d></a:effectStyle></a:effectStyleLst><a:bgFillStyleLst><a:solidFill><a:schemeClr val=\"phClr\" /></a:solidFill><a:gradFill rotWithShape=\"1\"><a:gsLst><a:gs pos=\"0\"><a:schemeClr val=\"phClr\"><a:tint val=\"40000\" /><a:satMod val=\"350000\" /></a:schemeClr></a:gs><a:gs pos=\"40000\"><a:schemeClr val=\"phClr\"><a:tint val=\"45000\" /><a:shade val=\"99000\" /><a:satMod val=\"350000\" /></a:schemeClr></a:gs><a:gs pos=\"100000\"><a:schemeClr val=\"phClr\"><a:shade val=\"20000\" /><a:satMod val=\"255000\" /></a:schemeClr></a:gs></a:gsLst><a:path path=\"circle\"><a:fillToRect l=\"50000\" t=\"-80000\" r=\"50000\" b=\"180000\" /></a:path></a:gradFill><a:gradFill rotWithShape=\"1\"><a:gsLst><a:gs pos=\"0\"><a:schemeClr val=\"phClr\"><a:tint val=\"80000\" /><a:satMod val=\"300000\" /></a:schemeClr></a:gs><a:gs pos=\"100000\"><a:schemeClr val=\"phClr\"><a:shade val=\"30000\" /><a:satMod val=\"200000\" /></a:schemeClr></a:gs></a:gsLst><a:path path=\"circle\"><a:fillToRect l=\"50000\" t=\"50000\" r=\"50000\" b=\"50000\" /></a:path></a:gradFill></a:bgFillStyleLst></a:fmtScheme></a:themeElements><a:objectDefaults><a:spDef><a:spPr /><a:bodyPr /><a:lstStyle /><a:style><a:lnRef idx=\"1\"><a:schemeClr val=\"accent1\" /></a:lnRef><a:fillRef idx=\"3\"><a:schemeClr val=\"accent1\" /></a:fillRef><a:effectRef idx=\"2\"><a:schemeClr val=\"accent1\" /></a:effectRef><a:fontRef idx=\"minor\"><a:schemeClr val=\"lt1\" /></a:fontRef></a:style></a:spDef><a:lnDef><a:spPr /><a:bodyPr /><a:lstStyle /><a:style><a:lnRef idx=\"2\"><a:schemeClr val=\"accent1\" /></a:lnRef><a:fillRef idx=\"0\"><a:schemeClr val=\"accent1\" /></a:fillRef><a:effectRef idx=\"1\"><a:schemeClr val=\"accent1\" /></a:effectRef><a:fontRef idx=\"minor\"><a:schemeClr val=\"tx1\" /></a:fontRef></a:style></a:lnDef></a:objectDefaults><a:extraClrSchemeLst /></a:theme>"),("dzslides/template.html","<!DOCTYPE html>\n\n<meta charset=\"utf-8\">\n<title>The Title Of Your Presentation</title>\n\n<!-- Your Slides -->\n<!-- One section is one slide -->\n\n<section>\n    <!-- This is the first slide -->\n    <h1>My Presentation</h1>\n    <footer>by John Doe</footer>\n</section>\n\n<section>\n    <p>Some random text: But I've never been to the moon! You can see how I lived before I met you. Also Zoidberg.\n    I could if you hadn't turned on the light and shut off my stereo.</p>\n</section>\n\n<section>\n    <h3>An incremental list</h3>\n    <ul class=\"incremental\">\n      <li>Item 1\n      <li>Item 2\n      <li>Item 3\n    </ul>\n    <details>Some notes. They are only visible using onstage shell.</details>\n</section>\n\n<section>\n  <q>\n    Who's brave enough to fly into something we all keep calling a death sphere?\n  </q>\n</section>\n\n<section>\n    <h2>Part two</h2>\n</section>\n\n<section>\n    <figure> <!-- Figures are used to display images and videos fullpage -->\n      <img src=\"http://placekitten.com/g/800/600\">\n      <figcaption>An image</figcaption>\n    </figure>\n    <details>Kittens are so cute!</details>\n</section>\n\n<section>\n    <figure> <!-- Videos are automatically played -->\n      <video src=\"http://videos-cdn.mozilla.net/brand/Mozilla_Firefox_Manifesto_v0.2_640.webm\" poster=\"http://www.mozilla.org/images/about/poster.jpg\"></video>\n      <figcaption>A video</figcaption>\n    </figure>\n</section>\n\n<section>\n    <h2>End!</h2>\n</section>\n\n<!-- Your Style -->\n<!-- Define the style of your presentation -->\n\n<!-- Maybe a font from http://www.google.com/webfonts ? -->\n<link href='http://fonts.googleapis.com/css?family=Oswald' rel='stylesheet'>\n\n<style>\n  html { background-color: black; }\n  body { background-color: white; border-radius: 12px}\n  /* A section is a slide. It's size is 800x600, and this will never change */\n  section {\n      /* The font from Google */\n      font-family: 'Oswald', arial, serif;\n      font-size: 30px;\n  }\n  h1, h2 {\n    margin-top: 200px;\n    text-align: center;\n    font-size: 80px;\n  }\n  h3 {\n    margin: 100px 0 50px 100px;\n  }\n\n  ul {\n      margin: 50px 200px;\n  }\n\n  p {\n    margin: 75px;\n    font-size: 50px;\n  }\n\n  q {\n    display: block;\n    width: 100%;\n    height: 100%;\n    background-color: black;\n    color: white;\n    font-size: 60px;\n    padding: 50px;\n  }\n\n  /* Figures are displayed full-page, with the caption\n     on top of the image/video */\n  figure {\n    background-color: black;\n  }\n  figcaption {\n    margin: 70px;\n    font-size: 50px;\n  }\n\n  footer {\n    position: absolute;\n    bottom: 0;\n    width: 100%;\n    padding: 40px;\n    text-align: right;\n    background-color: #F3F4F8;\n    border-top: 1px solid #CCC;\n  }\n\n  /* Transition effect */\n  /* Feel free to change the transition effect for original\n     animations. See here:\n     https://developer.mozilla.org/en/CSS/CSS_transitions\n     How to use CSS3 Transitions: */\n  section {\n      -moz-transition: left 400ms linear 0s;\n      -webkit-transition: left 400ms linear 0s;\n      -ms-transition: left 400ms linear 0s;\n      transition: left 400ms linear 0s;\n  }\n\n  /* Before */\n  section { left: -150%; }\n  /* Now */\n  section[aria-selected] { left: 0; }\n  /* After */\n  section[aria-selected] ~ section { left: +150%; }\n\n  /* Incremental elements */\n\n  /* By default, visible */\n  .incremental > * { opacity: 1; }\n\n  /* The current item */\n  .incremental > *[aria-selected] { opacity: 1; }\n\n  /* The items to-be-selected */\n  .incremental > *[aria-selected] ~ * { opacity: 0; }\n\n  /* The progressbar, at the bottom of the slides, show the global\n     progress of the presentation. */\n  #progress-bar {\n    height: 2px;\n    background: #AAA;\n  }\n</style>\n\n<!-- {{{{ dzslides core\n#\n#\n#     __  __  __       .  __   ___  __\n#    |  \\  / /__` |    | |  \\ |__  /__`\n#    |__/ /_ .__/ |___ | |__/ |___ .__/ core :\226\130\172\n#\n#\n# The following block of code is not supposed to be edited.\n# But if you want to change the behavior of these slides,\n# feel free to hack it!\n#\n-->\n\n<div id=\"progress-bar\"></div>\n\n<!-- Default Style -->\n<style>\n  * { margin: 0; padding: 0; -moz-box-sizing: border-box; -webkit-box-sizing: border-box; box-sizing: border-box; }\n  details { display: none; }\n  body {\n    width: 800px; height: 600px;\n    margin-left: -400px; margin-top: -300px;\n    position: absolute; top: 50%; left: 50%;\n    overflow: hidden;\n  }\n  section {\n    position: absolute;\n    pointer-events: none;\n    width: 100%; height: 100%;\n  }\n  section[aria-selected] { pointer-events: auto; }\n  html { overflow: hidden; }\n  body { display: none; }\n  body.loaded { display: block; }\n  .incremental {visibility: hidden; }\n  .incremental[active] {visibility: visible; }\n  #progress-bar{\n    bottom: 0;\n    position: absolute;\n    -moz-transition: width 400ms linear 0s;\n    -webkit-transition: width 400ms linear 0s;\n    -ms-transition: width 400ms linear 0s;\n    transition: width 400ms linear 0s;\n  }\n  figure {\n    width: 100%;\n    height: 100%;\n  }\n  figure > * {\n    position: absolute;\n  }\n  figure > img, figure > video {\n    width: 100%; height: 100%;\n  }\n</style>\n\n<script>\n  var Dz = {\n    remoteWindows: [],\n    idx: -1,\n    step: 0,\n    slides: null,\n    progressBar : null,\n    params: {\n      autoplay: \"1\"\n    }\n  };\n\n  Dz.init = function() {\n    document.body.className = \"loaded\";\n    this.slides = $$(\"body > section\");\n    this.progressBar = $(\"#progress-bar\");\n    this.setupParams();\n    this.onhashchange();\n    this.setupTouchEvents();\n    this.onresize();\n  }\n  \n  Dz.setupParams = function() {\n    var p = window.location.search.substr(1).split('&');\n    p.forEach(function(e, i, a) {\n      var keyVal = e.split('=');\n      Dz.params[keyVal[0]] = decodeURIComponent(keyVal[1]);\n    });\n  // Specific params handling\n    if (!+this.params.autoplay)\n      $$.forEach($$(\"video\"), function(v){ v.controls = true });\n  }\n\n  Dz.onkeydown = function(aEvent) {\n    // Don't intercept keyboard shortcuts\n    if (aEvent.altKey\n      || aEvent.ctrlKey\n      || aEvent.metaKey\n      || aEvent.shiftKey) {\n      return;\n    }\n    if ( aEvent.keyCode == 37 // left arrow\n      || aEvent.keyCode == 38 // up arrow\n      || aEvent.keyCode == 33 // page up\n    ) {\n      aEvent.preventDefault();\n      this.back();\n    }\n    if ( aEvent.keyCode == 39 // right arrow\n      || aEvent.keyCode == 40 // down arrow\n      || aEvent.keyCode == 34 // page down\n    ) {\n      aEvent.preventDefault();\n      this.forward();\n    }\n    if (aEvent.keyCode == 35) { // end\n      aEvent.preventDefault();\n      this.goEnd();\n    }\n    if (aEvent.keyCode == 36) { // home\n      aEvent.preventDefault();\n      this.goStart();\n    }\n    if (aEvent.keyCode == 32) { // space\n      aEvent.preventDefault();\n      this.toggleContent();\n    }\n    if (aEvent.keyCode == 70) { // f\n      aEvent.preventDefault();\n      this.goFullscreen();\n    }\n  }\n\n  /* Touch Events */\n\n  Dz.setupTouchEvents = function() {\n    var orgX, newX;\n    var tracking = false;\n\n    var db = document.body;\n    db.addEventListener(\"touchstart\", start.bind(this), false);\n    db.addEventListener(\"touchmove\", move.bind(this), false);\n\n    function start(aEvent) {\n      aEvent.preventDefault();\n      tracking = true;\n      orgX = aEvent.changedTouches[0].pageX;\n    }\n\n    function move(aEvent) {\n      if (!tracking) return;\n      newX = aEvent.changedTouches[0].pageX;\n      if (orgX - newX > 100) {\n        tracking = false;\n        this.forward();\n      } else {\n        if (orgX - newX < -100) {\n          tracking = false;\n          this.back();\n        }\n      }\n    }\n  }\n\n  /* Adapt the size of the slides to the window */\n\n  Dz.onresize = function() {\n    var db = document.body;\n    var sx = db.clientWidth / window.innerWidth;\n    var sy = db.clientHeight / window.innerHeight;\n    var transform = \"scale(\" + (1/Math.max(sx, sy)) + \")\";\n\n    db.style.MozTransform = transform;\n    db.style.WebkitTransform = transform;\n    db.style.OTransform = transform;\n    db.style.msTransform = transform;\n    db.style.transform = transform;\n  }\n\n\n  Dz.getDetails = function(aIdx) {\n    var s = $(\"section:nth-of-type(\" + aIdx + \")\");\n    var d = s.$(\"details\");\n    return d ? d.innerHTML : \"\";\n  }\n\n  Dz.onmessage = function(aEvent) {\n    var argv = aEvent.data.split(\" \"), argc = argv.length;\n    argv.forEach(function(e, i, a) { a[i] = decodeURIComponent(e) });\n    var win = aEvent.source;\n    if (argv[0] === \"REGISTER\" && argc === 1) {\n      this.remoteWindows.push(win);\n      this.postMsg(win, \"REGISTERED\", document.title, this.slides.length);\n      this.postMsg(win, \"CURSOR\", this.idx + \".\" + this.step);\n      return;\n    }\n    if (argv[0] === \"BACK\" && argc === 1)\n      this.back();\n    if (argv[0] === \"FORWARD\" && argc === 1)\n      this.forward();\n    if (argv[0] === \"START\" && argc === 1)\n      this.goStart();\n    if (argv[0] === \"END\" && argc === 1)\n      this.goEnd();\n    if (argv[0] === \"TOGGLE_CONTENT\" && argc === 1)\n      this.toggleContent();\n    if (argv[0] === \"SET_CURSOR\" && argc === 2)\n      window.location.hash = \"#\" + argv[1];\n    if (argv[0] === \"GET_CURSOR\" && argc === 1)\n      this.postMsg(win, \"CURSOR\", this.idx + \".\" + this.step);\n    if (argv[0] === \"GET_NOTES\" && argc === 1)\n      this.postMsg(win, \"NOTES\", this.getDetails(this.idx));\n  }\n\n  Dz.toggleContent = function() {\n    // If a Video is present in this new slide, play it.\n    // If a Video is present in the previous slide, stop it.\n    var s = $(\"section[aria-selected]\");\n    if (s) {\n      var video = s.$(\"video\");\n      if (video) {\n        if (video.ended || video.paused) {\n          video.play();\n        } else {\n          video.pause();\n        }\n      }\n    }\n  }\n\n  Dz.setCursor = function(aIdx, aStep) {\n    // If the user change the slide number in the URL bar, jump\n    // to this slide.\n    aStep = (aStep != 0 && typeof aStep !== \"undefined\") ? \".\" + aStep : \".0\";\n    window.location.hash = \"#\" + aIdx + aStep;\n  }\n\n  Dz.onhashchange = function() {\n    var cursor = window.location.hash.split(\"#\"),\n        newidx = 1,\n        newstep = 0;\n    if (cursor.length == 2) {\n      newidx = ~~cursor[1].split(\".\")[0];\n      newstep = ~~cursor[1].split(\".\")[1];\n      if (newstep > Dz.slides[newidx - 1].$$('.incremental > *').length) {\n        newstep = 0;\n        newidx++;\n      }\n    }\n    this.setProgress(newidx, newstep);\n    if (newidx != this.idx) {\n      this.setSlide(newidx);\n    }\n    if (newstep != this.step) {\n      this.setIncremental(newstep);\n    }\n    for (var i = 0; i < this.remoteWindows.length; i++) {\n      this.postMsg(this.remoteWindows[i], \"CURSOR\", this.idx + \".\" + this.step);\n    }\n  }\n\n  Dz.back = function() {\n    if (this.idx == 1 && this.step == 0) {\n      return;\n    }\n    if (this.step == 0) {\n      this.setCursor(this.idx - 1,\n                     this.slides[this.idx - 2].$$('.incremental > *').length);\n    } else {\n      this.setCursor(this.idx, this.step - 1);\n    }\n  }\n\n  Dz.forward = function() {\n    if (this.idx >= this.slides.length &&\n        this.step >= this.slides[this.idx - 1].$$('.incremental > *').length) {\n        return;\n    }\n    if (this.step >= this.slides[this.idx - 1].$$('.incremental > *').length) {\n      this.setCursor(this.idx + 1, 0);\n    } else {\n      this.setCursor(this.idx, this.step + 1);\n    }\n  }\n\n  Dz.goStart = function() {\n    this.setCursor(1, 0);\n  }\n\n  Dz.goEnd = function() {\n    var lastIdx = this.slides.length;\n    var lastStep = this.slides[lastIdx - 1].$$('.incremental > *').length;\n    this.setCursor(lastIdx, lastStep);\n  }\n\n  Dz.setSlide = function(aIdx) {\n    this.idx = aIdx;\n    var old = $(\"section[aria-selected]\");\n    var next = $(\"section:nth-of-type(\"+ this.idx +\")\");\n    if (old) {\n      old.removeAttribute(\"aria-selected\");\n      var video = old.$(\"video\");\n      if (video) {\n        video.pause();\n      }\n    }\n    if (next) {\n      next.setAttribute(\"aria-selected\", \"true\");\n      var video = next.$(\"video\");\n      if (video && !!+this.params.autoplay) {\n        video.play();\n      }\n    } else {\n      // That should not happen\n      this.idx = -1;\n      // console.warn(\"Slide doesn't exist.\");\n    }\n  }\n\n  Dz.setIncremental = function(aStep) {\n    this.step = aStep;\n    var old = this.slides[this.idx - 1].$('.incremental > *[aria-selected]');\n    if (old) {\n      old.removeAttribute('aria-selected');\n    }\n    var incrementals = $$('.incremental');\n    if (this.step <= 0) {\n      $$.forEach(incrementals, function(aNode) {\n        aNode.removeAttribute('active');\n      });\n      return;\n    }\n    var next = this.slides[this.idx - 1].$$('.incremental > *')[this.step - 1];\n    if (next) {\n      next.setAttribute('aria-selected', true);\n      next.parentNode.setAttribute('active', true);\n      var found = false;\n      $$.forEach(incrementals, function(aNode) {\n        if (aNode != next.parentNode)\n          if (found)\n            aNode.removeAttribute('active');\n          else\n            aNode.setAttribute('active', true);\n        else\n          found = true;\n      });\n    } else {\n      setCursor(this.idx, 0);\n    }\n    return next;\n  }\n\n  Dz.goFullscreen = function() {\n    var html = $('html'),\n        requestFullscreen = html.requestFullscreen || html.requestFullScreen || html.mozRequestFullScreen || html.webkitRequestFullScreen;\n    if (requestFullscreen) {\n      requestFullscreen.apply(html);\n    }\n  }\n  \n  Dz.setProgress = function(aIdx, aStep) {\n    var slide = $(\"section:nth-of-type(\"+ aIdx +\")\");\n    if (!slide)\n      return;\n    var steps = slide.$$('.incremental > *').length + 1,\n        slideSize = 100 / (this.slides.length - 1),\n        stepSize = slideSize / steps;\n    this.progressBar.style.width = ((aIdx - 1) * slideSize + aStep * stepSize) + '%';\n  }\n  \n  Dz.postMsg = function(aWin, aMsg) { // [arg0, [arg1...]]\n    aMsg = [aMsg];\n    for (var i = 2; i < arguments.length; i++)\n      aMsg.push(encodeURIComponent(arguments[i]));\n    aWin.postMessage(aMsg.join(\" \"), \"*\");\n  }\n  \n  function init() {\n    Dz.init();\n    window.onkeydown = Dz.onkeydown.bind(Dz);\n    window.onresize = Dz.onresize.bind(Dz);\n    window.onhashchange = Dz.onhashchange.bind(Dz);\n    window.onmessage = Dz.onmessage.bind(Dz);\n  }\n\n  window.onload = init;\n</script>\n\n\n<script> // Helpers\n  if (!Function.prototype.bind) {\n    Function.prototype.bind = function (oThis) {\n\n      // closest thing possible to the ECMAScript 5 internal IsCallable\n      // function \n      if (typeof this !== \"function\")\n      throw new TypeError(\n        \"Function.prototype.bind - what is trying to be fBound is not callable\"\n      );\n\n      var aArgs = Array.prototype.slice.call(arguments, 1),\n          fToBind = this,\n          fNOP = function () {},\n          fBound = function () {\n            return fToBind.apply( this instanceof fNOP ? this : oThis || window,\n                   aArgs.concat(Array.prototype.slice.call(arguments)));\n          };\n\n      fNOP.prototype = this.prototype;\n      fBound.prototype = new fNOP();\n\n      return fBound;\n    };\n  }\n\n  var $ = (HTMLElement.prototype.$ = function(aQuery) {\n    return this.querySelector(aQuery);\n  }).bind(document);\n\n  var $$ = (HTMLElement.prototype.$$ = function(aQuery) {\n    return this.querySelectorAll(aQuery);\n  }).bind(document);\n\n  $$.forEach = function(nodeList, fun) {\n    Array.prototype.forEach.call(nodeList, fun);\n  }\n\n</script>\n<!-- vim: set fdm=marker: }}} -->\n"),("odt/content.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<office:document-content xmlns:office=\"urn:oasis:names:tc:opendocument:xmlns:office:1.0\" xmlns:style=\"urn:oasis:names:tc:opendocument:xmlns:style:1.0\" xmlns:text=\"urn:oasis:names:tc:opendocument:xmlns:text:1.0\" xmlns:table=\"urn:oasis:names:tc:opendocument:xmlns:table:1.0\" xmlns:draw=\"urn:oasis:names:tc:opendocument:xmlns:drawing:1.0\" xmlns:fo=\"urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:meta=\"urn:oasis:names:tc:opendocument:xmlns:meta:1.0\" xmlns:number=\"urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0\" xmlns:svg=\"urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0\" xmlns:chart=\"urn:oasis:names:tc:opendocument:xmlns:chart:1.0\" xmlns:dr3d=\"urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0\" xmlns:math=\"http://www.w3.org/1998/Math/MathML\" xmlns:form=\"urn:oasis:names:tc:opendocument:xmlns:form:1.0\" xmlns:script=\"urn:oasis:names:tc:opendocument:xmlns:script:1.0\" xmlns:ooo=\"http://openoffice.org/2004/office\" xmlns:ooow=\"http://openoffice.org/2004/writer\" xmlns:oooc=\"http://openoffice.org/2004/calc\" xmlns:dom=\"http://www.w3.org/2001/xml-events\" xmlns:xforms=\"http://www.w3.org/2002/xforms\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:rpt=\"http://openoffice.org/2005/report\" xmlns:of=\"urn:oasis:names:tc:opendocument:xmlns:of:1.2\" xmlns:xhtml=\"http://www.w3.org/1999/xhtml\" xmlns:grddl=\"http://www.w3.org/2003/g/data-view#\" xmlns:officeooo=\"http://openoffice.org/2009/office\" xmlns:tableooo=\"http://openoffice.org/2009/table\" xmlns:drawooo=\"http://openoffice.org/2010/draw\" xmlns:calcext=\"urn:org:documentfoundation:names:experimental:calc:xmlns:calcext:1.0\" xmlns:field=\"urn:openoffice:names:experimental:ooo-ms-interop:xmlns:field:1.0\" xmlns:formx=\"urn:openoffice:names:experimental:ooxml-odf-interop:xmlns:form:1.0\" xmlns:css3t=\"http://www.w3.org/TR/css3-text/\" office:version=\"1.2\"><office:scripts/><office:font-face-decls><style:font-face style:name=\"StarSymbol\" svg:font-family=\"StarSymbol\"/><style:font-face style:name=\"Tahoma1\" svg:font-family=\"Tahoma\"/><style:font-face style:name=\"Courier New\" svg:font-family=\"&apos;Courier New&apos;\" style:font-family-generic=\"modern\" style:font-pitch=\"fixed\"/><style:font-face style:name=\"Times New Roman\" svg:font-family=\"&apos;Times New Roman&apos;\" style:font-family-generic=\"roman\" style:font-pitch=\"variable\"/><style:font-face style:name=\"Arial\" svg:font-family=\"Arial\" style:font-family-generic=\"swiss\" style:font-pitch=\"variable\"/><style:font-face style:name=\"Lucida Sans Unicode\" svg:font-family=\"&apos;Lucida Sans Unicode&apos;\" style:font-family-generic=\"system\" style:font-pitch=\"variable\"/><style:font-face style:name=\"Tahoma\" svg:font-family=\"Tahoma\" style:font-family-generic=\"system\" style:font-pitch=\"variable\"/></office:font-face-decls><office:automatic-styles><style:style style:name=\"P1\" style:family=\"paragraph\" style:parent-style-name=\"Footer\"><style:paragraph-properties fo:text-align=\"center\" style:justify-single-word=\"false\"/></style:style></office:automatic-styles><office:body><office:text><text:sequence-decls><text:sequence-decl text:display-outline-level=\"0\" text:name=\"Illustration\"/><text:sequence-decl text:display-outline-level=\"0\" text:name=\"Table\"/><text:sequence-decl text:display-outline-level=\"0\" text:name=\"Text\"/><text:sequence-decl text:display-outline-level=\"0\" text:name=\"Drawing\"/></text:sequence-decls><text:p text:style-name=\"Standard\">Hello World!</text:p></office:text></office:body></office:document-content>"),("odt/manifest.rdf","<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n  <rdf:Description rdf:about=\"styles.xml\">\n    <rdf:type rdf:resource=\"http://docs.oasis-open.org/ns/office/1.2/meta/odf#StylesFile\"/>\n  </rdf:Description>\n  <rdf:Description rdf:about=\"\">\n    <ns0:hasPart xmlns:ns0=\"http://docs.oasis-open.org/ns/office/1.2/meta/pkg#\" rdf:resource=\"styles.xml\"/>\n  </rdf:Description>\n  <rdf:Description rdf:about=\"content.xml\">\n    <rdf:type rdf:resource=\"http://docs.oasis-open.org/ns/office/1.2/meta/odf#ContentFile\"/>\n  </rdf:Description>\n  <rdf:Description rdf:about=\"\">\n    <ns0:hasPart xmlns:ns0=\"http://docs.oasis-open.org/ns/office/1.2/meta/pkg#\" rdf:resource=\"content.xml\"/>\n  </rdf:Description>\n  <rdf:Description rdf:about=\"\">\n    <rdf:type rdf:resource=\"http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Document\"/>\n  </rdf:Description>\n</rdf:RDF>\n"),("odt/meta.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<office:document-meta\n    xmlns:office=\"urn:oasis:names:tc:opendocument:xmlns:office:1.0\"\n    xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n    xmlns:dc=\"http://purl.org/dc/elements/1.1/\"\n    xmlns:meta=\"urn:oasis:names:tc:opendocument:xmlns:meta:1.0\"\n    xmlns:ooo=\"http://openoffice.org/2004/office\"\n    xmlns:grddl=\"http://www.w3.org/2003/g/data-view#\"\n    office:version=\"1.2\">\n  <office:meta>\n    <meta:document-statistic\n      meta:table-count=\"0\" meta:image-count=\"0\" meta:object-count=\"0\"\n      meta:page-count=\"1\" meta:paragraph-count=\"2\" meta:word-count=\"3\"\n      meta:character-count=\"14\"\n      meta:non-whitespace-character-count=\"12\"/>\n    <meta:generator>Pandoc</meta:generator>\n  </office:meta>\n</office:document-meta>\n"),("odt/mimetype","application/vnd.oasis.opendocument.text"),("odt/settings.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<office:document-settings xmlns:office=\"urn:oasis:names:tc:opendocument:xmlns:office:1.0\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:config=\"urn:oasis:names:tc:opendocument:xmlns:config:1.0\" xmlns:ooo=\"http://openoffice.org/2004/office\" office:version=\"1.2\"><office:settings><config:config-item-set config:name=\"ooo:view-settings\"><config:config-item config:name=\"ViewAreaTop\" config:type=\"int\">0</config:config-item><config:config-item config:name=\"ViewAreaLeft\" config:type=\"int\">0</config:config-item><config:config-item config:name=\"ViewAreaWidth\" config:type=\"int\">21747</config:config-item><config:config-item config:name=\"ViewAreaHeight\" config:type=\"int\">10874</config:config-item><config:config-item config:name=\"ShowRedlineChanges\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"InBrowseMode\" config:type=\"boolean\">false</config:config-item><config:config-item-map-indexed config:name=\"Views\"><config:config-item-map-entry><config:config-item config:name=\"ViewId\" config:type=\"string\">view2</config:config-item><config:config-item config:name=\"ViewLeft\" config:type=\"int\">3041</config:config-item><config:config-item config:name=\"ViewTop\" config:type=\"int\">3041</config:config-item><config:config-item config:name=\"VisibleLeft\" config:type=\"int\">0</config:config-item><config:config-item config:name=\"VisibleTop\" config:type=\"int\">0</config:config-item><config:config-item config:name=\"VisibleRight\" config:type=\"int\">21745</config:config-item><config:config-item config:name=\"VisibleBottom\" config:type=\"int\">10873</config:config-item><config:config-item config:name=\"ZoomType\" config:type=\"short\">0</config:config-item><config:config-item config:name=\"ViewLayoutColumns\" config:type=\"short\">0</config:config-item><config:config-item config:name=\"ViewLayoutBookMode\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"ZoomFactor\" config:type=\"short\">100</config:config-item><config:config-item config:name=\"IsSelectedFrame\" config:type=\"boolean\">false</config:config-item></config:config-item-map-entry></config:config-item-map-indexed></config:config-item-set><config:config-item-set config:name=\"ooo:configuration-settings\"><config:config-item config:name=\"ChartAutoUpdate\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"IsLabelDocument\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"MathBaselineAlignment\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"Rsid\" config:type=\"int\">1473719</config:config-item><config:config-item config:name=\"OutlineLevelYieldsNumbering\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintLeftPages\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"DoNotJustifyLinesWithManualBreak\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"ClippedPictures\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"AlignTabStopPosition\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"PrintTextPlaceholder\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"UseOldNumbering\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"CurrentDatabaseCommand\" config:type=\"string\"/><config:config-item config:name=\"ProtectForm\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintBlackFonts\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintProspectRTL\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"BackgroundParaOverDrawings\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"FloattableNomargins\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"SmallCapsPercentage66\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintControls\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"EmbedSystemFonts\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"CharacterCompressionType\" config:type=\"short\">0</config:config-item><config:config-item config:name=\"PrintHiddenText\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"UseFormerTextWrapping\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"IsKernAsianPunctuation\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintProspect\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintEmptyPages\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"UnbreakableNumberings\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"UseFormerObjectPositioning\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"ConsiderTextWrapOnObjPos\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"TableRowKeep\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintReversed\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"TabsRelativeToIndent\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"PrintRightPages\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"PrintPaperFromSetup\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"AddFrameOffsets\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"AddParaSpacingToTableCells\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"UpdateFromTemplate\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"AddExternalLeading\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"PrintSingleJobs\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrinterIndependentLayout\" config:type=\"string\">high-resolution</config:config-item><config:config-item config:name=\"RsidRoot\" config:type=\"int\">1473719</config:config-item><config:config-item config:name=\"LinkUpdateMode\" config:type=\"short\">1</config:config-item><config:config-item config:name=\"PrintAnnotationMode\" config:type=\"short\">0</config:config-item><config:config-item config:name=\"TabOverMargin\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"UseOldPrinterMetrics\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"RedlineProtectionKey\" config:type=\"base64Binary\"/><config:config-item config:name=\"PrinterSetup\" config:type=\"base64Binary\"/><config:config-item config:name=\"IgnoreFirstLineIndentInNumbering\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"CollapseEmptyCellPara\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"PrinterName\" config:type=\"string\"/><config:config-item config:name=\"EmbedFonts\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"InvertBorderSpacing\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintPageBackground\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"DoNotCaptureDrawObjsOnPage\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"TabOverflow\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"ApplyUserData\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"TabAtLeftIndentForParagraphsInList\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"UnxForceZeroExtLeading\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"SaveVersionOnClose\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintFaxName\" config:type=\"string\"/><config:config-item config:name=\"StylesNoDefault\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"AddParaTableSpacing\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"PrintDrawings\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"LoadReadonly\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintGraphics\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"FieldAutoUpdate\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"AllowPrintJobCancel\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"UseFormerLineSpacing\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"SaveGlobalDocumentLinks\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"CurrentDatabaseDataSource\" config:type=\"string\"/><config:config-item config:name=\"IgnoreTabsAndBlanksForLineCalculation\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"CurrentDatabaseCommandType\" config:type=\"int\">0</config:config-item><config:config-item config:name=\"DoNotResetParaAttrsForNumFont\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"ClipAsCharacterAnchoredWriterFlyFrames\" config:type=\"boolean\">false</config:config-item><config:config-item config:name=\"PrintTables\" config:type=\"boolean\">true</config:config-item><config:config-item config:name=\"AddParaTableSpacingAtStart\" config:type=\"boolean\">true</config:config-item></config:config-item-set></office:settings></office:document-settings>"),("odt/styles.xml","<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<office:document-styles xmlns:office=\"urn:oasis:names:tc:opendocument:xmlns:office:1.0\"\nxmlns:style=\"urn:oasis:names:tc:opendocument:xmlns:style:1.0\"\nxmlns:text=\"urn:oasis:names:tc:opendocument:xmlns:text:1.0\"\nxmlns:table=\"urn:oasis:names:tc:opendocument:xmlns:table:1.0\"\nxmlns:draw=\"urn:oasis:names:tc:opendocument:xmlns:drawing:1.0\"\nxmlns:fo=\"urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0\"\nxmlns:xlink=\"http://www.w3.org/1999/xlink\"\nxmlns:dc=\"http://purl.org/dc/elements/1.1/\"\nxmlns:meta=\"urn:oasis:names:tc:opendocument:xmlns:meta:1.0\"\nxmlns:number=\"urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0\"\nxmlns:svg=\"urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0\"\nxmlns:chart=\"urn:oasis:names:tc:opendocument:xmlns:chart:1.0\"\nxmlns:dr3d=\"urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0\"\nxmlns:math=\"http://www.w3.org/1998/Math/MathML\"\nxmlns:form=\"urn:oasis:names:tc:opendocument:xmlns:form:1.0\"\nxmlns:script=\"urn:oasis:names:tc:opendocument:xmlns:script:1.0\"\nxmlns:ooo=\"http://openoffice.org/2004/office\"\nxmlns:ooow=\"http://openoffice.org/2004/writer\"\nxmlns:oooc=\"http://openoffice.org/2004/calc\"\nxmlns:dom=\"http://www.w3.org/2001/xml-events\"\nxmlns:rpt=\"http://openoffice.org/2005/report\"\nxmlns:of=\"urn:oasis:names:tc:opendocument:xmlns:of:1.2\"\nxmlns:xhtml=\"http://www.w3.org/1999/xhtml\"\nxmlns:grddl=\"http://www.w3.org/2003/g/data-view#\"\nxmlns:officeooo=\"http://openoffice.org/2009/office\"\nxmlns:tableooo=\"http://openoffice.org/2009/table\"\nxmlns:drawooo=\"http://openoffice.org/2010/draw\"\nxmlns:calcext=\"urn:org:documentfoundation:names:experimental:calc:xmlns:calcext:1.0\"\nxmlns:css3t=\"http://www.w3.org/TR/css3-text/\" office:version=\"1.2\">\n  <office:font-face-decls>\n    <style:font-face style:name=\"StarSymbol\"\n    svg:font-family=\"StarSymbol\" />\n    <style:font-face style:name=\"Tahoma1\"\n    svg:font-family=\"Tahoma\" />\n    <style:font-face style:name=\"Courier New\"\n    svg:font-family=\"'Courier New'\"\n    style:font-family-generic=\"modern\" style:font-pitch=\"fixed\" />\n    <style:font-face style:name=\"Times New Roman\"\n    svg:font-family=\"'Times New Roman'\"\n    style:font-family-generic=\"roman\"\n    style:font-pitch=\"variable\" />\n    <style:font-face style:name=\"Arial\" svg:font-family=\"Arial\"\n    style:font-family-generic=\"swiss\"\n    style:font-pitch=\"variable\" />\n    <style:font-face style:name=\"Lucida Sans Unicode\"\n    svg:font-family=\"'Lucida Sans Unicode'\"\n    style:font-family-generic=\"system\"\n    style:font-pitch=\"variable\" />\n    <style:font-face style:name=\"Tahoma\" svg:font-family=\"Tahoma\"\n    style:font-family-generic=\"system\"\n    style:font-pitch=\"variable\" />\n  </office:font-face-decls>\n  <office:styles>\n    <style:default-style style:family=\"graphic\">\n      <style:graphic-properties fo:wrap-option=\"wrap\"\n      draw:shadow-offset-x=\"0.1181in\"\n      draw:shadow-offset-y=\"0.1181in\"\n      draw:start-line-spacing-horizontal=\"0.1114in\"\n      draw:start-line-spacing-vertical=\"0.1114in\"\n      draw:end-line-spacing-horizontal=\"0.1114in\"\n      draw:end-line-spacing-vertical=\"0.1114in\"\n      style:flow-with-text=\"false\" />\n      <style:paragraph-properties style:text-autospace=\"ideograph-alpha\"\n      style:line-break=\"strict\" style:writing-mode=\"lr-tb\"\n      style:font-independent-line-spacing=\"false\">\n        <style:tab-stops />\n      </style:paragraph-properties>\n      <style:text-properties style:use-window-font-color=\"true\"\n      fo:font-size=\"12pt\" fo:language=\"en\" fo:country=\"US\"\n      style:letter-kerning=\"true\" style:font-size-asian=\"12pt\"\n      style:language-asian=\"zxx\" style:country-asian=\"none\"\n      style:font-size-complex=\"12pt\" style:language-complex=\"zxx\"\n      style:country-complex=\"none\" />\n    </style:default-style>\n    <style:default-style style:family=\"paragraph\">\n      <style:paragraph-properties fo:hyphenation-ladder-count=\"no-limit\"\n      style:text-autospace=\"ideograph-alpha\"\n      style:punctuation-wrap=\"hanging\" style:line-break=\"strict\"\n      style:tab-stop-distance=\"0.4925in\"\n      style:writing-mode=\"page\" />\n      <style:text-properties style:use-window-font-color=\"true\"\n      style:font-name=\"Times New Roman\" fo:font-size=\"12pt\"\n      fo:language=\"en\" fo:country=\"US\" style:letter-kerning=\"true\"\n      style:font-name-asian=\"Lucida Sans Unicode\"\n      style:font-size-asian=\"12pt\" style:language-asian=\"zxx\"\n      style:country-asian=\"none\" style:font-name-complex=\"Tahoma\"\n      style:font-size-complex=\"12pt\" style:language-complex=\"zxx\"\n      style:country-complex=\"none\" fo:hyphenate=\"false\"\n      fo:hyphenation-remain-char-count=\"2\"\n      fo:hyphenation-push-char-count=\"2\" />\n    </style:default-style>\n    <style:default-style style:family=\"table\">\n      <style:table-properties table:border-model=\"collapsing\" />\n    </style:default-style>\n    <style:default-style style:family=\"table-row\">\n      <style:table-row-properties fo:keep-together=\"auto\" />\n    </style:default-style>\n    <style:style style:name=\"Standard\" style:family=\"paragraph\"\n    style:class=\"text\" />\n    <style:style style:name=\"Heading\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Text_20_body\" style:class=\"text\">\n      <style:paragraph-properties fo:margin-top=\"0.1665in\"\n      fo:margin-bottom=\"0.0835in\" style:contextual-spacing=\"false\"\n      fo:keep-with-next=\"always\" />\n      <style:text-properties style:font-name=\"Arial\"\n      fo:font-size=\"14pt\"\n      style:font-name-asian=\"Lucida Sans Unicode\"\n      style:font-size-asian=\"14pt\" style:font-name-complex=\"Tahoma\"\n      style:font-size-complex=\"14pt\" />\n    </style:style>\n    <style:style style:name=\"Text_20_body\"\n    style:display-name=\"Text body\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"text\">\n      <style:paragraph-properties fo:margin-top=\"0.0598in\"\n      fo:margin-bottom=\"0.0598in\"\n      style:contextual-spacing=\"false\" />\n    </style:style>\n    <style:style style:name=\"List\" style:family=\"paragraph\"\n    style:parent-style-name=\"Text_20_body\" style:class=\"list\">\n      <style:text-properties style:font-name-complex=\"Tahoma1\" />\n    </style:style>\n    <style:style style:name=\"Caption\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"extra\">\n      <style:paragraph-properties fo:margin-top=\"0.0835in\"\n      fo:margin-bottom=\"0.0835in\" style:contextual-spacing=\"false\"\n      text:number-lines=\"false\" text:line-number=\"0\" />\n      <style:text-properties fo:font-size=\"12pt\"\n      fo:font-style=\"italic\" style:font-size-asian=\"12pt\"\n      style:font-style-asian=\"italic\"\n      style:font-name-complex=\"Tahoma1\"\n      style:font-size-complex=\"12pt\"\n      style:font-style-complex=\"italic\" />\n    </style:style>\n    <style:style style:name=\"TableCaption\" style:family=\"paragraph\"\n    style:parent-style-name=\"Caption\" style:class=\"extra\">\n    </style:style>\n    <style:style style:name=\"FigureCaption\" style:family=\"paragraph\"\n    style:parent-style-name=\"Caption\" style:class=\"extra\">\n    </style:style>\n    <style:style style:name=\"Figure\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"extra\">\n      <style:paragraph-properties text:number-lines=\"false\"\n      text:line-number=\"0\" />\n    </style:style>\n    <style:style style:name=\"FigureWithCaption\" style:family=\"paragraph\"\n    style:parent-style-name=\"Figure\" style:class=\"extra\">\n      <style:paragraph-properties text:number-lines=\"false\"\n      text:line-number=\"0\" fo:keep-with-next=\"always\" />\n    </style:style>\n    <style:style style:name=\"Index\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"index\">\n      <style:paragraph-properties text:number-lines=\"false\"\n      text:line-number=\"0\" />\n      <style:text-properties style:font-name-complex=\"Tahoma1\" />\n    </style:style>\n    <style:style style:name=\"Heading_20_1\"\n    style:display-name=\"Heading 1\" style:family=\"paragraph\"\n    style:parent-style-name=\"Heading\"\n    style:next-style-name=\"Text_20_body\"\n    style:default-outline-level=\"1\" style:class=\"text\">\n      <style:text-properties fo:font-size=\"115%\"\n      fo:font-weight=\"bold\" style:font-size-asian=\"115%\"\n      style:font-weight-asian=\"bold\" style:font-size-complex=\"115%\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Heading_20_2\"\n    style:display-name=\"Heading 2\" style:family=\"paragraph\"\n    style:parent-style-name=\"Heading\"\n    style:next-style-name=\"Text_20_body\"\n    style:default-outline-level=\"2\" style:class=\"text\">\n      <style:text-properties fo:font-size=\"14pt\"\n      fo:font-style=\"italic\" fo:font-weight=\"bold\"\n      style:font-size-asian=\"14pt\" style:font-style-asian=\"italic\"\n      style:font-weight-asian=\"bold\" style:font-size-complex=\"14pt\"\n      style:font-style-complex=\"italic\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Heading_20_3\"\n    style:display-name=\"Heading 3\" style:family=\"paragraph\"\n    style:parent-style-name=\"Heading\"\n    style:next-style-name=\"Text_20_body\"\n    style:default-outline-level=\"3\" style:class=\"text\">\n      <style:text-properties fo:font-size=\"14pt\"\n      fo:font-weight=\"bold\" style:font-size-asian=\"14pt\"\n      style:font-weight-asian=\"bold\" style:font-size-complex=\"14pt\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Heading_20_4\"\n    style:display-name=\"Heading 4\" style:family=\"paragraph\"\n    style:parent-style-name=\"Heading\"\n    style:next-style-name=\"Text_20_body\"\n    style:default-outline-level=\"4\" style:class=\"text\">\n      <style:text-properties fo:font-size=\"85%\"\n      fo:font-style=\"italic\" fo:font-weight=\"bold\"\n      style:font-size-asian=\"85%\" style:font-style-asian=\"italic\"\n      style:font-weight-asian=\"bold\" style:font-size-complex=\"85%\"\n      style:font-style-complex=\"italic\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Heading_20_5\"\n    style:display-name=\"Heading 5\" style:family=\"paragraph\"\n    style:parent-style-name=\"Heading\"\n    style:next-style-name=\"Text_20_body\"\n    style:default-outline-level=\"5\" style:class=\"text\">\n      <style:text-properties fo:font-size=\"85%\"\n      fo:font-weight=\"bold\" style:font-size-asian=\"85%\"\n      style:font-weight-asian=\"bold\" style:font-size-complex=\"85%\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Heading_20_6\"\n    style:display-name=\"Heading 6\" style:family=\"paragraph\"\n    style:parent-style-name=\"Heading\"\n    style:next-style-name=\"Text_20_body\"\n    style:default-outline-level=\"6\" style:class=\"text\">\n      <style:text-properties fo:font-size=\"75%\"\n      fo:font-weight=\"bold\" style:font-size-asian=\"75%\"\n      style:font-weight-asian=\"bold\" style:font-size-complex=\"75%\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Quotations\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"html\">\n      <style:paragraph-properties fo:margin-left=\"0.3937in\"\n      fo:margin-right=\"0.3937in\" fo:margin-top=\"0.1in\"\n      fo:margin-bottom=\"0.1in\" style:contextual-spacing=\"false\"\n      fo:text-indent=\"0in\" style:auto-text-indent=\"false\" />\n    </style:style>\n    <style:style style:name=\"Preformatted_20_Text\"\n    style:display-name=\"Preformatted Text\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"html\">\n      <style:paragraph-properties fo:margin-top=\"0in\"\n      fo:margin-bottom=\"0in\" style:contextual-spacing=\"false\" />\n      <style:text-properties style:font-name=\"Courier New\"\n      fo:font-size=\"10pt\" style:font-name-asian=\"Courier New\"\n      style:font-size-asian=\"10pt\"\n      style:font-name-complex=\"Courier New\"\n      style:font-size-complex=\"10pt\" />\n    </style:style>\n    <style:style style:name=\"Definition_20_Term\"\n    style:display-name=\"Definition Term\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Definition_20_Definition\">\n      <style:paragraph-properties fo:margin-top=\"0.0598in\"\n      fo:margin-bottom=\"0.0598in\"\n      style:contextual-spacing=\"false\" />\n    </style:style>\n    <style:style style:name=\"Definition_20_Definition\"\n    style:display-name=\"Definition Definition\"\n    style:family=\"paragraph\" style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Text_20_body\">\n      <style:paragraph-properties fo:margin-left=\"0.5in\"\n      fo:margin-right=\"0in\" fo:text-indent=\"0in\"\n      style:auto-text-indent=\"false\" />\n    </style:style>\n    <style:style style:name=\"Table_20_Contents\"\n    style:display-name=\"Table Contents\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"extra\">\n      <style:paragraph-properties fo:margin-left=\"0.0299in\"\n      fo:margin-right=\"0.0299in\" fo:text-indent=\"0in\"\n      style:auto-text-indent=\"false\" text:number-lines=\"false\"\n      text:line-number=\"0\" />\n    </style:style>\n    <style:style style:name=\"Table_20_Heading\"\n    style:display-name=\"Table Heading\" style:family=\"paragraph\"\n    style:parent-style-name=\"Table_20_Contents\"\n    style:class=\"extra\">\n      <style:paragraph-properties fo:margin-left=\"0.0299in\"\n      fo:margin-right=\"0.0299in\" fo:text-align=\"start\"\n      style:justify-single-word=\"false\" fo:text-indent=\"0in\"\n      style:auto-text-indent=\"false\" style:shadow=\"none\"\n      text:number-lines=\"false\" text:line-number=\"0\" />\n      <style:text-properties fo:font-weight=\"bold\"\n      style:font-weight-asian=\"bold\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Footnote\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"extra\">\n      <style:paragraph-properties fo:margin-left=\"0.1965in\"\n      fo:margin-right=\"0in\" fo:text-indent=\"-0.1965in\"\n      style:auto-text-indent=\"false\" text:number-lines=\"false\"\n      text:line-number=\"0\" />\n      <style:text-properties fo:font-size=\"10pt\"\n      style:font-size-asian=\"10pt\"\n      style:font-size-complex=\"10pt\" />\n    </style:style>\n    <style:style style:name=\"Footer\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:class=\"extra\">\n      <style:paragraph-properties text:number-lines=\"false\"\n      text:line-number=\"0\">\n        <style:tab-stops>\n          <style:tab-stop style:position=\"3.25in\"\n          style:type=\"center\" />\n          <style:tab-stop style:position=\"6.5in\"\n          style:type=\"right\" />\n        </style:tab-stops>\n      </style:paragraph-properties>\n    </style:style>\n    <style:style style:name=\"Definition_20_Term_20_Tight\"\n    style:display-name=\"Definition Term Tight\"\n    style:family=\"paragraph\" style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Definition_20_Definition_20_Tight\">\n      <style:paragraph-properties fo:margin-top=\"0.0799in\"\n      fo:margin-bottom=\"0.0799in\"\n      style:contextual-spacing=\"false\" />\n    </style:style>\n    <style:style style:name=\"Definition_20_Definition_20_Tight\"\n    style:display-name=\"Definition Definition Tight\"\n    style:family=\"paragraph\" style:parent-style-name=\"Standard\">\n      <style:paragraph-properties fo:margin-left=\"0.5in\"\n      fo:margin-right=\"0in\" fo:margin-top=\"0in\"\n      fo:margin-bottom=\"0in\" style:contextual-spacing=\"false\"\n      fo:text-indent=\"0in\" style:auto-text-indent=\"false\" />\n    </style:style>\n    <style:style style:name=\"Date\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Text_20_body\">\n      <style:text-properties fo:font-style=\"italic\" />\n    </style:style>\n    <style:style style:name=\"Author\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\" style:next-style-name=\"Date\"\n    style:master-page-name=\"\">\n      <style:paragraph-properties style:page-number=\"auto\" />\n      <style:text-properties fo:font-style=\"italic\" />\n    </style:style>\n    <style:style style:name=\"Horizontal_20_Line\"\n    style:display-name=\"Horizontal Line\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Text_20_body\" style:class=\"html\">\n      <style:paragraph-properties fo:margin-top=\"0in\"\n      fo:margin-bottom=\"0.1965in\" style:contextual-spacing=\"false\"\n      style:border-line-width-bottom=\"0.0008in 0.0138in 0.0008in\"\n      fo:padding=\"0in\" fo:border-left=\"none\" fo:border-right=\"none\"\n      fo:border-top=\"none\" fo:border-bottom=\"1.11pt double #808080\"\n      text:number-lines=\"false\" text:line-number=\"0\"\n      style:join-border=\"false\" />\n      <style:text-properties fo:font-size=\"6pt\"\n      style:font-size-asian=\"6pt\" style:font-size-complex=\"6pt\" />\n    </style:style>\n    <style:style style:name=\"First_20_paragraph\"\n    style:display-name=\"First paragraph\" style:family=\"paragraph\"\n    style:parent-style-name=\"Standard\"\n    style:next-style-name=\"Text_20_body\" style:class=\"text\" />\n    <style:style style:name=\"Numbering_20_Symbols\"\n    style:display-name=\"Numbering Symbols\" style:family=\"text\" />\n    <style:style style:name=\"Bullet_20_Symbols\"\n    style:display-name=\"Bullet Symbols\" style:family=\"text\">\n      <style:text-properties style:font-name=\"StarSymbol\"\n      fo:font-size=\"9pt\" style:font-name-asian=\"StarSymbol\"\n      style:font-size-asian=\"9pt\"\n      style:font-name-complex=\"StarSymbol\"\n      style:font-size-complex=\"9pt\" />\n    </style:style>\n    <style:style style:name=\"Emphasis\" style:family=\"text\">\n      <style:text-properties fo:font-style=\"italic\"\n      style:font-style-asian=\"italic\"\n      style:font-style-complex=\"italic\" />\n    </style:style>\n    <style:style style:name=\"Strong_20_Emphasis\"\n    style:display-name=\"Strong Emphasis\" style:family=\"text\">\n      <style:text-properties fo:font-weight=\"bold\"\n      style:font-weight-asian=\"bold\"\n      style:font-weight-complex=\"bold\" />\n    </style:style>\n    <style:style style:name=\"Strikeout\" style:family=\"text\">\n      <style:text-properties style:text-line-through-style=\"solid\" />\n    </style:style>\n    <style:style style:name=\"Superscript\" style:family=\"text\">\n      <style:text-properties style:text-position=\"super 58%\" />\n    </style:style>\n    <style:style style:name=\"Subscript\" style:family=\"text\">\n      <style:text-properties style:text-position=\"sub 58%\" />\n    </style:style>\n    <style:style style:name=\"Citation\" style:family=\"text\">\n      <style:text-properties fo:font-style=\"italic\"\n      style:font-style-asian=\"italic\"\n      style:font-style-complex=\"italic\" />\n    </style:style>\n    <style:style style:name=\"Teletype\" style:family=\"text\">\n      <style:text-properties style:font-name=\"Courier New\"\n      style:font-name-asian=\"Courier New\"\n      style:font-name-complex=\"Courier New\" />\n    </style:style>\n    <style:style style:name=\"Internet_20_link\"\n    style:display-name=\"Internet link\" style:family=\"text\">\n      <style:text-properties fo:color=\"#000080\"\n      style:text-underline-style=\"solid\"\n      style:text-underline-width=\"auto\"\n      style:text-underline-color=\"font-color\" />\n    </style:style>\n    <style:style style:name=\"Footnote_20_Symbol\"\n    style:display-name=\"Footnote Symbol\" style:family=\"text\" />\n    <style:style style:name=\"Footnote_20_anchor\"\n    style:display-name=\"Footnote anchor\" style:family=\"text\">\n      <style:text-properties style:text-position=\"super 58%\" />\n    </style:style>\n    <style:style style:name=\"Definition\" style:family=\"text\" />\n    <text:outline-style style:name=\"Outline\">\n      <text:outline-level-style text:level=\"1\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"2\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"3\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"4\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"5\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"6\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"7\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"8\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"9\" style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n      <text:outline-level-style text:level=\"10\"\n      style:num-format=\"\">\n        <style:list-level-properties text:min-label-distance=\"0.15in\" />\n      </text:outline-level-style>\n    </text:outline-style>\n    <text:list-style style:name=\"Numbering_20_1\"\n    style:display-name=\"Numbering 1\">\n      <text:list-level-style-number text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"0.1972in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"0.3937in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"0.5909in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"0.7874in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"0.9846in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"1.1815in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"1.3787in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"1.5752in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:space-before=\"1.7724in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n    </text:list-style>\n    <text:list-style style:name=\"Numbering_20_2\"\n    style:display-name=\"Numbering 2\">\n      <text:list-level-style-number text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\">\n        <style:list-level-properties text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"2\">\n        <style:list-level-properties text:space-before=\"0.1965in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"3\">\n        <style:list-level-properties text:space-before=\"0.3929in\"\n        text:min-label-width=\"0.3937in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"4\">\n        <style:list-level-properties text:space-before=\"0.7866in\"\n        text:min-label-width=\"0.4925in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"5\">\n        <style:list-level-properties text:space-before=\"1.2791in\"\n        text:min-label-width=\"0.5902in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"6\">\n        <style:list-level-properties text:space-before=\"1.8693in\"\n        text:min-label-width=\"0.7091in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"7\">\n        <style:list-level-properties text:space-before=\"2.5783in\"\n        text:min-label-width=\"0.9055in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"8\">\n        <style:list-level-properties text:space-before=\"3.4839in\"\n        text:min-label-width=\"1.0236in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"9\">\n        <style:list-level-properties text:space-before=\"4.5075in\"\n        text:min-label-width=\"1.1028in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"10\">\n        <style:list-level-properties text:space-before=\"5.6102in\"\n        text:min-label-width=\"1.2209in\" />\n      </text:list-level-style-number>\n    </text:list-style>\n    <text:list-style style:name=\"Numbering_20_3\"\n    style:display-name=\"Numbering 3\">\n      <text:list-level-style-number text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\">\n        <style:list-level-properties text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"2\">\n        <style:list-level-properties text:space-before=\"1.1815in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"3\">\n        <style:list-level-properties text:space-before=\"2.3626in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"4\">\n        <style:list-level-properties text:space-before=\"3.5441in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"5\">\n        <style:list-level-properties text:space-before=\"4.7252in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"6\">\n        <style:list-level-properties text:space-before=\"5.9063in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"7\">\n        <style:list-level-properties text:space-before=\"7.0878in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"8\">\n        <style:list-level-properties text:space-before=\"8.2689in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"9\">\n        <style:list-level-properties text:space-before=\"9.45in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-format=\"1\"\n      text:start-value=\"10\">\n        <style:list-level-properties text:space-before=\"10.6315in\"\n        text:min-label-width=\"1.1811in\" />\n      </text:list-level-style-number>\n    </text:list-style>\n    <text:list-style style:name=\"Numbering_20_4\"\n    style:display-name=\"Numbering 4\">\n      <text:list-level-style-number text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\">\n        <style:list-level-properties text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"2\">\n        <style:list-level-properties text:space-before=\"0.1972in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"3\">\n        <style:list-level-properties text:space-before=\"0.3937in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"4\">\n        <style:list-level-properties text:space-before=\"0.5909in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"5\">\n        <style:list-level-properties text:space-before=\"0.7874in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"6\">\n        <style:list-level-properties text:space-before=\"0.9846in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"7\">\n        <style:list-level-properties text:space-before=\"1.1815in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"8\">\n        <style:list-level-properties text:space-before=\"1.3787in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"9\">\n        <style:list-level-properties text:space-before=\"1.5752in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"I\" text:start-value=\"10\">\n        <style:list-level-properties text:space-before=\"1.7724in\"\n        text:min-label-width=\"0.1965in\" />\n      </text:list-level-style-number>\n    </text:list-style>\n    <text:list-style style:name=\"Numbering_20_5\"\n    style:display-name=\"Numbering 5\">\n      <text:list-level-style-number text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\">\n        <style:list-level-properties text:min-label-width=\"0.1575in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\".\"\n      style:num-format=\"1\" text:start-value=\"2\"\n      text:display-levels=\"2\">\n        <style:list-level-properties text:space-before=\"0.1772in\"\n        text:min-label-width=\"0.2563in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-number text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" style:num-suffix=\")\"\n      style:num-format=\"a\" text:start-value=\"3\">\n        <style:list-level-properties text:space-before=\"0.4331in\"\n        text:min-label-width=\"0.1772in\" />\n      </text:list-level-style-number>\n      <text:list-level-style-bullet text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.6319in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.7874in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.9429in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.0988in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.2543in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.4098in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.5654in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n    </text:list-style>\n    <text:list-style style:name=\"List_20_1\"\n    style:display-name=\"List 1\">\n      <text:list-level-style-bullet text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.1579in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.3146in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.4724in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.6299in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.7878in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"0.9445in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.1024in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.2598in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\162\">\n        <style:list-level-properties text:space-before=\"1.4177in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n    </text:list-style>\n    <text:list-style style:name=\"List_20_2\"\n    style:display-name=\"List 2\">\n      <text:list-level-style-bullet text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.1181in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.2362in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.3539in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.472in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.5902in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.7091in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.8272in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"0.9453in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\128\147\">\n        <style:list-level-properties text:space-before=\"1.063in\"\n        text:min-label-width=\"0.1181in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n    </text:list-style>\n    <text:list-style style:name=\"List_20_3\"\n    style:display-name=\"List 3\">\n      <text:list-level-style-bullet text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\152\145\">\n        <style:list-level-properties text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\150\161\">\n        <style:list-level-properties text:space-before=\"0.1555in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\152\145\">\n        <style:list-level-properties text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\150\161\">\n        <style:list-level-properties text:space-before=\"0.1555in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\152\145\">\n        <style:list-level-properties text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\150\161\">\n        <style:list-level-properties text:space-before=\"0.1555in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\152\145\">\n        <style:list-level-properties text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\150\161\">\n        <style:list-level-properties text:space-before=\"0.1555in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\152\145\">\n        <style:list-level-properties text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\150\161\">\n        <style:list-level-properties text:space-before=\"0.1555in\"\n        text:min-label-width=\"0.1555in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n    </text:list-style>\n    <text:list-style style:name=\"List_20_4\"\n    style:display-name=\"List 4\">\n      <text:list-level-style-bullet text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\158\162\">\n        <style:list-level-properties text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\134\">\n        <style:list-level-properties text:space-before=\"0.1579in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"0.3146in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"0.4724in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"0.6299in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"0.7878in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"0.9445in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"1.1024in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"1.2598in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\238\128\132\">\n        <style:list-level-properties text:space-before=\"1.4177in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n    </text:list-style>\n    <text:list-style style:name=\"List_20_5\"\n    style:display-name=\"List 5\">\n      <text:list-level-style-bullet text:level=\"1\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"2\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"0.1579in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"3\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"0.3146in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"4\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"0.4724in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"5\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"0.6299in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"6\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"0.7878in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"7\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"0.9445in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"8\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"1.1024in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"9\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"1.2598in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n      <text:list-level-style-bullet text:level=\"10\"\n      text:style-name=\"Numbering_20_Symbols\" text:bullet-char=\"\226\156\151\">\n        <style:list-level-properties text:space-before=\"1.4177in\"\n        text:min-label-width=\"0.1575in\" />\n        <style:text-properties style:font-name=\"StarSymbol\" />\n      </text:list-level-style-bullet>\n    </text:list-style>\n    <text:notes-configuration text:note-class=\"footnote\"\n    text:citation-style-name=\"Footnote_20_Symbol\"\n    text:citation-body-style-name=\"Footnote_20_anchor\"\n    style:num-format=\"1\" text:start-value=\"0\"\n    text:footnotes-position=\"page\"\n    text:start-numbering-at=\"document\" />\n    <text:notes-configuration text:note-class=\"endnote\"\n    style:num-format=\"i\" text:start-value=\"0\" />\n    <text:linenumbering-configuration text:number-lines=\"false\"\n    text:offset=\"0.1965in\" style:num-format=\"1\"\n    text:number-position=\"left\" text:increment=\"5\" />\n  </office:styles>\n  <office:automatic-styles>\n    <style:style style:name=\"MP1\" style:family=\"paragraph\"\n    style:parent-style-name=\"Footer\">\n      <style:paragraph-properties fo:text-align=\"center\"\n      style:justify-single-word=\"false\" />\n    </style:style>\n    <style:page-layout style:name=\"Mpm1\">\n      <style:page-layout-properties fo:page-width=\"8.5in\"\n      fo:page-height=\"11in\" style:num-format=\"1\"\n      style:print-orientation=\"portrait\" fo:margin-top=\"1in\"\n      fo:margin-bottom=\"1in\" fo:margin-left=\"1in\"\n      fo:margin-right=\"1in\" style:writing-mode=\"lr-tb\"\n      style:footnote-max-height=\"0in\">\n        <style:footnote-sep style:width=\"0.0071in\"\n        style:distance-before-sep=\"0.0398in\"\n        style:distance-after-sep=\"0.0398in\" style:line-style=\"none\"\n        style:adjustment=\"left\" style:rel-width=\"25%\"\n        style:color=\"#000000\" />\n      </style:page-layout-properties>\n      <style:header-style />\n      <style:footer-style>\n        <style:header-footer-properties fo:min-height=\"0.4in\"\n        fo:margin-left=\"0in\" fo:margin-right=\"0in\"\n        fo:margin-top=\"0.2in\" style:dynamic-spacing=\"false\" />\n      </style:footer-style>\n    </style:page-layout>\n  </office:automatic-styles>\n  <office:master-styles>\n    <style:master-page style:name=\"Standard\"\n    style:page-layout-name=\"Mpm1\">\n      <style:footer>\n        <text:p text:style-name=\"MP1\">\n          <text:page-number text:select-page=\"current\">\n          1</text:page-number>\n        </text:p>\n      </style:footer>\n    </style:master-page>\n  </office:master-styles>\n</office:document-styles>\n"),("odt/Configurations2/accelerator/current.xml",""),("odt/META-INF/manifest.xml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<manifest:manifest xmlns:manifest=\"urn:oasis:names:tc:opendocument:xmlns:manifest:1.0\" manifest:version=\"1.2\">\n <manifest:file-entry manifest:full-path=\"/\" manifest:version=\"1.2\" manifest:media-type=\"application/vnd.oasis.opendocument.text\"/>\n <manifest:file-entry manifest:full-path=\"meta.xml\" manifest:media-type=\"text/xml\"/>\n <manifest:file-entry manifest:full-path=\"settings.xml\" manifest:media-type=\"text/xml\"/>\n <manifest:file-entry manifest:full-path=\"content.xml\" manifest:media-type=\"text/xml\"/>\n <manifest:file-entry manifest:full-path=\"Thumbnails/thumbnail.png\" manifest:media-type=\"image/png\"/>\n <manifest:file-entry manifest:full-path=\"manifest.rdf\" manifest:media-type=\"application/rdf+xml\"/>\n <manifest:file-entry manifest:full-path=\"Configurations2/accelerator/current.xml\" manifest:media-type=\"\"/>\n <manifest:file-entry manifest:full-path=\"Configurations2/\" manifest:media-type=\"application/vnd.sun.xml.ui.configuration\"/>\n <manifest:file-entry manifest:full-path=\"styles.xml\" manifest:media-type=\"text/xml\"/>\n</manifest:manifest>"),("odt/Thumbnails/thumbnail.png","\137PNG\r\n\SUB\n\NUL\NUL\NUL\rIHDR\NUL\NUL\NUL\198\NUL\NUL\SOH\NUL\b\STX\NUL\NUL\NULg?\158\ETB\NUL\NUL\STX\216IDATx\156\237\214A\n\194\&0\DC4\NULQ\ETX\222\255\202_\161 E\DLE\186\CANQ\235{\139\240\179j\SYNC\210\235\204\\\160s\253\244\SOH8\ESCI\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC4\177,\169\181\214\204\220\215m\251\152\183\225i\173>\202\ETB*o\169GO\251y\ESC\246+\231\246\222\135o\DELo\241'\178\164^=g\158\185\DEL\227\247\156\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\138\152\164\136I\234\144\181\214\204|\250\DC4\191AR\135\232\233\&8I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC41I\DC1\147\DC4\177\ESC\b\SUB(\EOTp\211\ESCp\NUL\NUL\NUL\NULIEND\174B`\130"),("templates/.git","gitdir: ../../.git/modules/templates\n"),("templates/default.asciidoc","$if(titleblock)$\n$title$\n$for(author)$\n:author: $author$\n$endfor$\n$if(date)$\n:date: $date$\n$endif$\n$if(toc)$\n:toc:\n$endif$\n\n$endif$\n$for(header-includes)$\n$header-includes$\n\n$endfor$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.beamer","\\documentclass[$if(fontsize)$$fontsize$,$endif$$if(handout)$handout,$endif$$if(beamer)$ignorenonframetext,$endif$$for(classoption)$$classoption$$sep$,$endfor$]{$documentclass$}\n$if(theme)$\n\\usetheme{$theme$}\n$endif$\n$if(colortheme)$\n\\usecolortheme{$colortheme$}\n$endif$\n$if(fonttheme)$\n\\usefonttheme{$fonttheme$}\n$endif$\n\\setbeamertemplate{caption}[numbered]\n\\setbeamertemplate{caption label separator}{:}\n\\setbeamercolor{caption name}{fg=normal text.fg}\n\\usepackage{amssymb,amsmath}\n\\usepackage{ifxetex,ifluatex}\n\\usepackage{fixltx2e} % provides \\textsubscript\n\\usepackage{lmodern}\n\\ifxetex\n  \\usepackage{fontspec,xltxtra,xunicode}\n  \\defaultfontfeatures{Mapping=tex-text,Scale=MatchLowercase}\n  \\newcommand{\\euro}{\226\130\172}\n\\else\n  \\ifluatex\n    \\usepackage{fontspec}\n    \\defaultfontfeatures{Mapping=tex-text,Scale=MatchLowercase}\n    \\newcommand{\\euro}{\226\130\172}\n  \\else\n    \\usepackage[T1]{fontenc}\n    \\usepackage[utf8]{inputenc}\n    $if(euro)$\n      \\usepackage{eurosym}\n    $endif$\n  \\fi\n\\fi\n% use upquote if available, for straight quotes in verbatim environments\n\\IfFileExists{upquote.sty}{\\usepackage{upquote}}{}\n% use microtype if available\n\\IfFileExists{microtype.sty}{\\usepackage{microtype}}{}\n$if(natbib)$\n\\usepackage{natbib}\n\\bibliographystyle{plainnat}\n$endif$\n$if(biblatex)$\n\\usepackage{biblatex}\n$for(bibliography)$\n\\addbibresource{$bibliography$}\n$endfor$\n$endif$\n$if(listings)$\n\\usepackage{listings}\n$endif$\n$if(lhs)$\n\\lstnewenvironment{code}{\\lstset{language=Haskell,basicstyle=\\small\\ttfamily}}{}\n$endif$\n$if(highlighting-macros)$\n$highlighting-macros$\n$endif$\n$if(verbatim-in-note)$\n\\usepackage{fancyvrb}\n$endif$\n$if(tables)$\n\\usepackage{longtable,booktabs}\n\\usepackage{caption}\n% These lines are needed to make table captions work with longtable:\n\\makeatletter\n\\def\\fnum@table{\\tablename~\\thetable}\n\\makeatother\n$endif$\n$if(url)$\n\\usepackage{url}\n$endif$\n$if(graphics)$\n\\usepackage{graphicx}\n\\makeatletter\n\\def\\maxwidth{\\ifdim\\Gin@nat@width>\\linewidth\\linewidth\\else\\Gin@nat@width\\fi}\n\\def\\maxheight{\\ifdim\\Gin@nat@height>\\textheight0.8\\textheight\\else\\Gin@nat@height\\fi}\n\\makeatother\n% Scale images if necessary, so that they will not overflow the page\n% margins by default, and it is still possible to overwrite the defaults\n% using explicit options in \\includegraphics[width, height, ...]{}\n\\setkeys{Gin}{width=\\maxwidth,height=\\maxheight,keepaspectratio}\n$endif$\n\n% Comment these out if you don't want a slide with just the\n% part/section/subsection/subsubsection title:\n\\AtBeginPart{\n  \\let\\insertpartnumber\\relax\n  \\let\\partname\\relax\n  \\frame{\\partpage}\n}\n\\AtBeginSection{\n  \\let\\insertsectionnumber\\relax\n  \\let\\sectionname\\relax\n  \\frame{\\sectionpage}\n}\n\\AtBeginSubsection{\n  \\let\\insertsubsectionnumber\\relax\n  \\let\\subsectionname\\relax\n  \\frame{\\subsectionpage}\n}\n\n$if(strikeout)$\n\\usepackage[normalem]{ulem}\n% avoid problems with \\sout in headers with hyperref:\n\\pdfstringdefDisableCommands{\\renewcommand{\\sout}{}}\n$endif$\n\\setlength{\\parindent}{0pt}\n\\setlength{\\parskip}{6pt plus 2pt minus 1pt}\n\\setlength{\\emergencystretch}{3em}  % prevent overfull lines\n\\providecommand{\\tightlist}{%\n  \\setlength{\\itemsep}{0pt}\\setlength{\\parskip}{0pt}}\n$if(numbersections)$\n$else$\n\\setcounter{secnumdepth}{0}\n$endif$\n$if(verbatim-in-note)$\n\\VerbatimFootnotes % allows verbatim text in footnotes\n$endif$\n$if(lang)$\n\\ifxetex\n  \\usepackage{polyglossia}\n  \\setmainlanguage{$mainlang$}\n  \\setotherlanguages{$for(otherlang)$$otherlang$$sep$,$endfor$}\n\\else\n  \\usepackage[shorthands=off,$lang$]{babel}\n\\fi\n$endif$\n$for(header-includes)$\n$header-includes$\n$endfor$\n\n$if(title)$\n\\title{$title$}\n$endif$\n$if(subtitle)$\n\\subtitle{$subtitle$}\n$endif$\n$if(author)$\n\\author{$for(author)$$author$$sep$ \\and $endfor$}\n$endif$\n\\date{$date$}\n\n\\begin{document}\n$if(title)$\n\\frame{\\titlepage}\n$endif$\n\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n\\begin{frame}\n\\tableofcontents[hideallsubsections]\n\\end{frame}\n\n$endif$\n$body$\n\n$if(natbib)$\n$if(bibliography)$\n$if(biblio-title)$\n$if(book-class)$\n\\renewcommand\\bibname{$biblio-title$}\n$else$\n\\renewcommand\\refname{$biblio-title$}\n$endif$\n$endif$\n\\begin{frame}[allowframebreaks]{$biblio-title$}\n\\bibliography{$for(bibliography)$$bibliography$$sep$,$endfor$}\n\\end{frame}\n\n$endif$\n$endif$\n$if(biblatex)$\n\\begin{frame}[allowframebreaks]{$biblio-title$}\n\\printbibliography[heading=none]\n\\end{frame}\n\n$endif$\n$for(include-after)$\n$include-after$\n\n$endfor$\n\\end{document}\n"),("templates/default.commonmark","$if(titleblock)$\n$titleblock$\n\n$endif$\n$for(header-includes)$\n$header-includes$\n\n$endfor$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n$toc$\n\n$endif$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.context","\\startmode[*mkii]\n  \\enableregime[utf-8]  \n  \\setupcolors[state=start]\n\\stopmode\n$if(mainlang)$\n\\mainlanguage[$mainlang$]\n$endif$\n\n% Enable hyperlinks\n\\setupinteraction[state=start, color=middleblue]\n\n\\setuppapersize [$if(papersize)$$papersize$$else$letter$endif$][$if(papersize)$$papersize$$else$letter$endif$]\n\\setuplayout    [width=middle,  backspace=1.5in, cutspace=1.5in,\n                 height=middle, topspace=0.75in, bottomspace=0.75in]\n\n\\setuppagenumbering[location={footer,center}]\n\n\\setupbodyfont[11pt]\n\n\\setupwhitespace[medium]\n\n\\setuphead[chapter]      [style=\\tfd]\n\\setuphead[section]      [style=\\tfc]\n\\setuphead[subsection]   [style=\\tfb]\n\\setuphead[subsubsection][style=\\bf]\n\n$if(number-sections)$\n$else$\n\\setuphead[chapter, section, subsection, subsubsection][number=no]\n$endif$\n\n\\definedescription\n  [description]\n  [headstyle=bold, style=normal, location=hanging, width=broad, margin=1cm]\n\n\\setupitemize[autointro]    % prevent orphan list intro\n\\setupitemize[indentnext=no]\n\n\\setupfloat[figure][default={here,nonumber}]\n\\setupfloat[table][default={here,nonumber}]\n\n\\setupthinrules[width=15em] % width of horizontal rules\n\n\\setupdelimitedtext\n  [blockquote]\n  [before={\\blank[medium]},\n   after={\\blank[medium]},\n   indentnext=no,\n  ]\n\n$if(toc)$\n\\setupcombinedlist[content][list={$placelist$}]\n\n$endif$\n$for(header-includes)$\n$header-includes$\n$endfor$\n\n\\starttext\n$if(title)$\n\\startalignment[center]\n  \\blank[2*big]\n  {\\tfd $title$}\n$if(author)$\n  \\blank[3*medium]\n  {\\tfa $for(author)$$author$$sep$\\crlf $endfor$}\n$endif$\n$if(date)$\n  \\blank[2*medium]\n  {\\tfa $date$}\n$endif$\n  \\blank[3*medium]\n\\stopalignment\n$endif$\n$for(include-before)$\n$include-before$\n$endfor$\n$if(toc)$\n\\placecontent\n$endif$\n\n$body$\n\n$for(include-after)$\n$include-after$\n$endfor$\n\\stoptext\n"),("templates/default.docbook","<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n$if(mathml)$\n<!DOCTYPE article PUBLIC \"-//OASIS//DTD DocBook EBNF Module V1.1CR1//EN\"\n                  \"http://www.oasis-open.org/docbook/xml/mathml/1.1CR1/dbmathml.dtd\">\n$else$\n<!DOCTYPE article PUBLIC \"-//OASIS//DTD DocBook XML V4.5//EN\"\n                  \"http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd\">\n$endif$\n<article>\n  <articleinfo>\n    <title>$title$</title>\n$if(author)$\n    <authorgroup>\n$for(author)$\n      <author>\n        $author$\n      </author>\n$endfor$\n    </authorgroup>\n$endif$\n$if(date)$\n    <date>$date$</date>\n$endif$\n  </articleinfo>\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</article>\n"),("templates/default.dokuwiki","$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n__TOC__\n\n$endif$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.dzslides","<!DOCTYPE html>\n<head>\n<meta charset=\"utf-8\">\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\" />\n$endfor$\n$if(date-meta)$\n  <meta name=\"dcterms.date\" content=\"$date-meta$\" />\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$if(css)$\n$for(css)$\n  <link rel=\"stylesheet\" href=\"$css$\" $if(html5)$$else$type=\"text/css\" $endif$/>\n$endfor$\n$else$\n<style>\n  html { background-color: black; }\n  body { background-color: white; border-radius: 12px}\n  /* A section is a slide. It's size is 800x600, and this will never change */\n  section {\n      font-family: Arial, serif;\n      font-size: 20pt;\n    }\n  address, blockquote, dl, fieldset, form, h1, h2, h3, h4, h5, h6, hr, ol, p, pre, table, ul, dl { padding: 10px 20px 10px 20px; }\n  h1, h2, h3 {\n    text-align: center;\n    margin: 10pt 10pt 20pt 10pt;\n  }\n  ul, ol {\n    margin: 10px 10px 10px 50px;\n  }\n  section.titleslide h1 { margin-top: 200px; }\n  h1.title { margin-top: 150px; }\n  h1 { font-size: 180%; }\n  h2 { font-size: 120%; }\n  h3 { font-size: 100%; }\n  q { quotes: \"\226\128\156\" \"\226\128\157\" \"\226\128\152\" \"\226\128\153\"; }\n  blockquote { font-style: italic }\n  /* Figures are displayed full-page, with the caption on\n     top of the image/video */\n  figure {\n    background-color: black;\n  }\n  figcaption {\n    margin: 70px;\n  }\n  footer {\n    position: absolute;\n    bottom: 0;\n    width: 100%;\n    padding: 40px;\n    text-align: right;\n    background-color: #F3F4F8;\n    border-top: 1px solid #CCC;\n  }\n\n  /* Transition effect */\n  /* Feel free to change the transition effect for original\n     animations. See here:\n     https://developer.mozilla.org/en/CSS/CSS_transitions\n     How to use CSS3 Transitions: */\n  section {\n      -moz-transition: left 400ms linear 0s;\n      -webkit-transition: left 400ms linear 0s;\n      -ms-transition: left 400ms linear 0s;\n      transition: left 400ms linear 0s;\n  }\n\n  /* Before */\n  section { left: -150%; }\n  /* Now */\n  section[aria-selected] { left: 0; }\n  /* After */\n  section[aria-selected] ~ section { left: +150%; }\n\n  /* Incremental elements */\n\n  /* By default, visible */\n  .incremental > * { opacity: 1; }\n\n  /* The current item */\n  .incremental > *[aria-selected] { color: red; opacity: 1; }\n\n  /* The items to-be-selected */\n  .incremental > *[aria-selected] ~ * { opacity: 0.2; }\n</style>\n$endif$\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body>\n$if(title)$\n<section class=\"title\">\n  <h1 class=\"title\">$title$</h1>\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n$for(author)$\n  <h2 class=\"author\">$author$</h2>\n$endfor$\n  <h3 class=\"date\">$date$</h3>\n</section>\n$endif$\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n$dzslides-core$\n</body>\n</html>\n"),("templates/default.epub","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\"$if(lang)$ xml:lang=\"$lang$\"$endif$>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n  <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n  <meta name=\"generator\" content=\"pandoc\" />\n  <title>$pagetitle$</title>\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$for(css)$\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"$css$\" />\n$endfor$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body$if(coverpage)$ id=\"cover\"$endif$>\n$if(titlepage)$\n$for(title)$\n$if(title.text)$\n  <h1 class=\"$title.type$\">$title.text$</h1>\n$else$\n  <h1 class=\"title\">$title$</h1>\n$endif$\n$endfor$\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n$for(author)$\n  <h2 class=\"author\">$author$</h2>\n$endfor$\n$for(creator)$\n  <h2 class=\"$creator.role$\">$creator.text$</h2>\n$endfor$\n$if(publisher)$\n  <p class=\"publisher\">$publisher$</p>\n$endif$\n$if(date)$\n  <p class=\"date\">$date$</p>\n$endif$\n$if(rights)$\n  <div class=\"rights\">$rights$</div>\n$endif$\n$else$\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n$endif$\n</body>\n</html>\n\n"),("templates/default.epub3","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html>\n<html xmlns=\"http://www.w3.org/1999/xhtml\" xmlns:epub=\"http://www.idpf.org/2007/ops\"$if(lang)$ xml:lang=\"$lang$\"$endif$>\n<head>\n  <meta charset=\"utf-8\" />\n  <meta name=\"generator\" content=\"pandoc\" />\n  <title>$pagetitle$</title>\n$if(quotes)$\n  <style type=\"text/css\">\n    q { quotes: \"\226\128\156\" \"\226\128\157\" \"\226\128\152\" \"\226\128\153\"; }\n  </style>\n$endif$\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$for(css)$\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"$css$\" />\n$endfor$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body$if(coverpage)$ id=\"cover\"$endif$>\n$if(titlepage)$\n<section epub:type=\"titlepage\">\n$for(title)$\n$if(title.type)$\n  <h1 class=\"$title.type$\">$title.text$</h1>\n$else$\n  <h1 class=\"title\">$title$</h1>\n$endif$\n$endfor$\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n$for(author)$\n  <h2 class=\"author\">$author$</h2>\n$endfor$\n$for(creator)$\n  <h2 class=\"$creator.role$\">$creator.text$</h2>\n$endfor$\n$if(publisher)$\n  <p class=\"publisher\">$publisher$</p>\n$endif$\n$if(date)$\n  <p class=\"date\">$date$</p>\n$endif$\n$if(rights)$\n  <div class=\"rights\">$rights$</div>\n$endif$\n</section>\n$else$\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n$endif$\n</body>\n</html>\n\n"),("templates/default.haddock","$body$\n"),("templates/default.html","<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\"$if(lang)$ lang=\"$lang$\" xml:lang=\"$lang$\"$endif$>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n  <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n  <meta name=\"generator\" content=\"pandoc\" />\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\" />\n$endfor$\n$if(date-meta)$\n  <meta name=\"date\" content=\"$date-meta$\" />\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n$if(quotes)$\n  <style type=\"text/css\">q { quotes: \"\226\128\156\" \"\226\128\157\" \"\226\128\152\" \"\226\128\153\"; }</style>\n$endif$\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$for(css)$\n  <link rel=\"stylesheet\" href=\"$css$\" $if(html5)$$else$type=\"text/css\" $endif$/>\n$endfor$\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body>\n$for(include-before)$\n$include-before$\n$endfor$\n$if(title)$\n<div id=\"$idprefix$header\">\n<h1 class=\"title\">$title$</h1>\n$if(subtitle)$\n<h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n$for(author)$\n<h2 class=\"author\">$author$</h2>\n$endfor$\n$if(date)$\n<h3 class=\"date\">$date$</h3>\n$endif$\n</div>\n$endif$\n$if(toc)$\n<div id=\"$idprefix$TOC\">\n$toc$\n</div>\n$endif$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</body>\n</html>\n"),("templates/default.html5","<!DOCTYPE html>\n<html$if(lang)$ lang=\"$lang$\"$endif$>\n<head>\n  <meta charset=\"utf-8\">\n  <meta name=\"generator\" content=\"pandoc\">\n  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0, user-scalable=yes\">\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\">\n$endfor$\n$if(date-meta)$\n  <meta name=\"dcterms.date\" content=\"$date-meta$\">\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n  <!--[if lt IE 9]>\n    <script src=\"http://html5shim.googlecode.com/svn/trunk/html5.js\"></script>\n  <![endif]-->\n$if(quotes)$\n  <style type=\"text/css\">q { quotes: \"\226\128\156\" \"\226\128\157\" \"\226\128\152\" \"\226\128\153\"; }</style>\n$endif$\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$for(css)$\n  <link rel=\"stylesheet\" href=\"$css$\">\n$endfor$\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body>\n$for(include-before)$\n$include-before$\n$endfor$\n$if(title)$\n<header>\n<h1 class=\"title\">$title$</h1>\n$if(subtitle)$\n<h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n$for(author)$\n<h2 class=\"author\">$author$</h2>\n$endfor$\n$if(date)$\n<h3 class=\"date\">$date$</h3>\n$endif$\n</header>\n$endif$\n$if(toc)$\n<nav id=\"$idprefix$TOC\">\n$toc$\n</nav>\n$endif$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</body>\n</html>\n"),("templates/default.icml","<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\n<?aid style=\"50\" type=\"snippet\" readerVersion=\"6.0\" featureSet=\"513\" product=\"8.0(370)\" ?>\n<?aid SnippetType=\"InCopyInterchange\"?>\n<Document DOMVersion=\"8.0\" Self=\"pandoc_doc\">\n    <RootCharacterStyleGroup Self=\"pandoc_character_styles\">\n      <CharacterStyle Self=\"$$ID/NormalCharacterStyle\" Name=\"Default\" />\n      $charStyles$ \n    </RootCharacterStyleGroup>\n    <RootParagraphStyleGroup Self=\"pandoc_paragraph_styles\">\n      <ParagraphStyle Self=\"$$ID/NormalParagraphStyle\" Name=\"$$ID/NormalParagraphStyle\"\n          SpaceBefore=\"6\" SpaceAfter=\"6\"> <!-- paragraph spacing -->\n        <Properties>\n          <TabList type=\"list\">\n            <ListItem type=\"record\">\n              <Alignment type=\"enumeration\">LeftAlign</Alignment>\n              <AlignmentCharacter type=\"string\">.</AlignmentCharacter>\n              <Leader type=\"string\"></Leader>\n              <Position type=\"unit\">10</Position> <!-- first tab stop -->\n            </ListItem>\n          </TabList>\n        </Properties>\n      </ParagraphStyle>\n      $parStyles$ \n    </RootParagraphStyleGroup>\n    <RootTableStyleGroup Self=\"pandoc_table_styles\">\n      <TableStyle Self=\"TableStyle/Table\" Name=\"Table\" />\n    </RootTableStyleGroup>\n    <RootCellStyleGroup Self=\"pandoc_cell_styles\">\n      <CellStyle Self=\"CellStyle/Cell\" AppliedParagraphStyle=\"ParagraphStyle/$$ID/[No paragraph style]\" Name=\"Cell\" />\n    </RootCellStyleGroup>\n  <Story Self=\"pandoc_story\"\n      TrackChanges=\"false\"\n      StoryTitle=\"$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$\"\n      AppliedTOCStyle=\"n\"\n      AppliedNamedGrid=\"n\" >\n    <StoryPreference OpticalMarginAlignment=\"true\" OpticalMarginSize=\"12\" />\n\n<!-- body needs to be non-indented, otherwise code blocks are indented too far -->\n$body$\n\n  </Story>\n  $hyperlinks$\n</Document>\n"),("templates/default.latex","\\documentclass[$if(fontsize)$$fontsize$,$endif$$if(lang)$$lang$,$endif$$if(papersize)$$papersize$,$endif$$for(classoption)$$classoption$$sep$,$endfor$]{$documentclass$}\n$if(fontfamily)$\n\\usepackage{$fontfamily$}\n$else$\n\\usepackage{lmodern}\n$endif$\n$if(linestretch)$\n\\usepackage{setspace}\n\\setstretch{$linestretch$}\n$endif$\n\\usepackage{amssymb,amsmath}\n\\usepackage{ifxetex,ifluatex}\n\\usepackage{fixltx2e} % provides \\textsubscript\n\\ifnum 0\\ifxetex 1\\fi\\ifluatex 1\\fi=0 % if pdftex\n  \\usepackage[T1]{fontenc}\n  \\usepackage[utf8]{inputenc}\n$if(euro)$\n  \\usepackage{eurosym}\n$endif$\n\\else % if luatex or xelatex\n  \\ifxetex\n    \\usepackage{mathspec}\n    \\usepackage{xltxtra,xunicode}\n  \\else\n    \\usepackage{fontspec}\n  \\fi\n  \\defaultfontfeatures{Mapping=tex-text,Scale=MatchLowercase}\n  \\newcommand{\\euro}{\226\130\172}\n$if(mainfont)$\n    \\setmainfont{$mainfont$}\n$endif$\n$if(sansfont)$\n    \\setsansfont{$sansfont$}\n$endif$\n$if(monofont)$\n    \\setmonofont[Mapping=tex-ansi]{$monofont$}\n$endif$\n$if(mathfont)$\n    \\setmathfont(Digits,Latin,Greek){$mathfont$}\n$endif$\n$if(CJKmainfont)$\n    \\usepackage{xeCJK}\n    \\setCJKmainfont[$CJKoptions$]{$CJKmainfont$}\n$endif$\n\\fi\n% use upquote if available, for straight quotes in verbatim environments\n\\IfFileExists{upquote.sty}{\\usepackage{upquote}}{}\n% use microtype if available\n\\IfFileExists{microtype.sty}{%\n\\usepackage{microtype}\n\\UseMicrotypeSet[protrusion]{basicmath} % disable protrusion for tt fonts\n}{}\n$if(geometry)$\n\\usepackage[$for(geometry)$$geometry$$sep$,$endfor$]{geometry}\n$endif$\n\\ifxetex\n  \\usepackage[setpagesize=false, % page size defined by xetex\n              unicode=false, % unicode breaks when used with xetex\n              xetex]{hyperref}\n\\else\n  \\usepackage[unicode=true]{hyperref}\n\\fi\n\\usepackage[usenames,dvipsnames]{color}\n\\hypersetup{breaklinks=true,\n            bookmarks=true,\n            pdfauthor={$author-meta$},\n            pdftitle={$title-meta$},\n            colorlinks=true,\n            citecolor=$if(citecolor)$$citecolor$$else$blue$endif$,\n            urlcolor=$if(urlcolor)$$urlcolor$$else$blue$endif$,\n            linkcolor=$if(linkcolor)$$linkcolor$$else$magenta$endif$,\n            pdfborder={0 0 0}}\n\\urlstyle{same}  % don't use monospace font for urls\n$if(lang)$\n\\ifxetex\n  \\usepackage{polyglossia}\n  \\setmainlanguage{$mainlang$}\n  \\setotherlanguages{$for(otherlang)$$otherlang$$sep$,$endfor$}\n\\else\n  \\usepackage[shorthands=off,$lang$]{babel}\n\\fi\n$endif$\n$if(natbib)$\n\\usepackage{natbib}\n\\bibliographystyle{$if(biblio-style)$$biblio-style$$else$plainnat$endif$}\n$endif$\n$if(biblatex)$\n\\usepackage{biblatex}\n$for(bibliography)$\n\\addbibresource{$bibliography$}\n$endfor$\n$endif$\n$if(listings)$\n\\usepackage{listings}\n$endif$\n$if(lhs)$\n\\lstnewenvironment{code}{\\lstset{language=Haskell,basicstyle=\\small\\ttfamily}}{}\n$endif$\n$if(highlighting-macros)$\n$highlighting-macros$\n$endif$\n$if(verbatim-in-note)$\n\\usepackage{fancyvrb}\n\\VerbatimFootnotes\n$endif$\n$if(tables)$\n\\usepackage{longtable,booktabs}\n$endif$\n$if(graphics)$\n\\usepackage{graphicx,grffile}\n\\makeatletter\n\\def\\maxwidth{\\ifdim\\Gin@nat@width>\\linewidth\\linewidth\\else\\Gin@nat@width\\fi}\n\\def\\maxheight{\\ifdim\\Gin@nat@height>\\textheight\\textheight\\else\\Gin@nat@height\\fi}\n\\makeatother\n% Scale images if necessary, so that they will not overflow the page\n% margins by default, and it is still possible to overwrite the defaults\n% using explicit options in \\includegraphics[width, height, ...]{}\n\\setkeys{Gin}{width=\\maxwidth,height=\\maxheight,keepaspectratio}\n$endif$\n$if(links-as-notes)$\n% Make links footnotes instead of hotlinks:\n\\renewcommand{\\href}[2]{#2\\footnote{\\url{#1}}}\n$endif$\n$if(strikeout)$\n\\usepackage[normalem]{ulem}\n% avoid problems with \\sout in headers with hyperref:\n\\pdfstringdefDisableCommands{\\renewcommand{\\sout}{}}\n$endif$\n\\setlength{\\parindent}{0pt}\n\\setlength{\\parskip}{6pt plus 2pt minus 1pt}\n\\setlength{\\emergencystretch}{3em}  % prevent overfull lines\n\\providecommand{\\tightlist}{%\n  \\setlength{\\itemsep}{0pt}\\setlength{\\parskip}{0pt}}\n$if(numbersections)$\n\\setcounter{secnumdepth}{5}\n$else$\n\\setcounter{secnumdepth}{0}\n$endif$\n$if(verbatim-in-note)$\n\\VerbatimFootnotes % allows verbatim text in footnotes\n$endif$\n\n$if(title)$\n\\title{$title$$if(subtitle)$\\\\\\vspace{0.5em}{\\large $subtitle$}$endif$}\n$endif$\n$if(author)$\n\\author{$for(author)$$author$$sep$ \\and $endfor$}\n$endif$\n\\date{$date$}\n$for(header-includes)$\n$header-includes$\n$endfor$\n\n% Redefines (sub)paragraphs to behave more like sections\n\\ifx\\paragraph\\undefined\\else\n\\let\\oldparagraph\\paragraph\n\\renewcommand{\\paragraph}[1]{\\oldparagraph{#1}\\mbox{}}\n\\fi\n\\ifx\\subparagraph\\undefined\\else\n\\let\\oldsubparagraph\\subparagraph\n\\renewcommand{\\subparagraph}[1]{\\oldsubparagraph{#1}\\mbox{}}\n\\fi\n\n\\begin{document}\n$if(title)$\n\\maketitle\n$endif$\n$if(abstract)$\n\\begin{abstract}\n$abstract$\n\\end{abstract}\n$endif$\n\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n{\n\\hypersetup{linkcolor=$if(toccolor)$$toccolor$$else$black$endif$}\n\\setcounter{tocdepth}{$toc-depth$}\n\\tableofcontents\n}\n$endif$\n$if(lot)$\n\\listoftables\n$endif$\n$if(lof)$\n\\listoffigures\n$endif$\n$body$\n\n$if(natbib)$\n$if(bibliography)$\n$if(biblio-title)$\n$if(book-class)$\n\\renewcommand\\bibname{$biblio-title$}\n$else$\n\\renewcommand\\refname{$biblio-title$}\n$endif$\n$endif$\n\\bibliography{$for(bibliography)$$bibliography$$sep$,$endfor$}\n\n$endif$\n$endif$\n$if(biblatex)$\n\\printbibliography$if(biblio-title)$[title=$biblio-title$]$endif$\n\n$endif$\n$for(include-after)$\n$include-after$\n\n$endfor$\n\\end{document}\n"),("templates/default.man","$if(has-tables)$\n.\\\"t\n$endif$\n.TH \"$title$\" \"$section$\" \"$date$\" \"$footer$\" \"$header$\"\n$for(header-includes)$\n$header-includes$\n$endfor$\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n$if(author)$\n.SH AUTHORS\n$for(author)$$author$$sep$; $endfor$.\n$endif$\n"),("templates/default.markdown","$if(titleblock)$\n$titleblock$\n\n$endif$\n$for(header-includes)$\n$header-includes$\n\n$endfor$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n$toc$\n\n$endif$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.mediawiki","$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n__TOC__\n\n$endif$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.opendocument","<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n<office:document-content xmlns:office=\"urn:oasis:names:tc:opendocument:xmlns:office:1.0\" xmlns:style=\"urn:oasis:names:tc:opendocument:xmlns:style:1.0\" xmlns:text=\"urn:oasis:names:tc:opendocument:xmlns:text:1.0\" xmlns:table=\"urn:oasis:names:tc:opendocument:xmlns:table:1.0\" xmlns:draw=\"urn:oasis:names:tc:opendocument:xmlns:drawing:1.0\" xmlns:fo=\"urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:meta=\"urn:oasis:names:tc:opendocument:xmlns:meta:1.0\" xmlns:number=\"urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0\" xmlns:svg=\"urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0\" xmlns:chart=\"urn:oasis:names:tc:opendocument:xmlns:chart:1.0\" xmlns:dr3d=\"urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0\" xmlns:math=\"http://www.w3.org/1998/Math/MathML\" xmlns:form=\"urn:oasis:names:tc:opendocument:xmlns:form:1.0\" xmlns:script=\"urn:oasis:names:tc:opendocument:xmlns:script:1.0\" xmlns:ooo=\"http://openoffice.org/2004/office\" xmlns:ooow=\"http://openoffice.org/2004/writer\" xmlns:oooc=\"http://openoffice.org/2004/calc\" xmlns:dom=\"http://www.w3.org/2001/xml-events\" xmlns:xforms=\"http://www.w3.org/2002/xforms\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" office:version=\"1.2\">\n  <office:font-face-decls>\n    <style:font-face style:name=\"Courier New\" style:font-family-generic=\"modern\" style:font-pitch=\"fixed\" svg:font-family=\"'Courier New'\" />\n  </office:font-face-decls>\n  $automatic-styles$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n<office:body>\n<office:text>\n$if(title)$\n<text:p text:style-name=\"Title\">$title$</text:p>\n$endif$\n$for(author)$\n<text:p text:style-name=\"Author\">$author$</text:p>\n$endfor$\n$if(date)$\n<text:p text:style-name=\"Date\">$date$</text:p>\n$endif$\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</office:text>\n</office:body>\n</office:document-content>\n"),("templates/default.opml","<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<opml version=\"2.0\">\n  <head>\n    <title>$title$</title>\n    <dateModified>$date$</dateModified>\n    <ownerName>$for(author)$$author$$sep$; $endfor$</ownerName>\n  </head>\n  <body>\n$body$\n  </body>\n</opml>\n"),("templates/default.org","$if(title)$\n#+TITLE: $title$\n\n$endif$\n$if(author)$\n#+AUTHOR: $for(author)$$author$$sep$; $endfor$\n$endif$\n$if(date)$\n#+DATE: $date$\n\n$endif$\n$for(header-includes)$\n$header-includes$\n\n$endfor$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.plain","$if(titleblock)$\n$titleblock$\n\n$endif$\n$for(header-includes)$\n$header-includes$\n\n$endfor$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n$toc$\n\n$endif$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.revealjs","<!DOCTYPE html>\n<html$if(lang)$ lang=\"$lang$\"$endif$>\n<head>\n  <meta charset=\"utf-8\">\n  <meta name=\"generator\" content=\"pandoc\">\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\" />\n$endfor$\n$if(date-meta)$\n  <meta name=\"dcterms.date\" content=\"$date-meta$\" />\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <meta name=\"apple-mobile-web-app-capable\" content=\"yes\" />\n  <meta name=\"apple-mobile-web-app-status-bar-style\" content=\"black-translucent\" />\n  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no\">\n  <link rel=\"stylesheet\" href=\"$revealjs-url$/css/reveal.css\"/>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$if(theme)$\n  <link rel=\"stylesheet\" href=\"$revealjs-url$/css/theme/$theme$.css\" id=\"theme\">\n$else$\n  <link rel=\"stylesheet\" href=\"$revealjs-url$/css/theme/black.css\" id=\"theme\">\n$endif$\n$for(css)$\n  <link rel=\"stylesheet\" href=\"$css$\"/>\n$endfor$\n  <!-- If the query includes 'print-pdf', include the PDF print sheet -->\n  <script>\n    if( window.location.search.match( /print-pdf/gi ) ) {\n      var link = document.createElement( 'link' );\n      link.rel = 'stylesheet';\n      link.type = 'text/css';\n      link.href = '$revealjs-url$/css/print/pdf.css';\n      document.getElementsByTagName( 'head' )[0].appendChild( link );\n    }\n  </script>\n  <!--[if lt IE 9]>\n  <script src=\"$revealjs-url$/lib/js/html5shiv.js\"></script>\n  <![endif]-->\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body>\n$for(include-before)$\n$include-before$\n$endfor$\n  <div class=\"reveal\">\n    <div class=\"slides\">\n\n$if(title)$\n<section>\n    <h1 class=\"title\">$title$</h1>\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n$for(author)$\n    <h2 class=\"author\">$author$</h2>\n$endfor$\n    <h3 class=\"date\">$date$</h3>\n</section>\n$endif$\n$if(toc)$\n<section id=\"$idprefix$TOC\">\n$toc$\n</section>\n$endif$\n\n$body$\n    </div>\n  </div>\n\n\n  <script src=\"$revealjs-url$/lib/js/head.min.js\"></script>\n  <script src=\"$revealjs-url$/js/reveal.js\"></script>\n\n  <script>\n\n      // Full list of configuration options available here:\n      // https://github.com/hakimel/reveal.js#configuration\n      Reveal.initialize({\n        controls: true,         // Display controls in the bottom right corner\n        progress: true,         // Display a presentation progress bar\n        history: true,          // Push each slide change to the browser history\n        center: $if(center)$$center$$else$false$endif$,                       // Vertical centering of slides\n        maxScale: $if(maxScale)$$maxScale$$else$1.5$endif$,                  // Bounds for smallest/largest possible content scale\n        slideNumber: $if(slideNumber)$true$else$false$endif$,                // Display the page number of the current slide\n        theme: $if(theme)$'$theme$'$else$Reveal.getQueryHash().theme$endif$, // available themes are in /css/theme\n        transition: $if(transition)$'$transition$'$else$Reveal.getQueryHash().transition || 'default'$endif$, // default/cube/page/concave/zoom/linear/fade/none\n\n        // Optional libraries used to extend on reveal.js\n        dependencies: [\n          { src: '$revealjs-url$/lib/js/classList.js', condition: function() { return !document.body.classList; } },\n          { src: '$revealjs-url$/plugin/zoom-js/zoom.js', async: true, condition: function() { return !!document.body.classList; } },\n          { src: '$revealjs-url$/plugin/notes/notes.js', async: true, condition: function() { return !!document.body.classList; } },\n//          { src: '$revealjs-url$/plugin/search/search.js', async: true, condition: function() { return !!document.body.classList; }, }\n//          { src: '$revealjs-url$/plugin/remotes/remotes.js', async: true, condition: function() { return !!document.body.classList; } }\n]});\n    </script>\n  $for(include-after)$\n  $include-after$\n  $endfor$\n  </body>\n</html>\n"),("templates/default.rst","$if(title)$\n$title$\n\n$endif$\n$for(author)$\n:Author: $author$\n$endfor$\n$if(date)$\n:Date:   $date$\n$endif$\n$if(author)$\n\n$else$\n$if(date)$\n\n$endif$\n$endif$\n$if(math)$\n.. role:: math(raw)\n   :format: html latex\n..\n\n$endif$\n$if(rawtex)$\n.. role:: raw-latex(raw)\n   :format: latex\n..\n\n$endif$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n.. contents::\n   :depth: $toc-depth$\n..\n\n$endif$\n$for(header-includes)$\n$header-includes$\n\n$endfor$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/default.rtf","{\\rtf1\\ansi\\deff0{\\fonttbl{\\f0 \\fswiss Helvetica;}{\\f1 Courier;}}\n{\\colortbl;\\red255\\green0\\blue0;\\red0\\green0\\blue255;}\n\\widowctrl\\hyphauto\n$for(header-includes)$\n$header-includes$\n$endfor$\n\n$if(title)$\n{\\pard \\qc \\f0 \\sa180 \\li0 \\fi0 \\b \\fs36 $title$\\par}\n$endif$\n$for(author)$\n{\\pard \\qc \\f0 \\sa180 \\li0 \\fi0  $author$\\par}\n$endfor$\n$if(date)$\n{\\pard \\qc \\f0 \\sa180 \\li0 \\fi0  $date$\\par}\n$endif$\n$if(spacer)$\n{\\pard \\ql \\f0 \\sa180 \\li0 \\fi0 \\par}\n$endif$\n$if(toc)$\n$toc$\n$endif$\n$for(include-before)$\n$include-before$\n$endfor$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n}\n"),("templates/default.s5","<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n  <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n  <meta name=\"generator\" content=\"pandoc\" />\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\" />\n$endfor$\n$if(date-meta)$\n  <meta name=\"date\" content=\"$date-meta$\" />\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n  <!-- configuration parameters -->\n  <meta name=\"defaultView\" content=\"slideshow\" />\n  <meta name=\"controlVis\" content=\"hidden\" />\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n$for(css)$\n  <link rel=\"stylesheet\" href=\"$css$\" type=\"text/css\" />\n$endfor$\n  <!-- style sheet links -->\n  <link rel=\"stylesheet\" href=\"$s5-url$/slides.css\" type=\"text/css\" media=\"projection\" id=\"slideProj\" />\n  <link rel=\"stylesheet\" href=\"$s5-url$/outline.css\" type=\"text/css\" media=\"screen\" id=\"outlineStyle\" />\n  <link rel=\"stylesheet\" href=\"$s5-url$/print.css\" type=\"text/css\" media=\"print\" id=\"slidePrint\" />\n  <link rel=\"stylesheet\" href=\"$s5-url$/opera.css\" type=\"text/css\" media=\"projection\" id=\"operaFix\" />\n  <!-- S5 JS -->\n  <script src=\"$s5-url$/slides.js\" type=\"text/javascript\"></script>\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n</head>\n<body>\n$for(include-before)$\n$include-before$\n$endfor$\n<div class=\"layout\">\n<div id=\"controls\"></div>\n<div id=\"currentSlide\"></div>\n<div id=\"header\"></div>\n<div id=\"footer\">\n  <h1>$date$</h1>\n  <h2>$title$</h2>\n</div>\n</div>\n<div class=\"presentation\">\n$if(title)$\n<div class=\"titleslide slide\">\n  <h1>$title$</h1>\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n  <h2>$for(author)$$author$$sep$<br/>$endfor$</h2>\n  <h3>$date$</h3>\n</div>\n$endif$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</div>\n</body>\n</html>\n"),("templates/default.slideous","<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\"$if(lang)$ lang=\"$lang$\" xml:lang=\"$lang$\"$endif$>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n  <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n  <meta name=\"generator\" content=\"pandoc\" />\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\" />\n$endfor$\n$if(date-meta)$\n  <meta name=\"date\" content=\"$date-meta$\" />\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n  <link rel=\"stylesheet\" type=\"text/css\" media=\"screen, projection, print\"\n    href=\"$slideous-url$/slideous.css\" />\n$for(css)$\n  <link rel=\"stylesheet\" type=\"text/css\" media=\"screen, projection, print\"\n   href=\"$css$\" />\n$endfor$\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n  <script src=\"$slideous-url$/slideous.js\"\n    charset=\"utf-8\" type=\"text/javascript\"></script>\n$if(duration)$\n  <meta name=\"duration\" content=\"$duration$\" />\n$endif$\n</head>\n<body>\n$for(include-before)$\n$include-before$\n$endfor$\n<div id=\"statusbar\">\n<span style=\"float:right;\">\n<span style=\"margin-right:4em;font-weight:bold;\"><span id=\"slideidx\"></span> of {$$slidecount}</span>\n<button id=\"homebutton\" title=\"first slide\">1</button>\n<button id=\"prevslidebutton\" title=\"previous slide\">&laquo;</button>\n<button id=\"previtembutton\" title=\"previous item\">&lsaquo;</button>\n<button id=\"nextitembutton\" title=\"next item\">&rsaquo;</button>\n<button id=\"nextslidebutton\" title=\"next slide\">&raquo;</button>\n<button id=\"endbutton\" title=\"last slide\">{$$slidecount}</button>\n<button id=\"incfontbutton\" title=\"content\">A+</button>\n<button id=\"decfontbutton\" title=\"first slide\">A-</button>\n<select id=\"tocbox\" size=\"1\"><option></option></select>\n</span>\n<span id=\"eos\">&frac12;</span>\n<span title=\"{$$location}, {$$date}\">{$$title}, {$$author}</span>\n</div>\n$if(title)$\n<div class=\"slide titlepage\">\n  <h1 class=\"title\">$title$</h1>\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n  <p class=\"author\">\n$for(author)$$author$$sep$<br/>$endfor$\n  </p>\n$if(date)$\n  <p class=\"date\">$date$</p>\n$endif$\n</div>\n$endif$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</body>\n</html>\n"),("templates/default.slidy","<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"\n \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\"$if(lang)$ lang=\"$lang$\" xml:lang=\"$lang$\"$endif$>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n  <meta http-equiv=\"Content-Style-Type\" content=\"text/css\" />\n  <meta name=\"generator\" content=\"pandoc\" />\n$for(author-meta)$\n  <meta name=\"author\" content=\"$author-meta$\" />\n$endfor$\n$if(date-meta)$\n  <meta name=\"date\" content=\"$date-meta$\" />\n$endif$\n  <title>$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$</title>\n  <style type=\"text/css\">code{white-space: pre;}</style>\n$if(highlighting-css)$\n  <style type=\"text/css\">\n$highlighting-css$\n  </style>\n$endif$\n  <link rel=\"stylesheet\" type=\"text/css\" media=\"screen, projection, print\"\n    href=\"$slidy-url$/styles/slidy.css\" />\n$for(css)$\n  <link rel=\"stylesheet\" type=\"text/css\" media=\"screen, projection, print\"\n   href=\"$css$\" />\n$endfor$\n$if(math)$\n  $math$\n$endif$\n$for(header-includes)$\n  $header-includes$\n$endfor$\n  <script src=\"$slidy-url$/scripts/slidy.js\"\n    charset=\"utf-8\" type=\"text/javascript\"></script>\n$if(duration)$\n  <meta name=\"duration\" content=\"$duration$\" />\n$endif$\n</head>\n<body>\n$for(include-before)$\n$include-before$\n$endfor$\n$if(title)$\n<div class=\"slide titlepage\">\n  <h1 class=\"title\">$title$</h1>\n$if(subtitle)$\n  <h1 class=\"subtitle\">$subtitle$</h1>\n$endif$\n  <p class=\"author\">\n$for(author)$$author$$sep$<br/>$endfor$\n  </p>\n$if(date)$\n  <p class=\"date\">$date$</p>\n$endif$\n</div>\n$endif$\n$body$\n$for(include-after)$\n$include-after$\n$endfor$\n</body>\n</html>\n"),("templates/default.texinfo","\\input texinfo\n@documentencoding UTF-8\n$for(header-includes)$\n$header-includes$\n$endfor$\n\n$if(strikeout)$\n@macro textstrikeout{text}\n~~\\text\\~~\n@end macro\n\n$endif$\n$if(subscript)$\n@macro textsubscript{text}\n@iftex\n@textsubscript{\\text\\}\n@end iftex\n@ifnottex\n_@{\\text\\@}\n@end ifnottex\n@end macro\n\n$endif$\n$if(superscript)$\n@macro textsuperscript{text}\n@iftex\n@textsuperscript{\\text\\}\n@end iftex\n@ifnottex\n^@{\\text\\@}\n@end ifnottex\n@end macro\n\n$endif$\n@ifnottex\n@paragraphindent 0\n@end ifnottex\n$if(titlepage)$\n@titlepage\n@title $title$\n$for(author)$\n@author $author$\n$endfor$\n$if(date)$\n$date$\n$endif$\n@end titlepage\n\n$endif$\n$for(include-before)$\n$include-before$\n\n$endfor$\n$if(toc)$\n@contents\n\n$endif$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n\n@bye\n"),("templates/default.textile","$for(include-before)$\n$include-before$\n\n$endfor$\n$body$\n$for(include-after)$\n\n$include-after$\n$endfor$\n"),("templates/README.markdown","Templates for [pandoc](http://github.com/jgm/pandoc).\n\nIf you use custom templates, we recommend forking this repository,\nso that you can integrate changes to the default templates in future\npandoc releases.\n\nAll of the templates in this repository are dual licensed, under both\nthe GPL (v2 or higher, same as pandoc) and the BSD 3-clause license\n(included below).\n\n----\n\nCopyright (c) 2014, John MacFarlane\n\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n    * Redistributions of source code must retain the above copyright\n      notice, this list of conditions and the following disclaimer.\n\n    * Redistributions in binary form must reproduce the above\n      copyright notice, this list of conditions and the following\n      disclaimer in the documentation and/or other materials provided\n      with the distribution.\n\n    * Neither the name of John MacFarlane nor the names of other\n      contributors may be used to endorse or promote products derived\n      from this software without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n\"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\nLIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\nA PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT\nOWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,\nSPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT\nLIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,\nDATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY\nTHEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\nOF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n")]
